/******************************************************************************//**
 * @file     RGB_LED.c
 * @version  V1.00
 * @brief    RGB LED lighting effects sample file
 *
 * @copyright (C) 2016 Nuvoton Technology Corp. All rights reserved.
 ******************************************************************************/

/*!<Includes */
#include <stdlib.h>
#include "NUC121.h"
#include "RGB_LED.h"
#include "device.h"

uint32_t G12TimeCounter = 0, G34TimeCounter = 0, G5TimeCounter = 0, RGB1TimeCounter = 0;
uint8_t G12LightingMode, G34LightingMode, G5LightingMode, RGB1LightingMode;
uint8_t G12BreathingSpeed, G34BreathingSpeed, G5BreathingSpeed, RGB1BreathingSpeed;
uint8_t G12Brightness, G34Brightness, G5Brightness, RGB1Brightness;
uint32_t RandomG1 = 0, RandomG2 = 0, RandomG3 = 0, RandomG4 = 0, RandomG5 = 0, RandomRGB1 = 0;
uint8_t ptrG1Color[8], ptrG2Color[8], ptrG3Color[8], ptrG4Color[8], ptrG5Color[8], ptrRGB1Color[8];
uint8_t ptrG1Bright[8], ptrG2Bright[8], ptrG3Bright[8], ptrG4Bright[8], ptrG5Bright[8], ptrRGB1Bright[8];

uint8_t *ptrG1_ColorArray, *ptrG2_ColorArray, *ptrG3_ColorArray, *ptrG4_ColorArray, *ptrG5_ColorArray, *ptrRGB1_ColorArray;
uint8_t G12ColorSize, G34ColorSize, G5ColorSize, RGB1ColorSize;
uint8_t *ptrG12BrightArray, *ptrG34BrightArray, *ptrG5BrightArray, *ptrRGB1BrightArray;
uint8_t G12BrightSize, G34BrightSize, G5BrightSize, RGB1BrightSize;
uint8_t *ptrG12RateArray, *ptrG34RateArray, *ptrG5RateArray, *ptrRGB1RateArray;
uint8_t G12MaxBright, G34MaxBright, G5MaxBright, RGB1MaxBright;
uint32_t G1_R_CMP, G1_G_CMP, G1_B_CMP, G2_R_CMP, G2_G_CMP, G2_B_CMP, G3_R_CMP, G3_G_CMP, G3_B_CMP, G4_R_CMP, G4_G_CMP, G4_B_CMP,
				 G5_R_CMP, G5_G_CMP, G5_B_CMP, RGB1_R_CMP, RGB1_G_CMP, RGB1_B_CMP;
uint32_t G12TempCal, G34TempCal, G5TempCal, RGB1TempCal;

uint8_t G12RGBColor[2][3] = {{  0,   0,   0},			// (R, G, B)
														 {255, 255, 255}};		// for lighting;
uint8_t G34RGBColor[2][3] = {{  0,   0,   0},			// (R, G, B)
														 {255, 255, 255}};		// for lighting;
uint8_t G5RGBColor[2][3] = {{  0,   0,   0},			// (R, G, B)
														{255, 255, 255}};			// for lighting;
uint8_t RGB1RGBColor[2][3] = {{  0,   0,   0},		// (R, G, B)
														  {255, 255, 255}};		// for lighting;

uint8_t G12CycleCounter, G34CycleCounter, G5CycleCounter, RGB1CycleCounter;

uint8_t	RGBBright[1] = {100};
uint8_t TempColor[1][3];
const uint8_t DisableColor[1][3] = {{0, 0, 0}};
const uint8_t DisableBright[1] = {0};
const uint8_t FixedRate[3] = {1, 1, 1};		// {Low, Medium, High}
#define BreathingArraySize 70
const uint8_t BreathingBright[BreathingArraySize] = {  0,   0,   1,   2,   4,   7,  10,  13,  17,  21,
																											25,  30,  35,  40,  45,  50,  55,  60,  65,  70,
																											75,  79,  83,  87,  90,  93,  96,  98,  99, 100,
																										 100, 100,  99,  98,  96,  93,  90,  87,  83,  79,
																											75,  70,  65,  60,  55,  50,  45,  40,  34,  30,
																											25,  21,  17,  13,  10,   7,   4,   2,   1,   0,
																											 0,   0,   0,   0,   0,   0,   0,   0,   0,   0};													
const uint8_t BreathingRate[3] = {6, 4, 2};		// {Low, Medium, High}
#define FlashingArraySize 25
#define DoubleFlashingArraySize 31
const uint8_t DoubleFlashingBright[31] = {  0,  0,   0,   0,   0,  0,  0,  0,   0,   0,
																	          0,  0,   0,   0,   0,  0,  0,  0,   0,   0,
																	          0,  0, 100, 100, 100,  0,  0,  0, 100, 100,
																					100};
const uint8_t DoubleFlashingRate[3] = {5, 5, 5};		// {Low, Medium, High}
const uint8_t MeteorBright[95] = { 10,  20,  30,  40,  50,  60,  70,  80,  90, 100,
															     90,  80,  70,  60,  50,  40,  30,  20,  10,  0,
																   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
													  	     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
															     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
																   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
															     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
														 	     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
													  		   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
															     0,   0,   0,   0,   0};
const uint8_t StackBright[150] = {  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
																		0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
																		0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
																	 10,  20,  30,  40,  50,  60,  70,  80,  90, 100,
																	 90,  80,  70,  60,  50,  40,  30,  20,  10,   0,
																	  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
																	  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
																	  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
																	  0,   0,   0,   0,   0,  10,  20,  30,  40,  50,
																	 60,  70,  80,  90, 100, 100, 100, 100, 100, 100,
																  100, 100, 100, 100, 100, 100, 100, 100, 100, 100,
																  100, 100, 100, 100, 100, 100, 100, 100, 100, 100,
																  100, 100, 100, 100, 100, 100, 100, 100, 100, 100,
																  100, 100, 100, 100, 100, 100, 100, 100, 100, 100,
																	 90,  80,  70,  60,  50,  40,  30,  20,  10,   0};																	
const uint8_t RainbowColor[16][3]		// (R, G, B)
							= {{255,   0,   0},		// Red
								 {255,  43,   0},
								 {255,  85,   0},		// Orange
								 {255, 170,   0},
								 {255, 255,   0},		// Yellow
								 {127, 255,   0},
								 {  0, 255,   0},		// Green
								 {  0, 191, 127},
								 {  0, 127, 255},		// Cyan
								 {  0,  63, 255},
								 {  0,   0, 255},		// Blue
								 { 21,   0, 255},
								 { 43,   0, 255},		// Indigo
								 { 65,   0, 255},
								 { 87,   0, 255},		// Purple
							   {171,   0, 127}};
const uint8_t RainbowBright[91] = {100, 100, 100, 100, 100, 100, 100, 100, 100, 100,
															     100, 100, 100, 100, 100, 100,   0,   0,   0,   0,
																     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
													  	       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
															       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
																     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
															       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
														 	       0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
													  		     0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
															       0};							 
const uint8_t RainbowRate[3] = {24, 15, 6};			// {Low, Medium, High}
const uint8_t LightingRate[3] = {20, 20, 20};		// {Low, Medium, High}

void G12Mode_Reset(void)
{
		uint8_t i;
	
		/* Stop Timer1 counting */
		TIMER_Stop(TIMER1);
	
		/* Set Color */
		ptrG1_ColorArray = (uint8_t *)G12RGBColor;
		ptrG2_ColorArray = (uint8_t *)G12RGBColor;
		G12ColorSize = 1;
	
		/* Reset Color */
		for(i = 0; i < 8; i ++)
		{
				ptrG1Color[i] = 0;
		}
		for(i = 0; i < 8; i ++)
		{
				ptrG2Color[i] = 0;
		}

		/* Reset Bright */
		for(i = 0; i < 8; i ++)
		{		
				ptrG1Bright[i] = 0;
		}
		for(i = 0; i < 8; i ++)
		{		
				ptrG2Bright[i] = 0;
		}

		if(G12LightingMode == Disable)
		{
				/* Set Color */
				ptrG1_ColorArray = (uint8_t *)DisableColor;
				ptrG2_ColorArray = (uint8_t *)DisableColor;
				G12ColorSize = sizeof(DisableColor);
			
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)DisableBright;
				G12BrightSize = sizeof(DisableBright);
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)FixedRate;
		}
		else if(G12LightingMode == No_Animation)
		{	
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)RGBBright;
				G12BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)FixedRate;
		}
		else if(G12LightingMode == Breathing)
		{
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)BreathingBright;
				G12BrightSize = sizeof(BreathingBright);
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)BreathingRate;
		}
		else if(G12LightingMode == Flashing)
		{
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)DoubleFlashingBright;
				G12BrightSize = sizeof(DoubleFlashingBright) - 6;
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)DoubleFlashingRate;
		}
		else if(G12LightingMode == Double_Flashing)
		{
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)(DoubleFlashingBright + 6);
				G12BrightSize = sizeof(DoubleFlashingBright) - 6;
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)DoubleFlashingRate;
		}
		else if((G12LightingMode == Marquees) || (G12LightingMode == Meteor))
		{
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)MeteorBright;
				G12BrightSize = sizeof(MeteorBright);
			
				ptrG1Bright[0] = 55;
				ptrG1Bright[1] = 50;
				ptrG1Bright[2] = 45;
				ptrG1Bright[3] = 40;
				ptrG1Bright[4] = 35;
				ptrG1Bright[5] = 30;
				ptrG1Bright[6] = 25;
				ptrG1Bright[7] = 20;
				
				ptrG2Bright[0] = 60;
				ptrG2Bright[1] = 65;
				ptrG2Bright[2] = 70;
				ptrG2Bright[3] = 75;
				ptrG2Bright[4] = 80;
				ptrG2Bright[5] = 85;
				ptrG2Bright[6] = 90;
				ptrG2Bright[7] = 0;
			
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)BreathingRate;
		}
		else if(G12LightingMode == UpDown)
		{
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)MeteorBright;
				G12BrightSize = 55;
				
				ptrG1Bright[0] = 20;
				ptrG1Bright[1] = 25;
				ptrG1Bright[2] = 30;
				ptrG1Bright[3] = 35;
				ptrG1Bright[4] = 40;
				ptrG1Bright[5] = 45;
				ptrG1Bright[6] = 50;
				ptrG1Bright[7] = 0;
				
				ptrG2Bright[0] = 20;
				ptrG2Bright[1] = 25;
				ptrG2Bright[2] = 30;
				ptrG2Bright[3] = 35;
				ptrG2Bright[4] = 40;
				ptrG2Bright[5] = 45;
				ptrG2Bright[6] = 50;
				ptrG2Bright[7] = 0;
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)BreathingRate;
		}
		else if(G12LightingMode == ChasingMeteor)
		{
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)MeteorBright;
				G12BrightSize = 55;
				
				ptrG1Bright[0] = 90;
				ptrG1Bright[1] = 85;
				ptrG1Bright[2] = 80;
				ptrG1Bright[3] = 75;
				ptrG1Bright[4] = 70;
				ptrG1Bright[5] = 65;
				ptrG1Bright[6] = 60;
				ptrG1Bright[7] = 55;
							
				ptrG2Bright[0] = 55;
				ptrG2Bright[1] = 60;
				ptrG2Bright[2] = 65;
				ptrG2Bright[3] = 70;
				ptrG2Bright[4] = 75;
				ptrG2Bright[5] = 80;
				ptrG2Bright[6] = 85;
				ptrG2Bright[7] = 90;
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)BreathingRate;
		}
		else if(G12LightingMode == Waterfall)
		{
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)MeteorBright;
				G12BrightSize = 55;
			
				ptrG1Bright[0] = 0;
				ptrG1Bright[1] = 50;
				ptrG1Bright[2] = 45;
				ptrG1Bright[3] = 40;
				ptrG1Bright[4] = 35;
				ptrG1Bright[5] = 30;
				ptrG1Bright[6] = 25;
				ptrG1Bright[7] = 20;
				
				ptrG2Bright[0] = 0;
				ptrG2Bright[1] = 50;
				ptrG2Bright[2] = 45;
				ptrG2Bright[3] = 40;
				ptrG2Bright[4] = 35;
				ptrG2Bright[5] = 30;
				ptrG2Bright[6] = 25;
				ptrG2Bright[7] = 20;
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)BreathingRate;
		}
		else if(G12LightingMode == Stack)
		{
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)StackBright;
				G12BrightSize = sizeof(StackBright);
			
				ptrG1Bright[0] = 30;
				ptrG1Bright[1] = 25;
				ptrG1Bright[2] = 20;
				ptrG1Bright[3] = 15;
				ptrG1Bright[4] = 10;
				ptrG1Bright[5] = 5;
				ptrG1Bright[6] = 0;
				ptrG1Bright[7] = 50;
				
				ptrG2Bright[0] = 30;
				ptrG2Bright[1] = 25;
				ptrG2Bright[2] = 20;
				ptrG2Bright[3] = 15;
				ptrG2Bright[4] = 10;
				ptrG2Bright[5] = 5;
				ptrG2Bright[6] = 0;
				ptrG2Bright[7] = 50;
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)BreathingRate;
				
				/* Set cycle counter */
				G12CycleCounter = 50;
		}
		else if(G12LightingMode == Rainbow)
		{
				/* Set Color */
				ptrG1_ColorArray = (uint8_t *)RainbowColor;
				ptrG2_ColorArray = (uint8_t *)RainbowColor;
				G12ColorSize = sizeof(RainbowColor) / 3;
				
				ptrG1Color[0] = 0;
				ptrG1Color[1] = 1;
				ptrG1Color[2] = 2;
				ptrG1Color[3] = 3;
				ptrG1Color[4] = 4;
				ptrG1Color[5] = 5;
				ptrG1Color[6] = 6;
				ptrG1Color[7] = 7;
			
				ptrG2Color[0] = 7;
				ptrG2Color[1] = 6;
				ptrG2Color[2] = 5;
				ptrG2Color[3] = 4;
				ptrG2Color[4] = 3;
				ptrG2Color[5] = 2;
				ptrG2Color[6] = 1;
				ptrG2Color[7] = 0;
			
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)RGBBright;
				G12BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)RainbowRate;
		}
		else if(G12LightingMode == Rainbow_Waterfall)
		{
				/* Set Color */
				ptrG1_ColorArray = (uint8_t *)RainbowColor;
				ptrG2_ColorArray = (uint8_t *)RainbowColor;
				G12ColorSize = sizeof(RainbowColor) / 3;
			
				ptrG1Color[0] = 0;
				ptrG1Color[1] = 1;
				ptrG1Color[2] = 2;
				ptrG1Color[3] = 3;
				ptrG1Color[4] = 4;
				ptrG1Color[5] = 5;
				ptrG1Color[6] = 6;
				ptrG1Color[7] = 7;
				
				ptrG2Color[0] = 7;
				ptrG2Color[1] = 6;
				ptrG2Color[2] = 5;
				ptrG2Color[3] = 4;
				ptrG2Color[4] = 3;
				ptrG2Color[5] = 2;
				ptrG2Color[6] = 1;
				ptrG2Color[7] = 0;
			
				ptrG12BrightArray = (uint8_t *)RainbowBright;
				G12BrightSize = 51;
				
				ptrG1Bright[0] = 0;
				ptrG1Bright[1] = 46;
				ptrG1Bright[2] = 41;
				ptrG1Bright[3] = 36;
				ptrG1Bright[4] = 31;
				ptrG1Bright[5] = 26;
				ptrG1Bright[6] = 21;
				ptrG1Bright[7] = 16;
				
				ptrG2Bright[0] = 0;
				ptrG2Bright[1] = 46;
				ptrG2Bright[2] = 41;
				ptrG2Bright[3] = 36;
				ptrG2Bright[4] = 31;
				ptrG2Bright[5] = 26;
				ptrG2Bright[6] = 21;
				ptrG2Bright[7] = 16;
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)BreathingRate;
		}
		else if(G12LightingMode == Lighting)
		{			
				/* Set Brightness */
				ptrG12BrightArray = (uint8_t *)RGBBright;
				G12BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrG12RateArray = (uint8_t *)LightingRate;
		}
		
		/* Reset Time Counter */
		G12TimeCounter = 0;
		RandomG1 = 0;
		RandomG2 = 0;
		
		/* Reset Calculated value */
//		G1_R_CMP = 0;
//		G1_G_CMP = 0;
//		G1_B_CMP = 0;
//		G2_R_CMP = 0;
//		G2_G_CMP = 0;
//		G2_B_CMP = 0;
		
		G12TempCal = 8 * *(ptrG12RateArray + G12BreathingSpeed);
}

void G34Mode_Reset(void)
{
		uint8_t i;
	
		/* Stop Timer1 counting */
		TIMER_Stop(TIMER1);
	
		/* Set Color */
		ptrG3_ColorArray = (uint8_t *)G34RGBColor;
		ptrG4_ColorArray = (uint8_t *)G34RGBColor;
		G34ColorSize = 1;
	
		/* Reset Color */
		for(i = 0; i < 8; i ++)
		{
				ptrG3Color[i] = 0;
		}
		for(i = 0; i < 8; i ++)
		{
				ptrG4Color[i] = 0;
		}

		/* Reset Bright */
		for(i = 0; i < 8; i ++)
		{		
				ptrG3Bright[i] = 0;
		}
		for(i = 0; i < 8; i ++)
		{		
				ptrG4Bright[i] = 0;
		}

		if(G34LightingMode == Disable)
		{
				/* Set Color */
				ptrG1_ColorArray = (uint8_t *)DisableColor;
				ptrG2_ColorArray = (uint8_t *)DisableColor;
				ptrG3_ColorArray = (uint8_t *)DisableColor;
				ptrG4_ColorArray = (uint8_t *)DisableColor;
				ptrG5_ColorArray = (uint8_t *)DisableColor;
				G34ColorSize = sizeof(DisableColor);
			
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)DisableBright;
				G34BrightSize = sizeof(DisableBright);
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)FixedRate;
		}
		else if(G34LightingMode == No_Animation)
		{	
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)RGBBright;
				G34BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)FixedRate;
		}
		else if(G34LightingMode == Breathing)
		{
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)BreathingBright;
				G34BrightSize = sizeof(BreathingBright);
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)BreathingRate;
		}
		else if(G34LightingMode == Flashing)
		{
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)DoubleFlashingBright;
				G34BrightSize = sizeof(DoubleFlashingBright) - 6;
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)DoubleFlashingRate;
		}
		else if(G34LightingMode == Double_Flashing)
		{
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)(DoubleFlashingBright + 6);
				G34BrightSize = sizeof(DoubleFlashingBright) - 6;
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)DoubleFlashingRate;
		}
		else if((G34LightingMode == Marquees) || (G34LightingMode == Meteor))
		{
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)MeteorBright;
				G34BrightSize = sizeof(MeteorBright);
			
				ptrG3Bright[0] = 55;
				ptrG3Bright[1] = 50;
				ptrG3Bright[2] = 45;
				ptrG3Bright[3] = 40;
				ptrG3Bright[4] = 35;
				ptrG3Bright[5] = 30;
				ptrG3Bright[6] = 25;
				ptrG3Bright[7] = 20;
				
				ptrG4Bright[0] = 60;
				ptrG4Bright[1] = 65;
				ptrG4Bright[2] = 70;
				ptrG4Bright[3] = 75;
				ptrG4Bright[4] = 80;
				ptrG4Bright[5] = 85;
				ptrG4Bright[6] = 90;
				ptrG4Bright[7] = 0;
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)BreathingRate;
		}
		else if(G34LightingMode == UpDown)
		{
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)MeteorBright;
				G34BrightSize = 55;
				
				ptrG3Bright[0] = 20;
				ptrG3Bright[1] = 25;
				ptrG3Bright[2] = 30;
				ptrG3Bright[3] = 35;
				ptrG3Bright[4] = 40;
				ptrG3Bright[5] = 45;
				ptrG3Bright[6] = 50;
				ptrG3Bright[7] = 0;
				
				ptrG4Bright[0] = 20;
				ptrG4Bright[1] = 25;
				ptrG4Bright[2] = 30;
				ptrG4Bright[3] = 35;
				ptrG4Bright[4] = 40;
				ptrG4Bright[5] = 45;
				ptrG4Bright[6] = 50;
				ptrG4Bright[7] = 0;
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)BreathingRate;
		}
		else if(G34LightingMode == ChasingMeteor)
		{
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)MeteorBright;
				G34BrightSize = 55;

				ptrG3Bright[0] = 90;
				ptrG3Bright[1] = 85;
				ptrG3Bright[2] = 80;
				ptrG3Bright[3] = 75;
				ptrG3Bright[4] = 70;
				ptrG3Bright[5] = 65;
				ptrG3Bright[6] = 60;
				ptrG3Bright[7] = 55;
							
				ptrG4Bright[0] = 55;
				ptrG4Bright[1] = 60;
				ptrG4Bright[2] = 65;
				ptrG4Bright[3] = 70;
				ptrG4Bright[4] = 75;
				ptrG4Bright[5] = 80;
				ptrG4Bright[6] = 85;
				ptrG4Bright[7] = 90;
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)BreathingRate;
		}
		else if(G34LightingMode == Waterfall)
		{
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)MeteorBright;
				G34BrightSize = 55;
				
				ptrG3Bright[0] = 0;
				ptrG3Bright[1] = 50;
				ptrG3Bright[2] = 45;
				ptrG3Bright[3] = 40;
				ptrG3Bright[4] = 35;
				ptrG3Bright[5] = 30;
				ptrG3Bright[6] = 25;
				ptrG3Bright[7] = 20;
				
				ptrG4Bright[0] = 0;
				ptrG4Bright[1] = 50;
				ptrG4Bright[2] = 45;
				ptrG4Bright[3] = 40;
				ptrG4Bright[4] = 35;
				ptrG4Bright[5] = 30;
				ptrG4Bright[6] = 25;
				ptrG4Bright[7] = 20;
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)BreathingRate;
		}
		else if(G34LightingMode == Stack)
		{
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)StackBright;
				G34BrightSize = sizeof(StackBright);

				ptrG3Bright[0] = 30;
				ptrG3Bright[1] = 25;
				ptrG3Bright[2] = 20;
				ptrG3Bright[3] = 15;
				ptrG3Bright[4] = 10;
				ptrG3Bright[5] = 5;
				ptrG3Bright[6] = 0;
				ptrG3Bright[7] = 50;
				
				ptrG4Bright[0] = 30;
				ptrG4Bright[1] = 25;
				ptrG4Bright[2] = 20;
				ptrG4Bright[3] = 15;
				ptrG4Bright[4] = 10;
				ptrG4Bright[5] = 5;
				ptrG4Bright[6] = 0;
				ptrG4Bright[7] = 50;
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)BreathingRate;
				
				/* Set cycle counter */
				G34CycleCounter = 50;
		}
		else if(G34LightingMode == Rainbow)
		{
				/* Set Color */
				ptrG3_ColorArray = (uint8_t *)RainbowColor;
				ptrG4_ColorArray = (uint8_t *)RainbowColor;
				G34ColorSize = sizeof(RainbowColor) / 3;
				
				ptrG3Color[0] = 0;
				ptrG3Color[1] = 1;				
				ptrG3Color[2] = 2;				
				ptrG3Color[3] = 3;				
				ptrG3Color[4] = 4;			
				ptrG3Color[5] = 5;				
				ptrG3Color[6] = 6;				
				ptrG3Color[7] = 7;				
			
				ptrG4Color[0] = 7;
				ptrG4Color[1] = 6;
				ptrG4Color[2] = 5;
				ptrG4Color[3] = 4;
				ptrG4Color[4] = 3;
				ptrG4Color[5] = 2;
				ptrG4Color[6] = 1;
				ptrG4Color[7] = 0;

				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)RGBBright;
				G34BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)RainbowRate;
		}
		else if(G34LightingMode == Rainbow_Waterfall)
		{
				/* Set Color */
				ptrG3_ColorArray = (uint8_t *)RainbowColor;
				ptrG4_ColorArray = (uint8_t *)RainbowColor;
				G34ColorSize = sizeof(RainbowColor) / 3;
				
				ptrG3Color[0] = 0;
				ptrG3Color[1] = 1;
				ptrG3Color[2] = 2;
				ptrG3Color[3] = 3;
				ptrG3Color[4] = 4;
				ptrG3Color[5] = 5;
				ptrG3Color[6] = 6;
				ptrG3Color[7] = 7;
				
				ptrG4Color[0] = 7;
				ptrG4Color[1] = 6;
				ptrG4Color[2] = 5;
				ptrG4Color[3] = 4;
				ptrG4Color[4] = 3;
				ptrG4Color[5] = 2;
				ptrG4Color[6] = 1;
				ptrG4Color[7] = 0;
			
				ptrG34BrightArray = (uint8_t *)RainbowBright;
				G34BrightSize = 51;
				
				ptrG3Bright[0] = 0;
				ptrG3Bright[1] = 46;
				ptrG3Bright[2] = 41;
				ptrG3Bright[3] = 36;
				ptrG3Bright[4] = 31;
				ptrG3Bright[5] = 26;
				ptrG3Bright[6] = 21;
				ptrG3Bright[7] = 16;
				
				ptrG4Bright[0] = 0;
				ptrG4Bright[1] = 46;
				ptrG4Bright[2] = 41;
				ptrG4Bright[3] = 36;
				ptrG4Bright[4] = 31;
				ptrG4Bright[5] = 26;
				ptrG4Bright[6] = 21;
				ptrG4Bright[7] = 16;

				/* Set Rate */
				ptrG34RateArray = (uint8_t *)BreathingRate;
		}
		else if(G34LightingMode == Lighting)
		{			
				/* Set Brightness */
				ptrG34BrightArray = (uint8_t *)RGBBright;
				G34BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrG34RateArray = (uint8_t *)LightingRate;
		}
		
		/* Reset Time Counter */
		G34TimeCounter = 0;
		RandomG3 = 0;
		RandomG4 = 0;
		
		/* Reset Calculated value */
//		G3_R_CMP = 0;
//		G3_G_CMP = 0;
//		G3_B_CMP = 0;
//		G4_R_CMP = 0;
//		G4_G_CMP = 0;
//		G4_B_CMP = 0;
		
		G34TempCal = 8 * *(ptrG34RateArray + G34BreathingSpeed);
}

void G5Mode_Reset(void)
{
		uint8_t i;
	
		/* Stop Timer1 counting */
		TIMER_Stop(TIMER1);
	
		/* Set Color */
		ptrG5_ColorArray = (uint8_t *)G5RGBColor;
		G5ColorSize = 1;
	
		/* Reset Color */
		for(i = 0; i < 8; i ++)
		{
				ptrG5Color[i] = 0;
		}

		/* Reset Bright */
		for(i = 0; i < 8; i ++)
		{		
				ptrG5Bright[i] = 0;
		}

		if(G5LightingMode == Disable)
		{
				/* Set Color */
				ptrG5_ColorArray = (uint8_t *)DisableColor;
				G5ColorSize = sizeof(DisableColor);
			
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)DisableBright;
				G5BrightSize = sizeof(DisableBright);
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)FixedRate;
		}
		else if(G5LightingMode == No_Animation)
		{	
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)RGBBright;
				G5BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)FixedRate;
		}
		else if(G5LightingMode == Breathing)
		{
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)BreathingBright;
				G5BrightSize = sizeof(BreathingBright);
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)BreathingRate;
		}
		else if(G5LightingMode == Flashing)
		{
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)DoubleFlashingBright;
				G5BrightSize = sizeof(DoubleFlashingBright) - 6;
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)DoubleFlashingRate;
		}
		else if(G5LightingMode == Double_Flashing)
		{
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)(DoubleFlashingBright + 6);
				G5BrightSize = sizeof(DoubleFlashingBright) - 6;
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)DoubleFlashingRate;
		}
		else if(G5LightingMode == Meteor)
		{
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)MeteorBright;
				G5BrightSize = 40;

				ptrG5Bright[0] = 55;
				ptrG5Bright[1] = 50;
				ptrG5Bright[2] = 45;
				ptrG5Bright[3] = 40;
				ptrG5Bright[4] = 35;
				ptrG5Bright[5] = 30;
				ptrG5Bright[6] = 25;
				ptrG5Bright[7] = 20;
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)BreathingRate;
		}
		else if((G5LightingMode == Marquees) || (G5LightingMode == ChasingMeteor) || (G5LightingMode == UpDown))
		{
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)MeteorBright;
				G5BrightSize = 55;

				ptrG5Bright[0] = 20;
				ptrG5Bright[1] = 25;
				ptrG5Bright[2] = 30;
				ptrG5Bright[3] = 35;
				ptrG5Bright[4] = 40;
				ptrG5Bright[5] = 45;
				ptrG5Bright[6] = 50;
				ptrG5Bright[7] = 0;
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)BreathingRate;
			
				G5LightingMode = Marquees;
		}
		else if(G5LightingMode == Waterfall)
		{
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)MeteorBright;
				G5BrightSize = 55;

				ptrG5Bright[0] = 0;
				ptrG5Bright[1] = 50;
				ptrG5Bright[2] = 45;
				ptrG5Bright[3] = 40;
				ptrG5Bright[4] = 35;
				ptrG5Bright[5] = 30;
				ptrG5Bright[6] = 25;
				ptrG5Bright[7] = 20;
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)BreathingRate;
		}
		else if(G5LightingMode == Stack)
		{
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)StackBright;
				G5BrightSize = sizeof(StackBright);

				ptrG5Bright[0] = 30;
				ptrG5Bright[1] = 25;
				ptrG5Bright[2] = 20;
				ptrG5Bright[3] = 15;
				ptrG5Bright[4] = 10;
				ptrG5Bright[5] = 5;
				ptrG5Bright[6] = 0;
				ptrG5Bright[7] = 50;
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)BreathingRate;
				
				/* Set cycle counter */
				G5CycleCounter = 50;
		}
		else if(G5LightingMode == Rainbow)
		{
				/* Set Color */
				ptrG5_ColorArray = (uint8_t *)RainbowColor;
				G5ColorSize = sizeof(RainbowColor) / 3;
			
				ptrG5Color[0] = 0;
				ptrG5Color[1] = 1;				
				ptrG5Color[2] = 2;				
				ptrG5Color[3] = 3;				
				ptrG5Color[4] = 4;			
				ptrG5Color[5] = 5;				
				ptrG5Color[6] = 6;				
				ptrG5Color[7] = 7;
			
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)RGBBright;
				G5BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)RainbowRate;
		}
		else if(G5LightingMode == Rainbow_Waterfall)
		{
				/* Set Color */
				ptrG5_ColorArray = (uint8_t *)RainbowColor;
				G5ColorSize = sizeof(RainbowColor) / 3;
			
				ptrG5Color[0] = 0;
				ptrG5Color[1] = 1;
				ptrG5Color[2] = 2;
				ptrG5Color[3] = 3;
				ptrG5Color[4] = 4;
				ptrG5Color[5] = 5;
				ptrG5Color[6] = 6;
				ptrG5Color[7] = 7;
			
				ptrG5BrightArray = (uint8_t *)RainbowBright;
				G5BrightSize = 51;

				ptrG5Bright[0] = 0;
				ptrG5Bright[1] = 46;
				ptrG5Bright[2] = 41;
				ptrG5Bright[3] = 36;
				ptrG5Bright[4] = 31;
				ptrG5Bright[5] = 26;
				ptrG5Bright[6] = 21;
				ptrG5Bright[7] = 16;
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)BreathingRate;
		}
		else if(G5LightingMode == Lighting)
		{			
				/* Set Brightness */
				ptrG5BrightArray = (uint8_t *)RGBBright;
				G5BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrG5RateArray = (uint8_t *)LightingRate;
		}
		
		/* Reset Time Counter */
		G5TimeCounter = 0;
		RandomG5 = 0;
		
		/* Reset Calculated value */
//		G5_R_CMP = 0;
//		G5_G_CMP = 0;
//		G5_B_CMP = 0;
		
		G5TempCal = 8 * *(ptrG5RateArray + G5BreathingSpeed);
}

void RGB1Mode_Reset(void)
{
		uint8_t i;
	
		/* Stop Timer1 counting */
		TIMER_Stop(TIMER1);
	
		/* Set Color */
		ptrRGB1_ColorArray = (uint8_t *)RGB1RGBColor;
		RGB1ColorSize = 1;
	
		/* Reset Color */
		for(i = 0; i < 8; i ++)
		{
				ptrRGB1Color[i] = 0;
		}

		/* Reset Bright */
		for(i = 0; i < 8; i ++)
		{		
				ptrRGB1Bright[i] = 0;
		}

		if(RGB1LightingMode == Disable)
		{
				/* Set Color */
				ptrRGB1_ColorArray = (uint8_t *)DisableColor;
				RGB1ColorSize = sizeof(DisableColor);
			
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)DisableBright;
				RGB1BrightSize = sizeof(DisableBright);
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)FixedRate;
		}
		else if(RGB1LightingMode == No_Animation)
		{	
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)RGBBright;
				RGB1BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)FixedRate;
		}
		else if(RGB1LightingMode == Breathing)
		{
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)BreathingBright;
				RGB1BrightSize = sizeof(BreathingBright);
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)BreathingRate;
		}
		else if(RGB1LightingMode == Flashing)
		{
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)DoubleFlashingBright;
				RGB1BrightSize = sizeof(DoubleFlashingBright) - 6;
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)DoubleFlashingRate;
		}
		else if(RGB1LightingMode == Double_Flashing)
		{
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)(DoubleFlashingBright + 6);
				RGB1BrightSize = sizeof(DoubleFlashingBright) - 6;
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)DoubleFlashingRate;
		}
		else if(RGB1LightingMode == Meteor)
		{
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)MeteorBright;
				RGB1BrightSize = 40;

				ptrRGB1Bright[0] = 55;
				ptrRGB1Bright[1] = 50;
				ptrRGB1Bright[2] = 45;
				ptrRGB1Bright[3] = 40;
				ptrRGB1Bright[4] = 35;
				ptrRGB1Bright[5] = 30;
				ptrRGB1Bright[6] = 25;
				ptrRGB1Bright[7] = 20;
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)BreathingRate;
		}
		else if((RGB1LightingMode == Marquees) || (RGB1LightingMode == ChasingMeteor) || (RGB1LightingMode == UpDown))
		{
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)MeteorBright;
				RGB1BrightSize = 55;

				ptrRGB1Bright[0] = 20;
				ptrRGB1Bright[1] = 25;
				ptrRGB1Bright[2] = 30;
				ptrRGB1Bright[3] = 35;
				ptrRGB1Bright[4] = 40;
				ptrRGB1Bright[5] = 45;
				ptrRGB1Bright[6] = 50;
				ptrRGB1Bright[7] = 0;
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)BreathingRate;
			
				RGB1LightingMode = Marquees;
		}
		else if(RGB1LightingMode == Waterfall)
		{
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)MeteorBright;
				RGB1BrightSize = 55;

				ptrRGB1Bright[0] = 0;
				ptrRGB1Bright[1] = 50;
				ptrRGB1Bright[2] = 45;
				ptrRGB1Bright[3] = 40;
				ptrRGB1Bright[4] = 35;
				ptrRGB1Bright[5] = 30;
				ptrRGB1Bright[6] = 25;
				ptrRGB1Bright[7] = 20;
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)BreathingRate;
		}
		else if(RGB1LightingMode == Stack)
		{
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)StackBright;
				RGB1BrightSize = sizeof(StackBright);

				ptrRGB1Bright[0] = 30;
				ptrRGB1Bright[1] = 25;
				ptrRGB1Bright[2] = 20;
				ptrRGB1Bright[3] = 15;
				ptrRGB1Bright[4] = 10;
				ptrRGB1Bright[5] = 5;
				ptrRGB1Bright[6] = 0;
				ptrRGB1Bright[7] = 50;
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)BreathingRate;
				
				/* Set cycle counter */
				RGB1CycleCounter = 50;
		}
		else if(RGB1LightingMode == Rainbow)
		{
				/* Set Color */
				ptrRGB1_ColorArray = (uint8_t *)RainbowColor;
				RGB1ColorSize = sizeof(RainbowColor) / 3;
			
				ptrRGB1Color[0] = 0;
				ptrRGB1Color[1] = 1;				
				ptrRGB1Color[2] = 2;				
				ptrRGB1Color[3] = 3;				
				ptrRGB1Color[4] = 4;			
				ptrRGB1Color[5] = 5;				
				ptrRGB1Color[6] = 6;				
				ptrRGB1Color[7] = 7;
			
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)RGBBright;
				RGB1BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)RainbowRate;
		}
		else if(RGB1LightingMode == Rainbow_Waterfall)
		{
				/* Set Color */
				ptrRGB1_ColorArray = (uint8_t *)RainbowColor;
				RGB1ColorSize = sizeof(RainbowColor) / 3;
			
				ptrRGB1Color[0] = 0;
				ptrRGB1Color[1] = 1;
				ptrRGB1Color[2] = 2;
				ptrRGB1Color[3] = 3;
				ptrRGB1Color[4] = 4;
				ptrRGB1Color[5] = 5;
				ptrRGB1Color[6] = 6;
				ptrRGB1Color[7] = 7;
			
				ptrRGB1BrightArray = (uint8_t *)RainbowBright;
				RGB1BrightSize = 51;

				ptrRGB1Bright[0] = 0;
				ptrRGB1Bright[1] = 46;
				ptrRGB1Bright[2] = 41;
				ptrRGB1Bright[3] = 36;
				ptrRGB1Bright[4] = 31;
				ptrRGB1Bright[5] = 26;
				ptrRGB1Bright[6] = 21;
				ptrRGB1Bright[7] = 16;
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)BreathingRate;
		}
		else if(RGB1LightingMode == Lighting)
		{			
				/* Set Brightness */
				ptrRGB1BrightArray = (uint8_t *)RGBBright;
				RGB1BrightSize = sizeof(RGBBright);
				
				/* Set Rate */
				ptrRGB1RateArray = (uint8_t *)LightingRate;
		}
		
		/* Reset Time Counter */
		RGB1TimeCounter = 0;
		RandomRGB1 = 0;
		
		/* Reset Calculated value */
//		RGB1_R_CMP = 0;
//		RGB1_G_CMP = 0;
//		RGB1_B_CMP = 0;
		
		RGB1TempCal = 8 * *(ptrRGB1RateArray + RGB1BreathingSpeed);
}

void G12_Change(void)
{
		uint8_t i;
	
		if(G12TimeCounter == (G12TempCal * G12BrightSize))
		{
				switch(G12LightingMode)
				{
						case Marquees:
						{
								if(ptrG1Bright[0] == 55)
								{
										ptrG1Bright[0] = 60;
										ptrG1Bright[1] = 65;
										ptrG1Bright[2] = 70;
										ptrG1Bright[3] = 75;
										ptrG1Bright[4] = 80;
										ptrG1Bright[5] = 85;
										ptrG1Bright[6] = 90;
										ptrG1Bright[7] = 0;
										
										ptrG2Bright[0] = 55;
										ptrG2Bright[1] = 50;
										ptrG2Bright[2] = 45;
										ptrG2Bright[3] = 40;
										ptrG2Bright[4] = 35;
										ptrG2Bright[5] = 30;
										ptrG2Bright[6] = 25;
										ptrG2Bright[7] = 20;
								}
								else
								{
										ptrG1Bright[0] = 55;
										ptrG1Bright[1] = 50;
										ptrG1Bright[2] = 45;
										ptrG1Bright[3] = 40;
										ptrG1Bright[4] = 35;
										ptrG1Bright[5] = 30;
										ptrG1Bright[6] = 25;
										ptrG1Bright[7] = 20;
										
										ptrG2Bright[0] = 60;
										ptrG2Bright[1] = 65;
										ptrG2Bright[2] = 70;
										ptrG2Bright[3] = 75;
										ptrG2Bright[4] = 80;
										ptrG2Bright[5] = 85;
										ptrG2Bright[6] = 90;
										ptrG2Bright[7] = 0;
								}
								G12TimeCounter = 0;
								break;
						}
						case UpDown:
						{
								if(ptrG1Bright[0] == 20)
								{
										ptrG1Bright[0] = 0;
										ptrG1Bright[1] = 50;
										ptrG1Bright[2] = 45;
										ptrG1Bright[3] = 40;
										ptrG1Bright[4] = 35;
										ptrG1Bright[5] = 30;
										ptrG1Bright[6] = 25;
										ptrG1Bright[7] = 20;
										
										ptrG2Bright[0] = 0;
										ptrG2Bright[1] = 50;
										ptrG2Bright[2] = 45;
										ptrG2Bright[3] = 40;
										ptrG2Bright[4] = 35;
										ptrG2Bright[5] = 30;
										ptrG2Bright[6] = 25;
										ptrG2Bright[7] = 20;
								}
								else
								{
										ptrG1Bright[0] = 20;
										ptrG1Bright[1] = 25;
										ptrG1Bright[2] = 30;
										ptrG1Bright[3] = 35;
										ptrG1Bright[4] = 40;
										ptrG1Bright[5] = 45;
										ptrG1Bright[6] = 50;
										ptrG1Bright[7] = 0;
									
										ptrG2Bright[0] = 20;
										ptrG2Bright[1] = 25;
										ptrG2Bright[2] = 30;
										ptrG2Bright[3] = 35;
										ptrG2Bright[4] = 40;
										ptrG2Bright[5] = 45;
										ptrG2Bright[6] = 50;
										ptrG2Bright[7] = 0;
								}
								G12TimeCounter = 0;
								break;
						}
						case Lighting:
						{
								if(*ptrG12RateArray == 20)
								{
										for(i = 0; i < 8; i++)
										{
												/* Chagne color for lighting */
												if((RandomG1 >> i) & 0x1)
														ptrG1Color[i] = 3;
												else
														ptrG1Color[i] = 0;
												
												if((RandomG2 >> i) & 0x1)
														ptrG2Color[i] = 3;
												else
														ptrG2Color[i] = 0;
										}
										G12ColorSize = 2;
									
										/* Set Rate */
										ptrG12RateArray = (uint8_t *)DoubleFlashingRate;
								}
								else
								{
										for(i = 0; i < 8; i++)
										{
												/* Reset  color for RGBColor */
												ptrG1Color[i] = 0;
												ptrG2Color[i] = 0;
										}
										G12ColorSize = 1;
										
										/* Set Rate */
										ptrG12RateArray = (uint8_t *)LightingRate;
									
										RandomG1 = rand() % 256;
										RandomG2 = rand() % 256;
								}
								G12TimeCounter = 0;
								break;
						}
				}
		}

		if((G12LightingMode == Stack) && (G12TimeCounter == (G12TempCal * G12CycleCounter)))
		{
				if(ptrG2Bright[7] == 105)
				{
						ptrG1Bright[0] = 30;
						ptrG1Bright[1] = 25;
						ptrG1Bright[2] = 20;
						ptrG1Bright[3] = 15;
						ptrG1Bright[4] = 10;
						ptrG1Bright[5] = 5;
						ptrG1Bright[6] = 0;
						ptrG1Bright[7] = 50;
						
						ptrG2Bright[0] = 30;
						ptrG2Bright[1] = 25;
						ptrG2Bright[2] = 20;
						ptrG2Bright[3] = 15;
						ptrG2Bright[4] = 10;
						ptrG2Bright[5] = 5;
						ptrG2Bright[6] = 0;
						ptrG2Bright[7] = 50;
					
						/* Set cycle counter */
						G12CycleCounter = 50;
				}
				else if(ptrG2Bright[0] == 85)
				{
						/* Set Brightness */
						ptrG1Bright[0] = 140;
						ptrG1Bright[1] = 135;
						ptrG1Bright[2] = 130;
						ptrG1Bright[3] = 125;
						ptrG1Bright[4] = 120;
						ptrG1Bright[5] = 115;
						ptrG1Bright[6] = 110;
						ptrG1Bright[7] = 105;
					
						ptrG2Bright[0] = 140;
						ptrG2Bright[1] = 135;
						ptrG2Bright[2] = 130;
						ptrG2Bright[3] = 125;
						ptrG2Bright[4] = 120;
						ptrG2Bright[5] = 115;
						ptrG2Bright[6] = 110;
						ptrG2Bright[7] = 105;
						
						/* Set cycle counter */
						G12CycleCounter = 40;
				}
				else if(ptrG2Bright[1] == 80)
				{
						/* Set Brightness */
						ptrG1Bright[0] = 85;
						ptrG1Bright[1] = 95;
						ptrG1Bright[2] = 95;
						ptrG1Bright[3] = 95;
						ptrG1Bright[4] = 95;
						ptrG1Bright[5] = 95;
						ptrG1Bright[6] = 95;
						ptrG1Bright[7] = 95;
					
						ptrG2Bright[0] = 85;
						ptrG2Bright[1] = 95;
						ptrG2Bright[2] = 95;
						ptrG2Bright[3] = 95;
						ptrG2Bright[4] = 95;
						ptrG2Bright[5] = 95;
						ptrG2Bright[6] = 95;
						ptrG2Bright[7] = 95;

						/* Set cycle counter */
						G12CycleCounter = 15;
				}
				else if(ptrG2Bright[2] == 75)
				{
						/* Set Brightness */
						ptrG1Bright[0] = 30;
						ptrG1Bright[1] = 80;
						ptrG1Bright[2] = 95;
						ptrG1Bright[3] = 95;
						ptrG1Bright[4] = 95;
						ptrG1Bright[5] = 95;
						ptrG1Bright[6] = 95;
						ptrG1Bright[7] = 95;
						
						ptrG2Bright[0] = 30;
						ptrG2Bright[1] = 80;
						ptrG2Bright[2] = 95;
						ptrG2Bright[3] = 95;
						ptrG2Bright[4] = 95;
						ptrG2Bright[5] = 95;
						ptrG2Bright[6] = 95;
						ptrG2Bright[7] = 95;

						/* Set cycle counter */
						G12CycleCounter = 20;
				}
				else if(ptrG2Bright[3] == 70)
				{
						/* Set Brightness */
						ptrG1Bright[0] = 30;
						ptrG1Bright[1] = 25;
						ptrG1Bright[2] = 75;
						ptrG1Bright[3] = 95;
						ptrG1Bright[4] = 95;
						ptrG1Bright[5] = 95;
						ptrG1Bright[6] = 95;
						ptrG1Bright[7] = 95;
						
						ptrG2Bright[0] = 30;
						ptrG2Bright[1] = 25;
						ptrG2Bright[2] = 75;
						ptrG2Bright[3] = 95;
						ptrG2Bright[4] = 95;
						ptrG2Bright[5] = 95;
						ptrG2Bright[6] = 95;
						ptrG2Bright[7] = 95;
						
						/* Set cycle counter */
						G12CycleCounter = 25;
				}
				else if(ptrG2Bright[4] == 65)
				{
						/* Set Brightness */
						ptrG1Bright[0] = 30;
						ptrG1Bright[1] = 25;
						ptrG1Bright[2] = 20;
						ptrG1Bright[3] = 70;
						ptrG1Bright[4] = 95;
						ptrG1Bright[5] = 95;
						ptrG1Bright[6] = 95;
						ptrG1Bright[7] = 95;
					
						ptrG2Bright[0] = 30;
						ptrG2Bright[1] = 25;
						ptrG2Bright[2] = 20;
						ptrG2Bright[3] = 70;
						ptrG2Bright[4] = 95;
						ptrG2Bright[5] = 95;
						ptrG2Bright[6] = 95;
						ptrG2Bright[7] = 95;
						
						/* Set cycle counter */
						G12CycleCounter = 30;
				}
				else if(ptrG2Bright[5] == 60)
				{
						/* Set Brightness */
						ptrG1Bright[0] = 30;
						ptrG1Bright[1] = 25;
						ptrG1Bright[2] = 20;
						ptrG1Bright[3] = 15;
						ptrG1Bright[4] = 65;
						ptrG1Bright[5] = 95;
						ptrG1Bright[6] = 95;
						ptrG1Bright[7] = 95;
						
						ptrG2Bright[0] = 30;
						ptrG2Bright[1] = 25;
						ptrG2Bright[2] = 20;
						ptrG2Bright[3] = 15;
						ptrG2Bright[4] = 65;
						ptrG2Bright[5] = 95;
						ptrG2Bright[6] = 95;
						ptrG2Bright[7] = 95;

						/* Set cycle counter */
						G12CycleCounter = 35;
				}
				else if(ptrG2Bright[6] == 55)
				{
						/* Set Brightness */
						ptrG1Bright[0] = 30;
						ptrG1Bright[1] = 25;
						ptrG1Bright[2] = 20;
						ptrG1Bright[3] = 15;
						ptrG1Bright[4] = 10;
						ptrG1Bright[5] = 60;
						ptrG1Bright[6] = 95;
						ptrG1Bright[7] = 95;
						
						ptrG2Bright[0] = 30;
						ptrG2Bright[1] = 25;
						ptrG2Bright[2] = 20;
						ptrG2Bright[3] = 15;
						ptrG2Bright[4] = 10;
						ptrG2Bright[5] = 60;
						ptrG2Bright[6] = 95;
						ptrG2Bright[7] = 95;

						/* Set cycle counter */
						G12CycleCounter = 40;
				}
				else if(ptrG2Bright[7] == 50)
				{
						/* Set Brightness */
						ptrG1Bright[0] = 30;
						ptrG1Bright[1] = 25;
						ptrG1Bright[2] = 20;
						ptrG1Bright[3] = 15;
						ptrG1Bright[4] = 10;
						ptrG1Bright[5] = 5;
						ptrG1Bright[6] = 55;
						ptrG1Bright[7] = 95;
															
						ptrG2Bright[0] = 30;
						ptrG2Bright[1] = 25;
						ptrG2Bright[2] = 20;
						ptrG2Bright[3] = 15;
						ptrG2Bright[4] = 10;
						ptrG2Bright[5] = 5;
						ptrG2Bright[6] = 55;
						ptrG2Bright[7] = 95;

						/* Set cycle counter */
						G12CycleCounter = 45;
				}
				G12TimeCounter = 0;
		}
}

void G34_Change(void)
{
		uint8_t i;
	
		if(G34TimeCounter == (G34TempCal * G34BrightSize))
		{
				switch(G34LightingMode)
				{
						case Marquees:
						{
								if(ptrG3Bright[0] == 55)
								{
										ptrG3Bright[0] = 60;
										ptrG3Bright[1] = 65;
										ptrG3Bright[2] = 70;
										ptrG3Bright[3] = 75;
										ptrG3Bright[4] = 80;
										ptrG3Bright[5] = 85;
										ptrG3Bright[6] = 90;
										ptrG3Bright[7] = 0;
										
										ptrG4Bright[0] = 55;
										ptrG4Bright[1] = 50;
										ptrG4Bright[2] = 45;
										ptrG4Bright[3] = 40;
										ptrG4Bright[4] = 35;
										ptrG4Bright[5] = 30;
										ptrG4Bright[6] = 25;
										ptrG4Bright[7] = 20;
								}
								else
								{
										ptrG3Bright[0] = 55;
										ptrG3Bright[1] = 50;
										ptrG3Bright[2] = 45;
										ptrG3Bright[3] = 40;
										ptrG3Bright[4] = 35;
										ptrG3Bright[5] = 30;
										ptrG3Bright[6] = 25;
										ptrG3Bright[7] = 20;
										
										ptrG4Bright[0] = 60;
										ptrG4Bright[1] = 65;
										ptrG4Bright[2] = 70;
										ptrG4Bright[3] = 75;
										ptrG4Bright[4] = 80;
										ptrG4Bright[5] = 85;
										ptrG4Bright[6] = 90;
										ptrG4Bright[7] = 0;
								}
								G34TimeCounter = 0;
								break;
						}
						case UpDown:
						{
								if(ptrG3Bright[0] == 20)
								{
										ptrG3Bright[0] = 0;
										ptrG3Bright[1] = 50;
										ptrG3Bright[2] = 45;
										ptrG3Bright[3] = 40;
										ptrG3Bright[4] = 35;
										ptrG3Bright[5] = 30;
										ptrG3Bright[6] = 25;
										ptrG3Bright[7] = 20;
										
										ptrG4Bright[0] = 0;
										ptrG4Bright[1] = 50;
										ptrG4Bright[2] = 45;
										ptrG4Bright[3] = 40;
										ptrG4Bright[4] = 35;
										ptrG4Bright[5] = 30;
										ptrG4Bright[6] = 25;
										ptrG4Bright[7] = 20;
								}
								else
								{
										ptrG3Bright[0] = 20;
										ptrG3Bright[1] = 25;
										ptrG3Bright[2] = 30;
										ptrG3Bright[3] = 35;
										ptrG3Bright[4] = 40;
										ptrG3Bright[5] = 45;
										ptrG3Bright[6] = 50;
										ptrG3Bright[7] = 0;
									
										ptrG4Bright[0] = 20;
										ptrG4Bright[1] = 25;
										ptrG4Bright[2] = 30;
										ptrG4Bright[3] = 35;
										ptrG4Bright[4] = 40;
										ptrG4Bright[5] = 45;
										ptrG4Bright[6] = 50;
										ptrG4Bright[7] = 0;
								}
								G34TimeCounter = 0;
								break;
						}
						case Lighting:
						{
								if(*ptrG34RateArray == 20)
								{
										for(i = 0; i < 8; i++)
										{
												/* Chagne color for lighting */
												if((RandomG3 >> i) & 0x1)
														ptrG3Color[i] = 3;
												else
														ptrG3Color[i] = 0;
												
												if((RandomG4 >> i) & 0x1)
														ptrG4Color[i] = 3;
												else
														ptrG4Color[i] = 0;
										}
										G34ColorSize = 2;
									
										/* Set Rate */
										ptrG34RateArray = (uint8_t *)DoubleFlashingRate;
								}
								else
								{
										for(i = 0; i < 8; i++)
										{
												/* Reset  color for RGBColor */
												ptrG3Color[i] = 0;
												ptrG4Color[i] = 0;
										}
										G34ColorSize = 1;
										
										/* Set Rate */
										ptrG34RateArray = (uint8_t *)LightingRate;
									
										RandomG3 = rand() % 256;
										RandomG4 = rand() % 256;
								}
								G34TimeCounter = 0;
								break;
						}
				}
		}
		
		if((G34LightingMode == Stack) && (G34TimeCounter ==  (G34TempCal * G34CycleCounter)))
		{
				if(ptrG4Bright[7] == 105)
				{
						ptrG3Bright[0] = 30;
						ptrG3Bright[1] = 25;
						ptrG3Bright[2] = 20;
						ptrG3Bright[3] = 15;
						ptrG3Bright[4] = 10;
						ptrG3Bright[5] = 5;
						ptrG3Bright[6] = 0;
						ptrG3Bright[7] = 50;
						
						ptrG4Bright[0] = 30;
						ptrG4Bright[1] = 25;
						ptrG4Bright[2] = 20;
						ptrG4Bright[3] = 15;
						ptrG4Bright[4] = 10;
						ptrG4Bright[5] = 5;
						ptrG4Bright[6] = 0;
						ptrG4Bright[7] = 50;

						/* Set cycle counter */
						G34CycleCounter = 50;
				}
				else if(ptrG4Bright[0] == 85)
				{
						/* Set Brightness */
						ptrG3Bright[0] = 140;
						ptrG3Bright[1] = 135;
						ptrG3Bright[2] = 130;
						ptrG3Bright[3] = 125;
						ptrG3Bright[4] = 120;
						ptrG3Bright[5] = 115;
						ptrG3Bright[6] = 110;
						ptrG3Bright[7] = 105;
					
						ptrG4Bright[0] = 140;
						ptrG4Bright[1] = 135;
						ptrG4Bright[2] = 130;
						ptrG4Bright[3] = 125;
						ptrG4Bright[4] = 120;
						ptrG4Bright[5] = 115;
						ptrG4Bright[6] = 110;
						ptrG4Bright[7] = 105;

						/* Set cycle counter */
						G34CycleCounter = 40;
				}
				else if(ptrG4Bright[1] == 80)
				{
						/* Set Brightness */
						ptrG3Bright[0] = 85;
						ptrG3Bright[1] = 95;
						ptrG3Bright[2] = 95;
						ptrG3Bright[3] = 95;
						ptrG3Bright[4] = 95;
						ptrG3Bright[5] = 95;
						ptrG3Bright[6] = 95;
						ptrG3Bright[7] = 95;
					
						ptrG4Bright[0] = 85;
						ptrG4Bright[1] = 95;
						ptrG4Bright[2] = 95;
						ptrG4Bright[3] = 95;
						ptrG4Bright[4] = 95;
						ptrG4Bright[5] = 95;
						ptrG4Bright[6] = 95;
						ptrG4Bright[7] = 95;
					
						/* Set cycle counter */
						G34CycleCounter = 15;
				}
				else if(ptrG4Bright[2] == 75)
				{
						/* Set Brightness */
						ptrG3Bright[0] = 30;
						ptrG3Bright[1] = 80;
						ptrG3Bright[2] = 95;
						ptrG3Bright[3] = 95;
						ptrG3Bright[4] = 95;
						ptrG3Bright[5] = 95;
						ptrG3Bright[6] = 95;
						ptrG3Bright[7] = 95;
						
						ptrG4Bright[0] = 30;
						ptrG4Bright[1] = 80;
						ptrG4Bright[2] = 95;
						ptrG4Bright[3] = 95;
						ptrG4Bright[4] = 95;
						ptrG4Bright[5] = 95;
						ptrG4Bright[6] = 95;
						ptrG4Bright[7] = 95;
						
						/* Set cycle counter */
						G34CycleCounter = 20;
				}
				else if(ptrG4Bright[3] == 70)
				{
						/* Set Brightness */
						ptrG3Bright[0] = 30;
						ptrG3Bright[1] = 25;
						ptrG3Bright[2] = 75;
						ptrG3Bright[3] = 95;
						ptrG3Bright[4] = 95;
						ptrG3Bright[5] = 95;
						ptrG3Bright[6] = 95;
						ptrG3Bright[7] = 95;
						
						ptrG4Bright[0] = 30;
						ptrG4Bright[1] = 25;
						ptrG4Bright[2] = 75;
						ptrG4Bright[3] = 95;
						ptrG4Bright[4] = 95;
						ptrG4Bright[5] = 95;
						ptrG4Bright[6] = 95;
						ptrG4Bright[7] = 95;

						/* Set cycle counter */
						G34CycleCounter = 25;
				}
				else if(ptrG4Bright[4] == 65)
				{
						/* Set Brightness */
						ptrG3Bright[0] = 30;
						ptrG3Bright[1] = 25;
						ptrG3Bright[2] = 20;
						ptrG3Bright[3] = 70;
						ptrG3Bright[4] = 95;
						ptrG3Bright[5] = 95;
						ptrG3Bright[6] = 95;
						ptrG3Bright[7] = 95;
					
						ptrG4Bright[0] = 30;
						ptrG4Bright[1] = 25;
						ptrG4Bright[2] = 20;
						ptrG4Bright[3] = 70;
						ptrG4Bright[4] = 95;
						ptrG4Bright[5] = 95;
						ptrG4Bright[6] = 95;
						ptrG4Bright[7] = 95;
						
						/* Set cycle counter */
						G34CycleCounter = 30;
				}
				else if(ptrG4Bright[5] == 60)
				{
						/* Set Brightness */
						ptrG3Bright[0] = 30;
						ptrG3Bright[1] = 25;
						ptrG3Bright[2] = 20;
						ptrG3Bright[3] = 15;
						ptrG3Bright[4] = 65;
						ptrG3Bright[5] = 95;
						ptrG3Bright[6] = 95;
						ptrG3Bright[7] = 95;
						
						ptrG4Bright[0] = 30;
						ptrG4Bright[1] = 25;
						ptrG4Bright[2] = 20;
						ptrG4Bright[3] = 15;
						ptrG4Bright[4] = 65;
						ptrG4Bright[5] = 95;
						ptrG4Bright[6] = 95;
						ptrG4Bright[7] = 95;

						/* Set cycle counter */
						G34CycleCounter = 35;
				}
				else if(ptrG4Bright[6] == 55)
				{
						/* Set Brightness */
						ptrG3Bright[0] = 30;
						ptrG3Bright[1] = 25;
						ptrG3Bright[2] = 20;
						ptrG3Bright[3] = 15;
						ptrG3Bright[4] = 10;
						ptrG3Bright[5] = 60;
						ptrG3Bright[6] = 95;
						ptrG3Bright[7] = 95;
						
						ptrG4Bright[0] = 30;
						ptrG4Bright[1] = 25;
						ptrG4Bright[2] = 20;
						ptrG4Bright[3] = 15;
						ptrG4Bright[4] = 10;
						ptrG4Bright[5] = 60;
						ptrG4Bright[6] = 95;
						ptrG4Bright[7] = 95;

						/* Set cycle counter */
						G34CycleCounter = 40;
				}
				else if(ptrG4Bright[7] == 50)
				{
						/* Set Brightness */
						ptrG3Bright[0] = 30;
						ptrG3Bright[1] = 25;
						ptrG3Bright[2] = 20;
						ptrG3Bright[3] = 15;
						ptrG3Bright[4] = 10;
						ptrG3Bright[5] = 5;
						ptrG3Bright[6] = 55;
						ptrG3Bright[7] = 95;
															
						ptrG4Bright[0] = 30;
						ptrG4Bright[1] = 25;
						ptrG4Bright[2] = 20;
						ptrG4Bright[3] = 15;
						ptrG4Bright[4] = 10;
						ptrG4Bright[5] = 5;
						ptrG4Bright[6] = 55;
						ptrG4Bright[7] = 95;

						/* Set cycle counter */
						G34CycleCounter = 45;
				}
				G34TimeCounter = 0;
		}
}

void G5_Change(void)
{
		uint8_t i;
	
		if(G5TimeCounter == (G5TempCal * G5BrightSize))
		{
				switch(G5LightingMode)
				{
						case Marquees:
						{
								if(ptrG5Bright[0] == 20)
								{
										ptrG5Bright[0] = 0;
										ptrG5Bright[1] = 50;
										ptrG5Bright[2] = 45;
										ptrG5Bright[3] = 40;
										ptrG5Bright[4] = 35;
										ptrG5Bright[5] = 30;
										ptrG5Bright[6] = 25;
										ptrG5Bright[7] = 20;
								}
								else
								{	
										ptrG5Bright[0] = 20;
										ptrG5Bright[1] = 25;
										ptrG5Bright[2] = 30;
										ptrG5Bright[3] = 35;
										ptrG5Bright[4] = 40;
										ptrG5Bright[5] = 45;
										ptrG5Bright[6] = 50;
										ptrG5Bright[7] = 0;
								}
								G5TimeCounter = 0;
								break;
						}
						case UpDown:
						{
								if(ptrG5Bright[0] == 20)
								{
										ptrG5Bright[0] = 0;
										ptrG5Bright[1] = 50;
										ptrG5Bright[2] = 45;
										ptrG5Bright[3] = 40;
										ptrG5Bright[4] = 35;
										ptrG5Bright[5] = 30;
										ptrG5Bright[6] = 25;
										ptrG5Bright[7] = 20;
								}
								else
								{
										ptrG5Bright[0] = 20;
										ptrG5Bright[1] = 25;
										ptrG5Bright[2] = 30;
										ptrG5Bright[3] = 35;
										ptrG5Bright[4] = 40;
										ptrG5Bright[5] = 45;
										ptrG5Bright[6] = 50;
										ptrG5Bright[7] = 0;
								}
								G5TimeCounter = 0;
								break;
						}
						case Lighting:
						{
								if(*ptrG5RateArray == 20)
								{
										for(i = 0; i < 8; i++)
										{
												/* Chagne color for lighting */
												if((RandomG5 >> i) & 0x1)
														ptrG5Color[i] = 3;
												else
														ptrG5Color[i] = 0;
										}
										G5ColorSize = 2;
									
										/* Set Rate */
										ptrG5RateArray = (uint8_t *)DoubleFlashingRate;
								}
								else
								{
										for(i = 0; i < 8; i++)
										{
												/* Reset  color for RGBColor */
												ptrG5Color[i] = 0;
										}
										G5ColorSize = 1;
										
										/* Set Rate */
										ptrG5RateArray = (uint8_t *)LightingRate;
									
										RandomG5 = rand() % 256;
								}
								G5TimeCounter = 0;
								break;
						}
				}
		}
		
		if((G5LightingMode == Stack) && (G5TimeCounter ==  (G5TempCal * G5CycleCounter)))
		{
				if(ptrG5Bright[7] == 105)
				{
						ptrG5Bright[0] = 30;
						ptrG5Bright[1] = 25;
						ptrG5Bright[2] = 20;
						ptrG5Bright[3] = 15;
						ptrG5Bright[4] = 10;
						ptrG5Bright[5] = 5;
						ptrG5Bright[6] = 0;
						ptrG5Bright[7] = 50;

						/* Set cycle counter */
						G5CycleCounter = 50;
				}
				else if(ptrG5Bright[0] == 85)
				{
						/* Set Brightness */
						ptrG5Bright[0] = 140;
						ptrG5Bright[1] = 135;
						ptrG5Bright[2] = 130;
						ptrG5Bright[3] = 125;
						ptrG5Bright[4] = 120;
						ptrG5Bright[5] = 115;
						ptrG5Bright[6] = 110;
						ptrG5Bright[7] = 105;
						
						/* Set cycle counter */
						G5CycleCounter = 40;
				}
				else if(ptrG5Bright[1] == 80)
				{
						/* Set Brightness */
						ptrG5Bright[0] = 85;
						ptrG5Bright[1] = 95;
						ptrG5Bright[2] = 95;
						ptrG5Bright[3] = 95;
						ptrG5Bright[4] = 95;
						ptrG5Bright[5] = 95;
						ptrG5Bright[6] = 95;
						ptrG5Bright[7] = 95;

						/* Set cycle counter */
						G5CycleCounter = 15;
				}
				else if(ptrG5Bright[2] == 75)
				{
						/* Set Brightness */
						ptrG5Bright[0] = 30;
						ptrG5Bright[1] = 80;
						ptrG5Bright[2] = 95;
						ptrG5Bright[3] = 95;
						ptrG5Bright[4] = 95;
						ptrG5Bright[5] = 95;
						ptrG5Bright[6] = 95;
						ptrG5Bright[7] = 95;

						/* Set cycle counter */
						G5CycleCounter = 20;
				}
				else if(ptrG5Bright[3] == 70)
				{
						/* Set Brightness */
						ptrG5Bright[0] = 30;
						ptrG5Bright[1] = 25;
						ptrG5Bright[2] = 75;
						ptrG5Bright[3] = 95;
						ptrG5Bright[4] = 95;
						ptrG5Bright[5] = 95;
						ptrG5Bright[6] = 95;
						ptrG5Bright[7] = 95;
						
						/* Set cycle counter */
						G5CycleCounter = 25;
				}
				else if(ptrG5Bright[4] == 65)
				{
						/* Set Brightness */
						ptrG5Bright[0] = 30;
						ptrG5Bright[1] = 25;
						ptrG5Bright[2] = 20;
						ptrG5Bright[3] = 70;
						ptrG5Bright[4] = 95;
						ptrG5Bright[5] = 95;
						ptrG5Bright[6] = 95;
						ptrG5Bright[7] = 95;
						
						/* Set cycle counter */
						G5CycleCounter = 30;
				}
				else if(ptrG5Bright[5] == 60)
				{
						/* Set Brightness */
						ptrG5Bright[0] = 30;
						ptrG5Bright[1] = 25;
						ptrG5Bright[2] = 20;
						ptrG5Bright[3] = 15;
						ptrG5Bright[4] = 65;
						ptrG5Bright[5] = 95;
						ptrG5Bright[6] = 95;
						ptrG5Bright[7] = 95;

						/* Set cycle counter */
						G5CycleCounter = 35;
				}
				else if(ptrG5Bright[6] == 55)
				{
						/* Set Brightness */
						ptrG5Bright[0] = 30;
						ptrG5Bright[1] = 25;
						ptrG5Bright[2] = 20;
						ptrG5Bright[3] = 15;
						ptrG5Bright[4] = 10;
						ptrG5Bright[5] = 60;
						ptrG5Bright[6] = 95;
						ptrG5Bright[7] = 95;
						
						/* Set cycle counter */
						G5CycleCounter = 40;
				}
				else if(ptrG5Bright[7] == 50)
				{
						/* Set Brightness */
						ptrG5Bright[0] = 30;
						ptrG5Bright[1] = 25;
						ptrG5Bright[2] = 20;
						ptrG5Bright[3] = 15;
						ptrG5Bright[4] = 10;
						ptrG5Bright[5] = 5;
						ptrG5Bright[6] = 55;
						ptrG5Bright[7] = 95;
						
						/* Set cycle counter */
						G5CycleCounter = 45;
				}
				G5TimeCounter = 0;
		}
}

void RGB1_Change(void)
{
		uint8_t i;

		if(RGB1TimeCounter == (RGB1TempCal * RGB1BrightSize))
		{
				switch(RGB1LightingMode)
				{
						case Marquees:
						{
								if(ptrRGB1Bright[0] == 55)
								{
										ptrRGB1Bright[0] = 60;
										ptrRGB1Bright[1] = 65;
										ptrRGB1Bright[2] = 70;
										ptrRGB1Bright[3] = 75;
										ptrRGB1Bright[4] = 80;
										ptrRGB1Bright[5] = 85;
										ptrRGB1Bright[6] = 90;
										ptrRGB1Bright[7] = 0;
								}
								else
								{	
										ptrRGB1Bright[0] = 55;
										ptrRGB1Bright[1] = 50;
										ptrRGB1Bright[2] = 45;
										ptrRGB1Bright[3] = 40;
										ptrRGB1Bright[4] = 35;
										ptrRGB1Bright[5] = 30;
										ptrRGB1Bright[6] = 25;
										ptrRGB1Bright[7] = 20;
								}
								RGB1TimeCounter = 0;
								break;
						}
						case UpDown:
						{
								if(ptrRGB1Bright[0] == 20)
								{
										ptrRGB1Bright[0] = 0;
										ptrRGB1Bright[1] = 50;
										ptrRGB1Bright[2] = 45;
										ptrRGB1Bright[3] = 40;
										ptrRGB1Bright[4] = 35;
										ptrRGB1Bright[5] = 30;
										ptrRGB1Bright[6] = 25;
										ptrRGB1Bright[7] = 20;
								}
								else
								{
										ptrRGB1Bright[0] = 20;
										ptrRGB1Bright[1] = 25;
										ptrRGB1Bright[2] = 30;
										ptrRGB1Bright[3] = 35;
										ptrRGB1Bright[4] = 40;
										ptrRGB1Bright[5] = 45;
										ptrRGB1Bright[6] = 50;
										ptrRGB1Bright[7] = 0;
								}
								RGB1TimeCounter = 0;
								break;
						}
						case Lighting:
						{
								if(*ptrRGB1RateArray == 20)
								{
										for(i = 0; i < 8; i++)
										{
												/* Chagne color for lighting */
												if((RandomRGB1 >> i) & 0x1)
														ptrRGB1Color[i] = 3;
												else
														ptrRGB1Color[i] = 0;
										}
										RGB1ColorSize = 2;
									
										/* Set Rate */
										ptrRGB1RateArray = (uint8_t *)DoubleFlashingRate;
								}
								else
								{
										for(i = 0; i < 8; i++)
										{
												/* Reset  color for RGBColor */
												ptrRGB1Color[i] = 0;
										}
										RGB1ColorSize = 1;
										
										/* Set Rate */
										ptrRGB1RateArray = (uint8_t *)LightingRate;
									
										RandomRGB1 = rand() % 256;
								}
								RGB1TimeCounter = 0;
								break;
						}
				}
		}
		
		if((RGB1LightingMode == Stack) && (RGB1TimeCounter ==  (RGB1TempCal * RGB1CycleCounter)))
		{
				if(ptrRGB1Bright[7] == 105)
				{
						ptrRGB1Bright[0] = 30;
						ptrRGB1Bright[1] = 25;
						ptrRGB1Bright[2] = 20;
						ptrRGB1Bright[3] = 15;
						ptrRGB1Bright[4] = 10;
						ptrRGB1Bright[5] = 5;
						ptrRGB1Bright[6] = 0;
						ptrRGB1Bright[7] = 50;

						/* Set cycle counter */
						RGB1CycleCounter = 50;
				}
				else if(ptrRGB1Bright[0] == 85)
				{
						/* Set Brightness */
						ptrRGB1Bright[0] = 140;
						ptrRGB1Bright[1] = 135;
						ptrRGB1Bright[2] = 130;
						ptrRGB1Bright[3] = 125;
						ptrRGB1Bright[4] = 120;
						ptrRGB1Bright[5] = 115;
						ptrRGB1Bright[6] = 110;
						ptrRGB1Bright[7] = 105;
						
						/* Set cycle counter */
						RGB1CycleCounter = 40;
				}
				else if(ptrRGB1Bright[1] == 80)
				{
						/* Set Brightness */
						ptrRGB1Bright[0] = 85;
						ptrRGB1Bright[1] = 95;
						ptrRGB1Bright[2] = 95;
						ptrRGB1Bright[3] = 95;
						ptrRGB1Bright[4] = 95;
						ptrRGB1Bright[5] = 95;
						ptrRGB1Bright[6] = 95;
						ptrRGB1Bright[7] = 95;

						/* Set cycle counter */
						RGB1CycleCounter = 15;
				}
				else if(ptrRGB1Bright[2] == 75)
				{
						/* Set Brightness */
						ptrRGB1Bright[0] = 30;
						ptrRGB1Bright[1] = 80;
						ptrRGB1Bright[2] = 95;
						ptrRGB1Bright[3] = 95;
						ptrRGB1Bright[4] = 95;
						ptrRGB1Bright[5] = 95;
						ptrRGB1Bright[6] = 95;
						ptrRGB1Bright[7] = 95;

						/* Set cycle counter */
						RGB1CycleCounter = 20;
				}
				else if(ptrRGB1Bright[3] == 70)
				{
						/* Set Brightness */
						ptrRGB1Bright[0] = 30;
						ptrRGB1Bright[1] = 25;
						ptrRGB1Bright[2] = 75;
						ptrRGB1Bright[3] = 95;
						ptrRGB1Bright[4] = 95;
						ptrRGB1Bright[5] = 95;
						ptrRGB1Bright[6] = 95;
						ptrRGB1Bright[7] = 95;
						
						/* Set cycle counter */
						RGB1CycleCounter = 25;
				}
				else if(ptrRGB1Bright[4] == 65)
				{
						/* Set Brightness */
						ptrRGB1Bright[0] = 30;
						ptrRGB1Bright[1] = 25;
						ptrRGB1Bright[2] = 20;
						ptrRGB1Bright[3] = 70;
						ptrRGB1Bright[4] = 95;
						ptrRGB1Bright[5] = 95;
						ptrRGB1Bright[6] = 95;
						ptrRGB1Bright[7] = 95;
						
						/* Set cycle counter */
						RGB1CycleCounter = 30;
				}
				else if(ptrRGB1Bright[5] == 60)
				{
						/* Set Brightness */
						ptrRGB1Bright[0] = 30;
						ptrRGB1Bright[1] = 25;
						ptrRGB1Bright[2] = 20;
						ptrRGB1Bright[3] = 15;
						ptrRGB1Bright[4] = 65;
						ptrRGB1Bright[5] = 95;
						ptrRGB1Bright[6] = 95;
						ptrRGB1Bright[7] = 95;

						/* Set cycle counter */
						RGB1CycleCounter = 35;
				}
				else if(ptrRGB1Bright[6] == 55)
				{
						/* Set Brightness */
						ptrRGB1Bright[0] = 30;
						ptrRGB1Bright[1] = 25;
						ptrRGB1Bright[2] = 20;
						ptrRGB1Bright[3] = 15;
						ptrRGB1Bright[4] = 10;
						ptrRGB1Bright[5] = 60;
						ptrRGB1Bright[6] = 95;
						ptrRGB1Bright[7] = 95;
						
						/* Set cycle counter */
						RGB1CycleCounter = 40;
				}
				else if(ptrRGB1Bright[7] == 50)
				{
						/* Set Brightness */
						ptrRGB1Bright[0] = 30;
						ptrRGB1Bright[1] = 25;
						ptrRGB1Bright[2] = 20;
						ptrRGB1Bright[3] = 15;
						ptrRGB1Bright[4] = 10;
						ptrRGB1Bright[5] = 5;
						ptrRGB1Bright[6] = 55;
						ptrRGB1Bright[7] = 95;
						
						/* Set cycle counter */
						RGB1CycleCounter = 45;
				}
				RGB1TimeCounter = 0;
		}
}
