/******************************************************************************//**
 * @file     Serial_LED.c
 * @version  V1.00
 * @brief    Serial LED lighting effects sample file
 *
 * @copyright (C) 2016 Nuvoton Technology Corp. All rights reserved.
 ******************************************************************************/

/*!<Includes */
#include <stdlib.h>
#include "NUC121.h"
#include "Serial_LED.h"
#include "device.h"

uint8_t GraphicMaxBright, BarMaxBright, StripeMaxBright;
#define cGraphic_LED 9
uint8_t DataGraphic[cGraphic_LED*24];
#define cBar_LED 5
uint8_t DataBar[cBar_LED*24];
#define cStripe_LED 12
uint8_t DataStripe[cStripe_LED*24];
#define cMeteor_LED 2

typedef void (*Graphic_FUNC)(uint32_t *CountingTime);
static volatile Graphic_FUNC Graphic_Fn = NULL;
void *Graphic_ptr[13] = {Disable_Graphic, NoAnimation_Graphic, Breathing_Graphic, Flashing_Graphic, DoubleFlashing_Graphic,
											   Marquee_Graphic, Meteor_Graphic, Rainbow_Graphic, Lighting_Graphic, POP_Graphic,
												 JAZZ_Graphic, Play_Graphic, Movie_Graphic};
typedef void (*Bar_FUNC)(uint32_t *CountingTime);
static volatile Bar_FUNC Bar_Fn = NULL;
void *Bar_ptr[13] = {Disable_Bar, NoAnimation_Bar, Breathing_Bar, Flashing_Bar, DoubleFlashing_Bar,
										 Marquee_Bar, Meteor_Bar, Rainbow_Bar, Lighting_Bar, POP_Bar,
										 JAZZ_Bar, Play_Bar, Movie_Bar};
typedef void (*Stripe_FUNC)(uint32_t *CountingTime);
static volatile Stripe_FUNC Stripe_Fn = NULL;
void *Stripe_ptr[13] = {Disable_Stripe, NoAnimation_Stripe, Breathing_Stripe, Flashing_Stripe, DoubleFlashing_Stripe,
											 Marquee_Stripe, Meteor_Stripe, Rainbow_Stripe, Lighting_Stripe, POP_Stripe,
											 JAZZ_Stripe, Play_Stripe, Movie_Stripe};

uint32_t GraphicTimeCounter = 0, BarTimeCounter = 0, StripeTimeCounter = 0;
uint8_t GraphicBrightness, BarBrightness, StripeBrightness;
uint8_t GraphicLightingMode, BarLightingMode, StripeLightingMode;
uint8_t GraphicSpeed, BarSpeed, StripeSpeed;
uint8_t GraphicBrightness, BarBrightness, StripeBrightness;									 
uint8_t GraphicRGBColor[2][3] = {{  0,   0,   0},			// (R, G, B)
																 {255, 255, 255}};		// for lighting
uint8_t BarRGBColor[2][3] = {{  0,   0,   0},					// (R, G, B)
														 {255, 255, 255}};				// for lighting
uint8_t StripeRGBColor[2][3] = {{  0,   0,   0},			// (R, G, B)
																{255, 255, 255}};			// for lighting
uint8_t GraphicLightingFlag = 0, BarLightingFlag = 0, StripeLightingFlag = 0;
uint32_t Random_Graphic, Random_Bar, Random_Stripe; 

volatile uint8_t fPDMA_GraphicDone = 1, fPDMA_BarDone = 1, fPDMA_StripeDone = 1;
																
uint8_t MainVolume = 0;
uint8_t LeftChannelVolume = 0;
uint8_t RightChannelVolume = 0;

enum eWS2812B
{
		WSData0 = 0xC0,
		WSData1 = 0xF8
};
																
void USPI_Init(void)
{
    /*---------------------------------------------------------------------------------------------------------*/
    /* Init USCI0_SPI                                                                                                */
    /*---------------------------------------------------------------------------------------------------------*/
    /* Enable USCI0 peripheral clock */
    CLK_EnableModuleClock(USCI0_MODULE);
	
    /* Configure as a master, clock idle low, 8-bit transaction, drive output on falling clock edge and latch input on rising edge. */
    /* Set IP clock divider. SPI clock rate = HCLK / 6 = 38.1MHz / 6 = 6.35MHz */
    USPI_Open(USPI0, SPI_MASTER, SPI_MODE_0, 8, 6350000);
		USPI_SET_SUSPEND_CYCLE(USPI0, 0);

    /* Disable the automatic hardware slave select function. */
    USPI_DisableAutoSS(USPI0);
	
		/* Always enable SPI transaction */
		USPI_SET_SS_LOW(USPI0);
	
    /* Init I/O Multi-function */
    Serial_DataGraphic_Init();
		Serial_DataBar_Init();
	
		/* Set PDMA channel0 for DataGraphic and DataBar to display Graphic_LED and Bar_LED */
    /* Single request type. SPI only support PDMA single request type. */
    PDMA_SetBurstType(0, PDMA_REQ_SINGLE, 0);
		/* Set request source; set basic mode. */
		PDMA_SetTransferMode(0, PDMA_USCI0_TX, FALSE, 0);
    /* Disable table interrupt */
    PDMA->DSCT[0].CTL |= PDMA_DSCT_CTL_TBINTDIS_Msk;
		/* Enable interrupt */
    PDMA_EnableInt(0, PDMA_INT_TRANS_DONE);
    /* Enable NVIC for PDMA */
    NVIC_EnableIRQ(PDMA_IRQn);
}

/* Descriptor table */
volatile PDMA_DSCT_T PDMA_DESC[12]; 
void SPI_Init(void)
{
		uint8_t i;
	
		/*---------------------------------------------------------------------------------------------------------*/
    /* Init SPI0                                                                                               */
    /*---------------------------------------------------------------------------------------------------------*/
    /* Enable SPI0 peripheral clock */
    CLK_EnableModuleClock(SPI0_MODULE);
	
    /* Select SPI0 clock source */
    CLK_SetModuleClock(SPI0_MODULE, CLK_CLKSEL2_SPI0SEL_PCLK0, 0);
	
    /* Configure as a master, clock idle low, 8-bit transaction, drive output on falling clock edge and latch input on rising edge. */
    /* Set IP clock divider. SPI clock rate = HCLK / 6 = 38.1MHz / 6 = 6.35MHz */
    SPI_Open(SPI0, SPI_MASTER, SPI_MODE_0, 8, 6350000);
		SPI_SET_SUSPEND_CYCLE(SPI0, 0);

    /* Disable the automatic hardware slave select function. */
    SPI_DisableAutoSS(SPI0);
	
		/* Always enable SPI transaction */
		SPI_SET_SS_LOW(SPI0);
	
    /* Init I/O Multi-function */
		/* Set multi-function pins for SPI0_MOSI */
    SYS->GPC_MFPH = (SYS->GPC_MFPH & (~SYS_GPC_MFPH_PC11MFP_Msk));
    SYS->GPC_MFPH |= SYS_GPC_MFPH_PC11MFP_SPI0_MOSI;
	
		/* Set PDMA channel1 for DataStripe to display Stripe_LED */
    /* Enable Scatter Gather mode, assign the first scatter-gather descriptor table is table 1,
       and set transfer mode as memory to peripheral */
    PDMA_SetTransferMode(1, PDMA_SPI0_TX, 1, (uint32_t)&PDMA_DESC[0]);

		/*	Descriptor table 0~10 configuration for Stripe #0~10 */
		for(i = 0; i < 11; i++)
		{
				/*	Descriptor table i configuration for Stripe #i */
				PDMA_DESC[i].CTL =
						PDMA_WIDTH_8 |		/* Transfer width is 8 bits(one byte) */ \
						PDMA_SAR_INC |		/* Source increment size is 8 bits(one byte) */ \
						PDMA_DAR_FIX |		/* Destination fixed */ \
						PDMA_REQ_SINGLE |	/* Transfer type is burst transfer type */ \
						PDMA_BURST_128 |	/* Burst size is 128. No effect in single transfer type */ \
						PDMA_DSCT_CTL_TBINTDIS_Msk |   /* Disable transfer done and table empty interrupt */ \
						PDMA_OP_SCATTER;  /* Operation mode is scatter-gather mode */
				/* Configure next descriptor table address */
				PDMA_DESC[i].NEXT = (uint32_t)&PDMA_DESC[i+1] - (PDMA->SCATBA); /* next descriptor table is table i+1 */
		}

		/*	Descriptor table 11 configuration for Stripe #11 */
		PDMA_DESC[11].CTL =
				PDMA_WIDTH_8 |		/* Transfer width is 8 bits(one byte) */ \
				PDMA_SAR_INC |		/* Source increment size is 8 bits(one byte) */ \
				PDMA_DAR_FIX |		/* Destination fixed */ \
				PDMA_REQ_SINGLE |	/* Transfer type is burst transfer type */ \
				PDMA_BURST_128 |	/* Burst size is 128. No effect in single transfer type */ \
				PDMA_OP_BASIC;  		/* Operation mode is IDLE mode */
		/* Configure next descriptor table address */
		PDMA_DESC[11].NEXT = 0; /* No next operation table. No effect in basic mode */
		
		/* Raise channel1 priority */
		PDMA->PRISET |= PDMA_PRISET_FPRISET1_Msk;
		/* Enable interrupt */
    PDMA_EnableInt(1, PDMA_INT_TRANS_DONE);
    /* Enable NVIC for PDMA */
    NVIC_EnableIRQ(PDMA_IRQn);
}

void PDMA_IRQHandler(void)
{
		int32_t Intstatus;
	
		Intstatus = PDMA_GET_TD_STS();
	
		if(Intstatus & BIT0)
		{
				/* PDMA channel0 for DataGraphic to display Graphic_LED is done */
				if(!fPDMA_GraphicDone)
				{
						fPDMA_GraphicDone = 1;				
						Serial_DataGraphic_Init();	
				}
				/* PDMA channel0 for DataBar to display Bar_LED is done */
				else if(!fPDMA_BarDone)
				{
						fPDMA_BarDone = 1;
						Serial_DataBar_Init();	
				}
				PDMA_CLR_TD_FLAG(PDMA_TDSTS_TDIF0_Msk);
				/* Disable USPI master DMA function */
				USPI_DISABLE_PDMA(USPI0);
		}
		
		if(Intstatus & BIT1)
		{
				fPDMA_StripeDone = 1;
				PDMA_CLR_TD_FLAG(PDMA_TDSTS_TDIF1_Msk);
				/* Disable SPI master DMA function */
				SPI0->FIFOCTL |= SPI_FIFOCTL_RXRST_Msk | SPI_FIFOCTL_TXRST_Msk;
				SPI0->PDMACTL |= SPI_PDMACTL_PDMARST_Msk;
		}
}

void Set_GraphicLED(void)
{
		/* Set USCI0_DAT0 MFP function */
		Serial_DataGraphic_Open();
	
		/* Pause Channel1 for safety */
		PDMA_PAUSE(1);
	
		/* Set transfer width (8 bits) and transfer count */
		PDMA->DSCT[0].CTL |= ((cGraphic_LED*24) << PDMA_DSCT_CTL_TXCNT_Pos) | PDMA_OP_BASIC;
		/* Set source/destination address and attributes */
		PDMA_SetTransferAddr(0, (uint32_t)DataGraphic, PDMA_SAR_INC, (uint32_t)&USPI0->TXDAT, PDMA_DAR_FIX);

		/* Resume Channel1 */
		PDMA->CHCTL |= PDMA_CHCTL_CHEN1_Msk;	
	
		fPDMA_GraphicDone = 0;
		/* Enable SPI master DMA function */
		USPI0->PDMACTL |= (USPI_PDMACTL_TXPDMAEN_Msk | USPI_PDMACTL_PDMAEN_Msk);
}

void Set_BarLED(void)
{
		/* Set USCI0_DAT0 MFP function */
		Serial_DataBar_Open();
	
		/* Pause Channel1 for safety */
		PDMA_PAUSE(1);
	
		/* Set transfer width (8 bits) and transfer count */
		PDMA->DSCT[0].CTL |= ((cBar_LED*24) << PDMA_DSCT_CTL_TXCNT_Pos) | PDMA_OP_BASIC;
		/* Set source/destination address and attributes */
		PDMA_SetTransferAddr(0, (uint32_t)DataBar, PDMA_SAR_INC, (uint32_t)&USPI0->TXDAT, PDMA_DAR_FIX);

		/* Resume Channel1 */
		PDMA->CHCTL |= PDMA_CHCTL_CHEN1_Msk;	
	
		fPDMA_BarDone = 0;
		/* Enable SPI master DMA function */
		USPI0->PDMACTL |= (USPI_PDMACTL_TXPDMAEN_Msk | USPI_PDMACTL_PDMAEN_Msk);
}

void Set_StripeLED(void)
{
		uint32_t i;
	
    /* Enable Scatter Gather mode, assign the first scatter-gather descriptor table and set transfer mode as memory to peripheral */
		PDMA->DSCT[1].CTL = (PDMA->DSCT[1].CTL & ~PDMA_DSCT_CTL_OPMODE_Msk) | PDMA_OP_SCATTER;
		PDMA->DSCT[1].FIRST = (uint32_t)PDMA_DESC;
	
		/* Stripe */
		/* #0 ~ #10 */
		for(i = 0; i < 11; i++)
		{
				PDMA_DESC[i].CTL |= ((cStripe_LED*24-1) << PDMA_DSCT_CTL_TXCNT_Pos) | PDMA_OP_SCATTER;
				PDMA_DESC[i].SA = (uint32_t)DataStripe;
				PDMA_DESC[i].DA = (uint32_t)&SPI0->TX;
		}
		/* #11 */
		PDMA_DESC[11].CTL |= ((cStripe_LED*24-1) << PDMA_DSCT_CTL_TXCNT_Pos) | PDMA_OP_BASIC;
		PDMA_DESC[11].SA = (uint32_t)DataStripe;
		PDMA_DESC[11].DA = (uint32_t)&SPI0->TX;
		
		fPDMA_StripeDone = 0;
		/* Enable SPI master DMA function */
		SPI_TRIGGER_TX_PDMA(SPI0);
}

void Reset_GraphicLED(void)
{
		uint8_t i;

		for(i = 0; i < cGraphic_LED * 24; i++)
		{
				DataGraphic[i] = WSData0;
		}

		Set_GraphicLED();
}

void Reset_BarLED(void)
{
		uint8_t i;

		for(i = 0; i < cBar_LED * 24; i++)
		{
				DataBar[i] = WSData0;
		}

		Set_BarLED();
}

void Reset_StripeLED(void)
{
		uint32_t i;

		for(i = 0; i < cStripe_LED * 24; i++)
		{
				DataStripe[i] = WSData0;
		}

		Set_StripeLED();
}

void Set_Graphic_RGB(uint32_t TotalLED, uint8_t Data_R, uint8_t Data_G, uint8_t Data_B)
{
		uint8_t i;
		int8_t k;
		uint32_t Temp;

		/* Graphic */
		for(i = 0; i < TotalLED; i++)
		{
				/* G */
				Temp = i*24 + 0*8 + 7;
				for(k = 7; k >= 0; k--)
				{
						if(Data_G & (1 << k))
						{
								DataGraphic[Temp-k] = WSData1;
						}
						else
						{
								DataGraphic[Temp-k] = WSData0;
						}
				}
				/* R */
				Temp = i*24 + 1*8+7;
				for(k = 7; k >= 0; k--)
				{
						if(Data_R & (1 << k))
						{
								DataGraphic[Temp-k] = WSData1;
						}
						else
						{
								DataGraphic[Temp-k] = WSData0;
						}
				}
				/* B */
				Temp = i*24 + 2*8+7;
				for(k = 7; k >= 0; k--)
				{
						if(Data_B & (1 << k))
						{
								DataGraphic[Temp-k] = WSData1;
						}
						else
						{
								DataGraphic[Temp-k] = WSData0;
						}
				}
		}
}

void Set_Graphic_Array(uint32_t TotalLED, uint8_t *DisplayData, uint8_t MaxBright)
{
		uint8_t i;
		int8_t k;
		uint32_t Temp0, Temp1;

		/* Graphic */
		for(i = 0; i < TotalLED; i++)
		{
				/* G */
				Temp0 = i*24 + 0*8 + 7;
				Temp1 = *(DisplayData + i*3 + 1) * MaxBright / 10;
				for(k = 7; k >= 0; k--)
				{
						if(Temp1 & (1 << k))
						{
								DataGraphic[Temp0-k] = WSData1;
						}
						else
						{
								DataGraphic[Temp0-k] = WSData0;
						}
				}
				/* R */
				Temp0 = i*24 + 1*8 + 7;
				Temp1 = *(DisplayData + i*3 + 0) * MaxBright / 10;
				for(k = 7; k >= 0; k--)
				{
						if(Temp1 & (1 << k))
						{
								DataGraphic[Temp0-k] = WSData1;
						}
						else
						{
								DataGraphic[Temp0-k] = WSData0;
						}
				}
				/* B */
				Temp0 = i*24 + 2*8 + 7;
				Temp1 = *(DisplayData + i*3 + 2) * MaxBright / 10;
				for(k = 7; k >= 0; k--)
				{
						if(Temp1 & (1 << k))
						{
								DataGraphic[Temp0-k] = WSData1;
						}
						else
						{
								DataGraphic[Temp0-k] = WSData0;
						}
				}
		}
}

void Set_Bar_RGB(uint32_t TotalLED, uint8_t Data_R, uint8_t Data_G, uint8_t Data_B)
{
		uint8_t i;
		int8_t k;
		uint32_t Temp;

		/* Graphic */
		for(i = 0; i < TotalLED; i++)
		{
				/* G */
				Temp = i*24 + 0*8 + 7;
				for(k = 7; k >= 0; k--)
				{
						if(Data_G & (1 << k))
						{
								DataBar[Temp-k] = WSData1;
						}
						else
						{
								DataBar[Temp-k] = WSData0;
						}
				}
				/* R */
				Temp = i*24 + 1*8+7;
				for(k = 7; k >= 0; k--)
				{
						if(Data_R & (1 << k))
						{
								DataBar[Temp-k] = WSData1;
						}
						else
						{
								DataBar[Temp-k] = WSData0;
						}
				}
				/* B */
				Temp = i*24 + 2*8+7;
				for(k = 7; k >= 0; k--)
				{
						if(Data_B & (1 << k))
						{
								DataBar[Temp-k] = WSData1;
						}
						else
						{
								DataBar[Temp-k] = WSData0;
						}
				}
		}
}

void Set_Bar_Array(uint32_t TotalLED, uint8_t *DisplayData, uint8_t MaxBright)
{
		uint8_t i;
		int8_t k;
		uint32_t Temp0, Temp1;

		/* Bar */
		for(i = 0; i < TotalLED; i++)
		{
				/* G */
				Temp0 = i*24 + 0*8 + 7;
				Temp1 = *(DisplayData + i*3 + 1) * MaxBright / 10;
				for(k = 7; k >= 0; k--)
				{
						if(Temp1 & (1 << k))
						{
								DataBar[Temp0-k] = WSData1;
						}
						else
						{
								DataBar[Temp0-k] = WSData0;
						}
				}
				/* R */
				Temp0 = i*24 + 1*8 + 7;
				Temp1 = *(DisplayData + i*3 + 0) * MaxBright / 10;
				for(k = 7; k >= 0; k--)
				{
						if(Temp1 & (1 << k))
						{
								DataBar[Temp0-k] = WSData1;
						}
						else
						{
								DataBar[Temp0-k] = WSData0;
						}
				}
				/* B */
				Temp0 = i*24 + 2*8 + 7;
				Temp1 = *(DisplayData + i*3 + 2) * MaxBright / 10;
				for(k = 7; k >= 0; k--)
				{
						if(Temp1 & (1 << k))
						{
								DataBar[Temp0-k] = WSData1;
						}
						else
						{
								DataBar[Temp0-k] = WSData0;
						}
				}
		}
}

void Set_Stripe_RGB(uint32_t TotalLED, uint8_t Data_R, uint8_t Data_G, uint8_t Data_B)
{
		uint8_t i;
		int8_t k;
		uint32_t Temp;

		/* Graphic */
		for(i = 0; i < TotalLED; i++)
		{
				/* G */
				Temp = i*24 + 0*8 + 7;
				for(k = 7; k >= 0; k--)
				{
						if(Data_G & (1 << k))
						{
								DataStripe[Temp-k] = WSData1;
						}
						else
						{
								DataStripe[Temp-k] = WSData0;
						}
				}
				/* R */
				Temp = i*24 + 1*8+7;
				for(k = 7; k >= 0; k--)
				{
						if(Data_R & (1 << k))
						{
								DataStripe[Temp-k] = WSData1;
						}
						else
						{
								DataStripe[Temp-k] = WSData0;
						}
				}
				/* B */
				Temp = i*24 + 2*8+7;
				for(k = 7; k >= 0; k--)
				{
						if(Data_B & (1 << k))
						{
								DataStripe[Temp-k] = WSData1;
						}
						else
						{
								DataStripe[Temp-k] = WSData0;
						}
				}
		}
}

void Set_Stripe_Array(uint32_t TotalLED, uint8_t *DisplayData, uint8_t MaxBright)
{
		uint8_t i;
		int8_t k;
		uint32_t Temp0, Temp1;

		/* Stripe */
		for(i = 0; i < TotalLED; i++)
		{
				/* G */
				Temp0 = i*24 + 0*8 + 7;
				Temp1 = *(DisplayData + i*3 + 1) * MaxBright / 10;
				for(k = 7; k >= 0; k--)
				{
						if(Temp1 & (1 << k))
						{
								DataStripe[Temp0-k] = WSData1;
						}
						else
						{
								DataStripe[Temp0-k] = WSData0;
						}
				}
				/* R */
				Temp0 = i*24 + 1*8 + 7;
				Temp1 = *(DisplayData + i*3 + 0) * MaxBright / 10;
				for(k = 7; k >= 0; k--)
				{
						if(Temp1 & (1 << k))
						{
								DataStripe[Temp0-k] = WSData1;
						}
						else
						{
								DataStripe[Temp0-k] = WSData0;
						}
				}
				/* B */
				Temp0 = i*24 + 2*8 + 7;
				Temp1 = *(DisplayData + i*3 + 2) * MaxBright / 10;
				for(k = 7; k >= 0; k--)
				{
						if(Temp1 & (1 << k))
						{
								DataStripe[Temp0-k] = WSData1;
						}
						else
						{
								DataStripe[Temp0-k] = WSData0;
						}
				}
		}
}

void Disable_Graphic(uint32_t *CountingTime)
{
		uint32_t i;

		for(i = 0; i < ((cGraphic_LED) * 24); i++)
		{
				DataGraphic[i] = WSData0;
		}
}

void Disable_Bar(uint32_t *CountingTime)
{
		uint32_t i;

		for(i = 0; i < ((cBar_LED) * 24); i++)
		{
				DataBar[i] = WSData0;
		}
}

void Disable_Stripe(uint32_t *CountingTime)
{
		uint32_t i;

		for(i = 0; i < ((cStripe_LED) * 24); i++)
		{
				DataStripe[i] = WSData0;
		}
}

void NoAnimation_Graphic(void)
{
		uint32_t TempR, TempG, TempB;

		/* Graphic */
		TempR = (GraphicRGBColor[0][0] * GraphicBrightness * *RGBBright) / 1000;
		TempG = (GraphicRGBColor[0][1] * GraphicBrightness * *RGBBright) / 1000;
		TempB = (GraphicRGBColor[0][2] * GraphicBrightness * *RGBBright) / 1000;
		Set_Graphic_RGB(cGraphic_LED, TempR, TempG, TempB);
}

void NoAnimation_Bar(void)
{
		uint32_t TempR, TempG, TempB;

		/* Bar */
		TempR = (BarRGBColor[0][0] * BarBrightness * *RGBBright) / 1000;
		TempG = (BarRGBColor[0][1] * BarBrightness * *RGBBright) / 1000;
		TempB = (BarRGBColor[0][2] * BarBrightness * *RGBBright) / 1000;
		Set_Bar_RGB(cBar_LED, TempR, TempG, TempB);
}

void NoAnimation_Stripe(void)
{
		uint32_t TempR, TempG, TempB;

		/* Stripe */
		TempR = (StripeRGBColor[0][0] * StripeBrightness * *RGBBright) / 1000;
		TempG = (StripeRGBColor[0][1] * StripeBrightness * *RGBBright) / 1000;
		TempB = (StripeRGBColor[0][2] * StripeBrightness * *RGBBright) / 1000;
		Set_Stripe_RGB(cStripe_LED, TempR, TempG, TempB);
}

void Breathing_Graphic(uint32_t *CountingTime)
{
		uint32_t TempR, TempG, TempB;
	
		/* Graphic */
		TempR = (GraphicRGBColor[0][0] * GraphicBrightness * *(BreathingBright + (*CountingTime / (BreathingRate[GraphicSpeed] * 8) % BreathingArraySize))) / 1000;
		TempG = (GraphicRGBColor[0][1] * GraphicBrightness * *(BreathingBright + (*CountingTime / (BreathingRate[GraphicSpeed] * 8) % BreathingArraySize))) / 1000;
		TempB = (GraphicRGBColor[0][2] * GraphicBrightness * *(BreathingBright + (*CountingTime / (BreathingRate[GraphicSpeed] * 8) % BreathingArraySize))) / 1000;
		Set_Graphic_RGB(cGraphic_LED, TempR, TempG, TempB);
}

void Breathing_Bar(uint32_t *CountingTime)
{
		uint32_t TempR, TempG, TempB;
	
		/* Bar */
		TempR = (BarRGBColor[0][0] * BarBrightness * *(BreathingBright + (*CountingTime / (BreathingRate[BarSpeed] * 8) % BreathingArraySize))) / 1000;
		TempG = (BarRGBColor[0][1] * BarBrightness * *(BreathingBright + (*CountingTime / (BreathingRate[BarSpeed] * 8) % BreathingArraySize))) / 1000;
		TempB = (BarRGBColor[0][2] * BarBrightness * *(BreathingBright + (*CountingTime / (BreathingRate[BarSpeed] * 8) % BreathingArraySize))) / 1000;
		Set_Bar_RGB(cBar_LED, TempR, TempG, TempB);
}

void Breathing_Stripe(uint32_t *CountingTime)
{
		uint32_t TempR, TempG, TempB;
	
		/* Stripe */
		TempR = (StripeRGBColor[0][0] * StripeBrightness * *(BreathingBright + (*CountingTime / (BreathingRate[StripeSpeed] * 8) % BreathingArraySize))) / 1000;
		TempG = (StripeRGBColor[0][1] * StripeBrightness * *(BreathingBright + (*CountingTime / (BreathingRate[StripeSpeed] * 8) % BreathingArraySize))) / 1000;
		TempB = (StripeRGBColor[0][2] * StripeBrightness * *(BreathingBright + (*CountingTime / (BreathingRate[StripeSpeed] * 8) % BreathingArraySize))) / 1000;
		Set_Stripe_RGB(cStripe_LED, TempR, TempG, TempB);
}

void Flashing_Graphic(uint32_t *CountingTime)
{
		uint32_t TempR, TempG, TempB;
	
		/* Graphic */
		TempR = (GraphicRGBColor[0][0] * GraphicBrightness * *(DoubleFlashingBright + (*CountingTime / (DoubleFlashingRate[GraphicSpeed] * 8) % FlashingArraySize))) / 1000;
		TempG = (GraphicRGBColor[0][1] * GraphicBrightness * *(DoubleFlashingBright + (*CountingTime / (DoubleFlashingRate[GraphicSpeed] * 8) % FlashingArraySize))) / 1000;
		TempB = (GraphicRGBColor[0][2] * GraphicBrightness * *(DoubleFlashingBright + (*CountingTime / (DoubleFlashingRate[GraphicSpeed] * 8) % FlashingArraySize))) / 1000;
		Set_Graphic_RGB(cGraphic_LED, TempR, TempG, TempB);
}

void Flashing_Bar(uint32_t *CountingTime)
{
		uint32_t TempR, TempG, TempB;
	
		/* Bar */
		TempR = (BarRGBColor[0][0] * BarBrightness * *(DoubleFlashingBright + (*CountingTime / (DoubleFlashingRate[BarSpeed] * 8) % FlashingArraySize))) / 1000;
		TempG = (BarRGBColor[0][1] * BarBrightness * *(DoubleFlashingBright + (*CountingTime / (DoubleFlashingRate[BarSpeed] * 8) % FlashingArraySize))) / 1000;
		TempB = (BarRGBColor[0][2] * BarBrightness * *(DoubleFlashingBright + (*CountingTime / (DoubleFlashingRate[BarSpeed] * 8) % FlashingArraySize))) / 1000;
		Set_Bar_RGB(cBar_LED, TempR, TempG, TempB);
}

void Flashing_Stripe(uint32_t *CountingTime)
{
		uint32_t TempR, TempG, TempB;
	
		/* Stripe */
		TempR = (StripeRGBColor[0][0] * StripeBrightness * *(DoubleFlashingBright + (*CountingTime / (DoubleFlashingRate[StripeSpeed] * 8) % FlashingArraySize))) / 1000;
		TempG = (StripeRGBColor[0][1] * StripeBrightness * *(DoubleFlashingBright + (*CountingTime / (DoubleFlashingRate[StripeSpeed] * 8) % FlashingArraySize))) / 1000;
		TempB = (StripeRGBColor[0][2] * StripeBrightness * *(DoubleFlashingBright + (*CountingTime / (DoubleFlashingRate[StripeSpeed] * 8) % FlashingArraySize))) / 1000;
		Set_Stripe_RGB(cStripe_LED, TempR, TempG, TempB);
}

void DoubleFlashing_Graphic(uint32_t *CountingTime)
{
		uint32_t TempR, TempG, TempB;
	
		/* Graphic */
		TempR = (GraphicRGBColor[0][0] * GraphicBrightness * *((DoubleFlashingBright + 6) + (*CountingTime / (DoubleFlashingRate[GraphicSpeed] * 8) % (DoubleFlashingArraySize - 6)))) / 1000;
		TempG = (GraphicRGBColor[0][1] * GraphicBrightness * *((DoubleFlashingBright + 6) + (*CountingTime / (DoubleFlashingRate[GraphicSpeed] * 8) % (DoubleFlashingArraySize - 6)))) / 1000;
		TempB = (GraphicRGBColor[0][2] * GraphicBrightness * *((DoubleFlashingBright + 6) + (*CountingTime / (DoubleFlashingRate[GraphicSpeed] * 8) % (DoubleFlashingArraySize - 6)))) / 1000;
		Set_Graphic_RGB(cGraphic_LED, TempR, TempG, TempB);
}

void DoubleFlashing_Bar(uint32_t *CountingTime)
{
		uint32_t TempR, TempG, TempB;
	
		/* Bar */
		TempR = (BarRGBColor[0][0] * BarBrightness * *((DoubleFlashingBright + 6) + (*CountingTime / (DoubleFlashingRate[BarSpeed] * 8) % (DoubleFlashingArraySize - 6)))) / 1000;
		TempG = (BarRGBColor[0][1] * BarBrightness * *((DoubleFlashingBright + 6) + (*CountingTime / (DoubleFlashingRate[BarSpeed] * 8) % (DoubleFlashingArraySize - 6)))) / 1000;
		TempB = (BarRGBColor[0][2] * BarBrightness * *((DoubleFlashingBright + 6) + (*CountingTime / (DoubleFlashingRate[BarSpeed] * 8) % (DoubleFlashingArraySize - 6)))) / 1000;
		Set_Bar_RGB(cBar_LED, TempR, TempG, TempB);
}

void DoubleFlashing_Stripe(uint32_t *CountingTime)
{
		uint32_t TempR, TempG, TempB;
	
		/* Stripe */
		TempR = (StripeRGBColor[0][0] * StripeBrightness * *((DoubleFlashingBright + 6) + (*CountingTime / (DoubleFlashingRate[StripeSpeed] * 8) % (DoubleFlashingArraySize - 6)))) / 1000;
		TempG = (StripeRGBColor[0][1] * StripeBrightness * *((DoubleFlashingBright + 6) + (*CountingTime / (DoubleFlashingRate[StripeSpeed] * 8) % (DoubleFlashingArraySize - 6)))) / 1000;
		TempB = (StripeRGBColor[0][2] * StripeBrightness * *((DoubleFlashingBright + 6) + (*CountingTime / (DoubleFlashingRate[StripeSpeed] * 8) % (DoubleFlashingArraySize - 6)))) / 1000;
		Set_Stripe_RGB(cStripe_LED, TempR, TempG, TempB);
}

void Marquee_Calculation(uint8_t LightingSpeed, uint32_t *CurrentDuration, uint8_t* MixedColor, uint32_t cLED)
{
		uint8_t i, j;
		uint32_t Duration[3] = {70, 50, 30};
		uint8_t Color[cMeteor_LED][3];
		uint32_t Loop, CurrentTime, DeltaT;
		uint8_t ColorCursor, TempColor;

		/* DeltaT is unit time */
		DeltaT = Duration[LightingSpeed];
		Loop = (*CurrentDuration / DeltaT);
		/* Time in each LED period */
		CurrentTime = *CurrentDuration - (Loop * DeltaT);
		/* Loop to indicate which LED for first Color */
		Loop = Loop % (2 * (cLED + cMeteor_LED) - 1);
		/* ColorCursor for indicating color */
		ColorCursor = ((*CurrentDuration / DeltaT) / ((2 * (cLED + cMeteor_LED)) - 1)) % 7;

		/* Copy Color array to MixedColor */
		/* Forward */
		if(Loop < (cLED + cMeteor_LED))
		{
				for(i = 0; i < 3; i++)
				{
						TempColor = RainbowColor[ColorCursor*2][i];
						/* 1st 100% to 0% */
						Color[0][i] = (TempColor * (DeltaT - CurrentTime)) / DeltaT;
						/* 2nd 0% to 100% */
						Color[1][i] = (TempColor * CurrentTime) / DeltaT;
				}	
		
				for(j = Loop; j < (Loop + cMeteor_LED); j++)
				{
						for(i = 0; i < 3; i++)
								*(MixedColor + j*3 + i) = Color[j - Loop][i];
				}
		}
		/* Backward */
		else
		{
				for(i = 0; i < 3; i++)
				{
						TempColor = RainbowColor[ColorCursor*2][i];
						/* 1st 0% to 100% */
						Color[0][i] = (TempColor * CurrentTime) / DeltaT;
						/* 2nd 100% to 0% */
						Color[1][i] = (TempColor * (DeltaT - CurrentTime)) / DeltaT;
				}	
			
				for(j = (2 * (cLED + cMeteor_LED - 1) - Loop); j < (2 * (cLED + cMeteor_LED - 1) - Loop + cMeteor_LED); j++)
				{
						for(i = 0; i < 3; i++)
								*(MixedColor + j*3 + i) = Color[j - (2 * (cLED + cMeteor_LED - 1) - Loop)][i];
				}
		}
}

void Marquee_Graphic(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cGraphic_LED+(2*cMeteor_LED-1)][3] = {0};
	
		/* Calculate Graphic Color */
		Marquee_Calculation(GraphicSpeed, CountingTime, (uint8_t *)DisplayColor, cGraphic_LED);
		/* Graphic */
		Set_Graphic_Array(cGraphic_LED, (uint8_t *)(DisplayColor+cMeteor_LED), GraphicBrightness);
}

void Marquee_Bar(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cBar_LED+(2*cMeteor_LED-1)][3] = {0};
	
		/* Calculate Bar Color */
		Marquee_Calculation(BarSpeed, CountingTime, (uint8_t *)DisplayColor, cBar_LED);
		/* Bar */
		Set_Bar_Array(cBar_LED, (uint8_t *)(DisplayColor+cMeteor_LED), BarBrightness);
}

void Marquee_Stripe(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cStripe_LED+(2*cMeteor_LED-1)][3] = {0};
	
		/* Calculate Stripe Color */
		Marquee_Calculation(StripeSpeed, CountingTime, (uint8_t *)DisplayColor, cStripe_LED);
		/* Stripe */
		Set_Stripe_Array(cStripe_LED, (uint8_t *)(DisplayColor+cMeteor_LED), StripeBrightness);
}

void Meteor_Calculation(uint8_t LightingSpeed, uint32_t *CurrentDuration, uint8_t* MixedColor, uint32_t cLED)
{
		uint8_t j, i;
		uint32_t Duration[3] = {70, 50, 30};
		uint8_t Color[cMeteor_LED][3];
		uint32_t Loop, CurrentTime, DeltaT;
		uint8_t ColorCursor, TempColor;

		/* DeltaT is unit time */
		DeltaT = Duration[LightingSpeed];
		Loop = *CurrentDuration / DeltaT;
		/* Time in each LED period */
		CurrentTime = *CurrentDuration - (Loop * DeltaT);
		/* Loop to indicate which LED for first Color */
		Loop = Loop % (cLED + cMeteor_LED);
		/* ColorCursor for indicating color */
		ColorCursor = ((*CurrentDuration / DeltaT) / (cLED + cMeteor_LED)) % 7;

		for(i = 0; i < 3; i++)
		{
				TempColor = RainbowColor[ColorCursor*2][i];
				/* 1st 100% to 0% */
				Color[0][i] = (TempColor * (DeltaT - CurrentTime)) / DeltaT;
				/* 2nd 0% to 100% */
				Color[1][i] = (TempColor * CurrentTime) / DeltaT;
		}	
		
		/* Copy Color array to MixedColor */
		for(j = Loop; j < (Loop + cMeteor_LED); j++)
		{
				for(i = 0; i < 3; i++)
						*(MixedColor + j*3 + i) = Color[j - Loop][i];
		}
}

void Meteor_Graphic(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cGraphic_LED+(2*cMeteor_LED-1)][3] = {0};
	
		/* Calculate Graphic Color */
		Meteor_Calculation(GraphicSpeed, CountingTime, (uint8_t *)DisplayColor, cGraphic_LED);
		/* Graphic */
		Set_Graphic_Array(cGraphic_LED, (uint8_t *)(DisplayColor+cMeteor_LED-1), GraphicBrightness);
}

void Meteor_Bar(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cBar_LED+(2*cMeteor_LED-1)][3] = {0};
	
		/* Calculate Bar Color */
		Meteor_Calculation(BarSpeed, CountingTime, (uint8_t *)DisplayColor, cBar_LED);
		/* Bar */
		Set_Bar_Array(cBar_LED, (uint8_t *)(DisplayColor+cMeteor_LED-1), BarBrightness);
}

void Meteor_Stripe(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cStripe_LED+(2*cMeteor_LED-1)][3] = {0};
	
		/* Calculate Stripe Color */
		Meteor_Calculation(StripeSpeed, CountingTime, (uint8_t *)DisplayColor, cStripe_LED);
		/* Stripe */
		Set_Stripe_Array(cStripe_LED, (uint8_t *)(DisplayColor+cMeteor_LED-1), StripeBrightness);
}

void Rainbow_Graphic(uint32_t *CountingTime)
{
		uint8_t i;
		uint8_t DisplayColor[cGraphic_LED][3] = {0};
		uint32_t TempColor;
		
		TempColor = (*CountingTime / (8 * *(RainbowRate + GraphicSpeed))) % 14;
	
		/* Graphic */
		for(i = 0; i < cGraphic_LED; i++)
		{
				DisplayColor[cGraphic_LED-i-1][0] = RainbowColor[(i+TempColor)%14][0];
				DisplayColor[cGraphic_LED-i-1][1] = RainbowColor[(i+TempColor)%14][1];
				DisplayColor[cGraphic_LED-i-1][2] = RainbowColor[(i+TempColor)%14][2];
		}
		Set_Graphic_Array(cGraphic_LED, (uint8_t *)DisplayColor, GraphicBrightness);
}	

void Rainbow_Bar(uint32_t *CountingTime)
{
		uint8_t i;
		uint8_t DisplayColor[cBar_LED][3] = {0};
		uint32_t TempColor;
		
		TempColor = (*CountingTime / (8 * *(RainbowRate + BarSpeed))) % 14;
	
		/* Bar */
		for(i = 0; i < cBar_LED; i++)
		{
				DisplayColor[cBar_LED-i-1][0] = RainbowColor[(i+TempColor)%14][0];
				DisplayColor[cBar_LED-i-1][1] = RainbowColor[(i+TempColor)%14][1];
				DisplayColor[cBar_LED-i-1][2] = RainbowColor[(i+TempColor)%14][2];
		}
		Set_Bar_Array(cBar_LED, (uint8_t *)DisplayColor, BarBrightness);
}	

void Rainbow_Stripe(uint32_t *CountingTime)
{
		uint8_t i;
		uint8_t DisplayColor[cStripe_LED][3] = {0};
		uint32_t TempColor;
		
		TempColor = (*CountingTime / (8 * *(RainbowRate + StripeSpeed))) % 14;
	
		/* Stripe */
		for(i = 0; i < cStripe_LED; i++)
		{
				DisplayColor[cStripe_LED-i-1][0] = RainbowColor[(i+TempColor)%14][0];
				DisplayColor[cStripe_LED-i-1][1] = RainbowColor[(i+TempColor)%14][1];
				DisplayColor[cStripe_LED-i-1][2] = RainbowColor[(i+TempColor)%14][2];
		}
		Set_Stripe_Array(cStripe_LED, (uint8_t *)DisplayColor, StripeBrightness);
}	

void Lighting_Graphic(uint32_t *CountingTime)
{
		uint8_t i, j;
		uint32_t Period, CurrentTime;
		uint8_t DisplayColor[cGraphic_LED][3] = {0};
	
		/* Calculate Graphic Color */
		Period = 8 * (LightingRate[GraphicSpeed] + DoubleFlashingRate[GraphicSpeed]);
		CurrentTime = *CountingTime % Period;
		if(CurrentTime < (8 * LightingRate[GraphicSpeed]))
		{
				/* Copy Color array to DisplayColor */
				for(j = 0; j < cGraphic_LED; j++)
				{
						for(i = 0; i < 3; i++)
								DisplayColor[j][i] = GraphicRGBColor[0][i];
				}
				
				GraphicLightingFlag = 1;
		}
		else
		{
				if(GraphicLightingFlag)
				{
						Random_Graphic = rand();
						GraphicLightingFlag = 0;
				}
				/* Copy Color array to DisplayColor */
				for(j = 0; j < cGraphic_LED; j++)
				{
						if(Random_Graphic & (0x01 << j))
						{
								for(i = 0; i < 3; i++)
										DisplayColor[j][i] = 255;

						}
						else
						{
								for(i = 0; i < 3; i++)
										DisplayColor[j][i] = GraphicRGBColor[0][i];
						}
				}
		}
		/* Graphic */
		Set_Graphic_Array(cGraphic_LED, (uint8_t *)DisplayColor, GraphicBrightness);
}

void Lighting_Bar(uint32_t *CountingTime)
{
		uint8_t i, j;
		uint32_t Period, CurrentTime;
		uint8_t DisplayColor[cBar_LED][3] = {0};
	
		/* Calculate Bar Color */
		Period = 8 * (LightingRate[BarSpeed] + DoubleFlashingRate[BarSpeed]);
		CurrentTime = *CountingTime % Period;
		if(CurrentTime < (8 * LightingRate[BarSpeed]))
		{
				/* Copy Color array to DisplayColor */
				for(j = 0; j < cBar_LED; j++)
				{
						for(i = 0; i < 3; i++)
								DisplayColor[j][i] = BarRGBColor[0][i];
				}
				
				BarLightingFlag = 1;
		}
		else
		{
				if(BarLightingFlag)
				{
						Random_Bar = rand();
						BarLightingFlag = 0;
				}
				/* Copy Color array to DisplayColor */
				for(j = 0; j < cBar_LED; j++)
				{
						if(Random_Bar & (0x01 << j))
						{
								for(i = 0; i < 3; i++)
										DisplayColor[j][i] = 255;

						}
						else
						{
								for(i = 0; i < 3; i++)
										DisplayColor[j][i] = BarRGBColor[0][i];
						}
				}
		}
		/* Bar */
		Set_Bar_Array(cBar_LED, (uint8_t *)DisplayColor, BarBrightness);
}

void Lighting_Stripe(uint32_t *CountingTime)
{
		uint8_t i, j;
		uint32_t Period, CurrentTime;
		uint8_t DisplayColor[cStripe_LED][3] = {0};
	
		/* Calculate Stripe Color */
		Period = 8 * (LightingRate[StripeSpeed] + DoubleFlashingRate[StripeSpeed]);
		CurrentTime = *CountingTime % Period;
		if(CurrentTime < (8 * LightingRate[StripeSpeed]))
		{
				/* Copy Color array to DisplayColor */
				for(j = 0; j < cStripe_LED; j++)
				{
						for(i = 0; i < 3; i++)
								DisplayColor[j][i] = StripeRGBColor[0][i];
				}
				
				StripeLightingFlag = 1;
		}
		else
		{
				if(StripeLightingFlag)
				{
						Random_Stripe = rand();
						StripeLightingFlag = 0;
				}
				/* Copy Color array to DisplayColor */
				for(j = 0; j < cStripe_LED; j++)
				{
						if(Random_Stripe & (0x01 << j))
						{
								for(i = 0; i < 3; i++)
										DisplayColor[j][i] = 255;

						}
						else
						{
								for(i = 0; i < 3; i++)
										DisplayColor[j][i] = StripeRGBColor[0][i];
						}
				}
		}
		/* Stripe */
		Set_Stripe_Array(cStripe_LED, (uint8_t *)DisplayColor, StripeBrightness);
}

void POP_Graphic(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cGraphic_LED][3] = {0};
		uint8_t i, j;
		
		/* Calculate Graphic Color */
		if(RightChannelVolume > 0)
		{
				for(i = 0; i < 3; i++)
				{
						DisplayColor[8][i] = RainbowColor[Green][i];
				}
		}
		if(RightChannelVolume > 33)
		{
				for(j = 4; j < 8; j++)
				{
						for(i = 0; i < 3; i++)
						{
								DisplayColor[j][i] = RainbowColor[Orange][i];
						}
				}
		}
		if(RightChannelVolume > 66)
		{
				for(j = 0; j < 4; j++)
				{
						for(i = 0; i < 3; i++)
						{
								DisplayColor[j][i] = RainbowColor[Red][i];
						}
				}
		}		
	
		/* Graphic */
		Set_Graphic_Array(cGraphic_LED, (uint8_t *)DisplayColor, GraphicBrightness);
}

void POP_Bar(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cBar_LED][3] = {0};
		uint8_t Unit_Volume = (LeftChannelVolume * cBar_LED) / 100;
		uint8_t i, j;
		
		/* Calculate Bar Color */
		for(j = 0; j < Unit_Volume; j++)
		{
				/* Blue */
				if(j < (cBar_LED / 3))
				{
						for(i = 0; i < 3; i++)
						{
								DisplayColor[j][i] = RainbowColor[Green][i];
						}
				}
				/* Purple */
				else if(j < (2 * cBar_LED / 3))
				{
						for(i = 0; i < 3; i++)
						{
								DisplayColor[j][i] = RainbowColor[Orange][i];
						}
				}
				/* Red */
				else
				{
						for(i = 0; i < 3; i++)
						{
								DisplayColor[j][i] = RainbowColor[Red][i];
						}
				}
		}
	
		/* Bar */
		Set_Bar_Array(cBar_LED, (uint8_t *)DisplayColor, BarBrightness);
}

void POP_Stripe(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cStripe_LED][3] = {0};
		uint8_t Unit_Volume = (MainVolume * cStripe_LED) / 100;
		uint8_t i, j;
		
		/* Calculate Stripe Color */
		for(j = 0; j < Unit_Volume; j++)
		{
				/* Blue */
				if(j < (cStripe_LED / 3))
				{
						for(i = 0; i < 3; i++)
						{
								DisplayColor[j][i] = RainbowColor[Green][i];
						}
				}
				/* Purple */
				else if(j < (2 * cStripe_LED / 3))
				{
						for(i = 0; i < 3; i++)
						{
								DisplayColor[j][i] = RainbowColor[Orange][i];
						}
				}
				/* Red */
				else
				{
						for(i = 0; i < 3; i++)
						{
								DisplayColor[j][i] = RainbowColor[Red][i];
						}
				}
		}
	
		/* Stripe */
		Set_Stripe_Array(cStripe_LED, (uint8_t *)DisplayColor, StripeBrightness);
}

void JAZZ_Graphic(uint32_t *CountingTime)
{
		/* Graphic */
		Set_Graphic_RGB(cGraphic_LED, GraphicRGBColor[0][0] * GraphicBrightness * RightChannelVolume / 1000, GraphicRGBColor[0][1] * GraphicBrightness * RightChannelVolume / 1000, GraphicRGBColor[0][2] * GraphicBrightness * RightChannelVolume / 1000);
}

void JAZZ_Bar(uint32_t *CountingTime)
{
		/* Bar */
		Set_Bar_RGB(cBar_LED, BarRGBColor[0][0] * BarBrightness * LeftChannelVolume / 1000, BarRGBColor[0][1] * BarBrightness * LeftChannelVolume / 1000, BarRGBColor[0][2] * BarBrightness * LeftChannelVolume / 1000);
}

void JAZZ_Stripe(uint32_t *CountingTime)
{
		/* Stripe */
		Set_Stripe_RGB(cStripe_LED, StripeRGBColor[0][0] * StripeBrightness * MainVolume / 1000, StripeRGBColor[0][1] * StripeBrightness * MainVolume / 1000, StripeRGBColor[0][2] * BarBrightness * MainVolume / 1000);
}

void Play_Graphic(uint32_t *CountingTime)
{
		uint8_t DisplayColor[3] = {0};
		uint8_t i;
		
		/* Calculate Graphic Color */
		if(RightChannelVolume == 0)
		{
				for(i = 0; i < 3; i++)
						DisplayColor[i] = 0;
		}
		else
		{
				/* 0(Green) ----- 50(Orange) ----- 100(Red) */
				if(RightChannelVolume > 50)
				{
						for(i = 0; i < 3; i++)
								DisplayColor[i] = ((RightChannelVolume - 50) * RainbowColor[Red][i] + (100 - RightChannelVolume) * RainbowColor[Orange][i]) / 50;
				}
				else
				{
						for(i = 0; i < 3; i++)
								DisplayColor[i] = (RightChannelVolume * RainbowColor[Orange][i] + (50 - RightChannelVolume) * RainbowColor[Green][i]) / 50;				
				}
		}
	
		/* Graphic */
		Set_Graphic_RGB(cGraphic_LED, DisplayColor[0] * GraphicBrightness / 10, DisplayColor[1] * GraphicBrightness / 10, DisplayColor[2] * GraphicBrightness / 10);
}

void Play_Bar(uint32_t *CountingTime)
{
		uint8_t DisplayColor[3] = {0};
		uint8_t i;
		
		/* Calculate Bar Color */
		if(LeftChannelVolume == 0)
		{
				for(i = 0; i < 3; i++)
						DisplayColor[i] = 0;
		}
		else
		{
				/* 0(Green) ----- 50(Orange) ----- 100(Red) */
				if(LeftChannelVolume > 50)
				{
						for(i = 0; i < 3; i++)
								DisplayColor[i] = ((LeftChannelVolume - 50) * RainbowColor[Red][i] + (100 - LeftChannelVolume) * RainbowColor[Orange][i]) / 50;
				}
				else
				{
						for(i = 0; i < 3; i++)
								DisplayColor[i] = (LeftChannelVolume * RainbowColor[Orange][i] + (50 - LeftChannelVolume) * RainbowColor[Green][i]) / 50;				
				}
		}
	
		/* Bar */
		Set_Bar_RGB(cBar_LED, DisplayColor[0] * BarBrightness / 10, DisplayColor[1] * BarBrightness / 10, DisplayColor[2] * BarBrightness / 10);
}

void Play_Stripe(uint32_t *CountingTime)
{
		uint8_t DisplayColor[3] = {0};
		uint8_t i;
		
		/* Calculate Stripe Color */
		if(MainVolume == 0)
		{
				for(i = 0; i < 3; i++)
						DisplayColor[i] = 0;
		}
		else
		{
				/* 0(Green) ----- 50(Orange) ----- 100(Red) */
				if(MainVolume > 50)
				{
						for(i = 0; i < 3; i++)
								DisplayColor[i] = ((MainVolume - 50) * RainbowColor[Red][i] + (100 - MainVolume) * RainbowColor[Orange][i]) / 50;
				}
				else
				{
						for(i = 0; i < 3; i++)
								DisplayColor[i] = (MainVolume * RainbowColor[Orange][i] + (50 - MainVolume) * RainbowColor[Green][i]) / 50;				
				}
		}
	
		/* Stripe */
		Set_Stripe_RGB(cStripe_LED, DisplayColor[0] * StripeBrightness / 10, DisplayColor[1] * StripeBrightness / 10, DisplayColor[2] * BarBrightness / 10);
}

void Movie_Graphic(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cGraphic_LED][3] = {0};
		uint8_t i, j;
		
		/* Calculate Graphic Color */
		if(RightChannelVolume > 0)
		{
				for(i = 0; i < 3; i++)
				{
						DisplayColor[8][i] = GraphicRGBColor[0][i];
				}
		}
		if(RightChannelVolume > 33)
		{
				for(j = 4; j < 8; j++)
				{
						for(i = 0; i < 3; i++)
						{
								DisplayColor[j][i] = GraphicRGBColor[0][i];
						}
				}
		}
		if(RightChannelVolume > 66)
		{
				for(j = 0; j < 4; j++)
				{
						for(i = 0; i < 3; i++)
						{
								DisplayColor[j][i] = GraphicRGBColor[0][i];
						}
				}
		}		
	
		/* Graphic */
		Set_Graphic_Array(cGraphic_LED, (uint8_t *)DisplayColor, GraphicBrightness);
}

void Movie_Bar(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cBar_LED][3] = {0};
		uint8_t Unit_Volume = (LeftChannelVolume * cBar_LED) / 100;
		uint8_t i, j;
		
		/* Calculate Bar Color */
		for(j = 0; j < Unit_Volume; j++)
		{
				for(i = 0; i < 3; i++)
				{
						DisplayColor[j][i] = BarRGBColor[0][i];
				}
		}
	
		/* Bar */
		Set_Bar_Array(cBar_LED, (uint8_t *)DisplayColor, BarBrightness);
}

void Movie_Stripe(uint32_t *CountingTime)
{
		uint8_t DisplayColor[cStripe_LED][3] = {0};
		uint8_t Unit_Volume = (MainVolume * cStripe_LED) / 100;
		uint8_t i, j;
		
		/* Calculate Stripe Color */
		for(j = 0; j < Unit_Volume; j++)
		{
				for(i = 0; i < 3; i++)
				{
						DisplayColor[j][i] = StripeRGBColor[0][i];
				}
		}
	
		/* Stripe */
		Set_Stripe_Array(cStripe_LED, (uint8_t *)DisplayColor, StripeBrightness);
}
