/******************************************************************************
 * @file     Serial_LED.h
 * @brief    Serial LED lighting effects header file
 *
 * @note
 * Copyright (C) 2016 Nuvoton Technology Corp. All rights reserved.
 ******************************************************************************/
#ifndef __Serial_LED_H__
#define __Serial_LED_H__

#include <stdint.h>

extern uint8_t RGBBright[1];
extern const uint8_t DisableColor[1][3];
extern const uint8_t DisableBright[1];
extern const uint8_t FixedRate[3];
#define BreathingArraySize 70
extern const uint8_t BreathingBright[BreathingArraySize];													
extern const uint8_t BreathingRate[3];
#define FlashingArraySize 25
#define DoubleFlashingArraySize 31
extern const uint8_t DoubleFlashingBright[31];
extern const uint8_t DoubleFlashingRate[3];
extern const uint8_t MeteorBright[95];
extern const uint8_t StackBright[150];																	
extern const uint8_t RainbowColor[16][3];
extern const uint8_t RainbowBright[91];							 
extern const uint8_t RainbowRate[3];
extern const uint8_t LightingRate[3];

/*-------------------------------------------------------------*/
void USPI_Init(void);
void SPI_Init(void);
void Set_GraphicLED(void);
void Set_BarLED(void);
void Set_StripeLED(void);
void Reset_GraphicLED(void);
void Reset_BarLED(void);
void Reset_StripeLED(void);

/*------Disable------------------------------------------------*/
void Disable_Graphic(uint32_t *CountingTime);
void Disable_Bar(uint32_t *CountingTime);
void Disable_Stripe(uint32_t *CountingTime);
/*------NoAnimation--------------------------------------------*/
void NoAnimation_Graphic(void);
void NoAnimation_Bar(void);
void NoAnimation_Stripe(void);
/*------Breathing----------------------------------------------*/
void Breathing_Graphic(uint32_t *CountingTime);
void Breathing_Bar(uint32_t *CountingTime);
void Breathing_Stripe(uint32_t *CountingTime);
/*------Flashing-----------------------------------------------*/
void Flashing_Graphic(uint32_t *CountingTime);
void Flashing_Bar(uint32_t *CountingTime);
void Flashing_Stripe(uint32_t *CountingTime);
/*------DoubleFlashing-----------------------------------------*/
void DoubleFlashing_Graphic(uint32_t *CountingTime);
void DoubleFlashing_Bar(uint32_t *CountingTime);
void DoubleFlashing_Stripe(uint32_t *CountingTime);
/*------Marquee------------------------------------------------*/
void Marquee_Graphic(uint32_t *CountingTime);
void Marquee_Bar(uint32_t *CountingTime);
void Marquee_Stripe(uint32_t *CountingTime);
/*------Meteor-------------------------------------------------*/
void Meteor_Graphic(uint32_t *CountingTime);
void Meteor_Bar(uint32_t *CountingTime);
void Meteor_Stripe(uint32_t *CountingTime);
/*------Rainbow------------------------------------------------*/
void Rainbow_Graphic(uint32_t *CountingTime);
void Rainbow_Bar(uint32_t *CountingTime);
void Rainbow_Stripe(uint32_t *CountingTime);
/*------Lighting-----------------------------------------------*/
void Lighting_Graphic(uint32_t *CountingTime);
void Lighting_Bar(uint32_t *CountingTime);
void Lighting_Stripe(uint32_t *CountingTime);

/* Music Function */
/*------POP----------------------------------------------------*/
void POP_Graphic(uint32_t *CountingTime);
void POP_Bar(uint32_t *CountingTime);
void POP_Stripe(uint32_t *CountingTime);
/*------JAZZ----------------------------------------------------*/
void JAZZ_Graphic(uint32_t *CountingTime);
void JAZZ_Bar(uint32_t *CountingTime);
void JAZZ_Stripe(uint32_t *CountingTime);
/*------Play----------------------------------------------------*/
void Play_Graphic(uint32_t *CountingTime);
void Play_Bar(uint32_t *CountingTime);
void Play_Stripe(uint32_t *CountingTime);
/*------Movie---------------------------------------------------*/
void Movie_Graphic(uint32_t *CountingTime);
void Movie_Bar(uint32_t *CountingTime);
void Movie_Stripe(uint32_t *CountingTime);

#endif  /* __Serial_LED_H__ */

/*** (C) COPYRIGHT 2016 Nuvoton Technology Corp. ***/
