/******************************************************************************
 * @file     device.h
 * @brief    LED DEMO device header file
 *
 * @note
 * Copyright (C) 2016 Nuvoton Technology Corp. All rights reserved.
 ******************************************************************************/
#include <stdint.h>

#define Band_Gap 1.21
#define ADC_Temp_Gain -1.76
#define ADC_Temp_Offset 725

/*!<Define COM port */
/* COM0 */
#define COM0_PORT			PB
#define COM0_BIT			BIT0
#define COM0_PIN			PB0
#define COM0_ON()			(COM0_PIN = 0)
#define COM0_OFF()		(COM0_PIN = 1)
#define COM0_Init()		COM0_OFF();GPIO_SetMode(COM0_PORT, COM0_BIT, GPIO_MODE_OUTPUT)
/* COM1 */
#define COM1_PORT			PB
#define COM1_BIT			BIT1
#define COM1_PIN			PB1
#define COM1_ON()			(COM1_PIN = 0)
#define COM1_OFF()		(COM1_PIN = 1)
#define COM1_Init()		COM1_OFF();GPIO_SetMode(COM1_PORT, COM1_BIT, GPIO_MODE_OUTPUT)
/* COM2 */
#define COM2_PORT			PB
#define COM2_BIT			BIT10
#define COM2_PIN			PB10
#define COM2_ON()			(COM2_PIN = 0)
#define COM2_OFF()		(COM2_PIN = 1)
#define COM2_Init()		COM2_OFF();GPIO_SetMode(COM2_PORT, COM2_BIT, GPIO_MODE_OUTPUT)
/* COM3 */
#define COM3_PORT			PB
#define COM3_BIT			BIT9
#define COM3_PIN			PB9
#define COM3_ON()			(COM3_PIN = 0)
#define COM3_OFF()		(COM3_PIN = 1)
#define COM3_Init()		COM3_OFF();GPIO_SetMode(COM3_PORT, COM3_BIT, GPIO_MODE_OUTPUT)
/* COM4 */
#define COM4_PORT			PC
#define COM4_BIT			BIT13
#define COM4_PIN			PC13
#define COM4_ON()			(COM4_PIN = 0)
#define COM4_OFF()		(COM4_PIN = 1)
#define COM4_Init()		COM4_OFF();GPIO_SetMode(COM4_PORT, COM4_BIT, GPIO_MODE_OUTPUT)
/* COM5 */
#define COM5_PORT			PC
#define COM5_BIT			BIT12
#define COM5_PIN			PC12
#define COM5_ON()			(COM5_PIN = 0)
#define COM5_OFF()		(COM5_PIN = 1)
#define COM5_Init()		COM5_OFF();GPIO_SetMode(COM5_PORT, COM5_BIT, GPIO_MODE_OUTPUT)
/* COM6 */
#define COM6_PORT			PC
#define COM6_BIT			BIT10
#define COM6_PIN			PC10
#define COM6_ON()			(COM6_PIN = 0)
#define COM6_OFF()		(COM6_PIN = 1)
#define COM6_Init()		COM6_OFF();GPIO_SetMode(COM6_PORT, COM6_BIT, GPIO_MODE_OUTPUT)
/* COM7 */
#define COM7_PORT			PE
#define COM7_BIT			BIT1
#define COM7_PIN			PE1
#define COM7_ON()			(COM7_PIN = 0)
#define COM7_OFF()		(COM7_PIN = 1)
#define COM7_Init()		COM7_OFF();GPIO_SetMode(COM7_PORT, COM7_BIT, GPIO_MODE_OUTPUT)

/*!<Define DEMO detection port */
#define DEMO_Mode_PORT		PF
#define DEMO_Mode_BIT			BIT5
#define DEMO_Mode_NUM			5
#define DEMO_Mode_PIN			PF5
#define DEMO_Mode_Init()	SYS->GPF_MFPL=SYS->GPF_MFPL&(~SYS_GPF_MFPL_PF5MFP_Msk);GPIO_SetMode(DEMO_Mode_PORT, DEMO_Mode_BIT, GPIO_MODE_INPUT)
#define DEMO_Color_PORT		PF
#define DEMO_Color_BIT		BIT4
#define DEMO_Color_NUM		4
#define DEMO_Color_PIN		PF4
#define DEMO_Color_Init()	SYS->GPF_MFPL=SYS->GPF_MFPL&(~SYS_GPF_MFPL_PF4MFP_Msk);GPIO_SetMode(DEMO_Color_PORT, DEMO_Color_BIT, GPIO_MODE_INPUT)

/*!<Define Serial Data port */
#define Serial_DataGraphic_PORT			PD
#define Serial_DataGraphic_BIT			BIT8
#define Serial_DataGraphic_PIN			PD8
#define Serial_DataGraphic_Reset()	(Serial_DataGraphic_PIN = 0)
#define Serial_DataGraphic_Init()		Serial_DataGraphic_Reset();GPIO_SetMode(Serial_DataGraphic_PORT, Serial_DataGraphic_BIT, GPIO_MODE_OUTPUT);(SYS->GPD_MFPH=(SYS->GPD_MFPH&(~SYS_GPD_MFPH_PD8MFP_Msk))|(SYS_GPD_MFPH_PD8MFP_GPIO))
#define Serial_DataGraphic_Open()		(SYS->GPD_MFPH=(SYS->GPD_MFPH&(~SYS_GPD_MFPH_PD8MFP_Msk))|(SYS_GPD_MFPH_PD8MFP_USCI0_DAT0))
#define Serial_DataBar_PORT					PD
#define Serial_DataBar_BIT					BIT3
#define Serial_DataBar_PIN					PD3
#define Serial_DataBar_Reset()			(Serial_DataBar_PIN = 0)
#define Serial_DataBar_Init()				Serial_DataBar_Reset();GPIO_SetMode(Serial_DataBar_PORT, Serial_DataBar_BIT, GPIO_MODE_OUTPUT);(SYS->GPD_MFPL=(SYS->GPD_MFPL&(~SYS_GPD_MFPL_PD3MFP_Msk))|(SYS_GPD_MFPL_PD3MFP_GPIO))
#define Serial_DataBar_Open()				(SYS->GPD_MFPL=(SYS->GPD_MFPL&(~SYS_GPD_MFPL_PD3MFP_Msk))|(SYS_GPD_MFPL_PD3MFP_USCI0_DAT0))

enum eLightingMode
{
		Disable,
		No_Animation,
		Breathing,
		Flashing,
		Double_Flashing,
		Marquees,
		Meteor,
		Rainbow,
		Lighting,
		/*--------------*/
		ChasingMeteor,
		UpDown,
		Waterfall,
		Stack,
		Rainbow_Waterfall
};

enum eBreathingSpeed
{
		Low,
		Medium,
		High
};

enum eBrightness
{
		B20 = 2,
		B40 = 4,
		B60 = 6,
		B80 = 8,
		B100 = 10
};

enum eRainbow
{
		Red = 0,
		Orange = 2,
		Yellow = 4,
		Green = 6,
		Cyan = 8,
		Blue = 10,
		Indigo = 12,
		Purple = 14
};

/*** (C) COPYRIGHT 2016 Nuvoton Technology Corp. ***/
