/******************************************************************************//**
 * @file     main.c
 * @version  V3.00
 * @brief
 *           Demonstrate how to transfer data between USB device and PC through USB HID interface.
 *           A windows tool is also included in this sample code to connect with USB device.
 *
 * @copyright (C) 2016 Nuvoton Technology Corp. All rights reserved.
 ******************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include "NUC121.h"
#include "hid_transfer.h"
#include "RGB_LED.h"
#include "Serial_LED.h"
#include "device.h"
#include "Global_Variable.h"

#define Color_Intensity 254
#define LED_Brightness	10
#define PWM_Frequency 10000
/* PWM Frequency = 76200000 / (Color_Intensity * LED_Brightness * PWM_Prescaler) */
#define PWM_Prescaler	(76200000 / (Color_Intensity * LED_Brightness * PWM_Frequency ))

#define Data_Address 0x7E00

extern uint8_t RcvBuffer[64];
extern uint8_t set_report_flag;
extern uint8_t get_set_report_flag;

uint32_t PWMCounter = 0;
uint32_t TimeCounter = 0;

uint8_t	ptrDEMOColor = 0;
uint8_t Change_Flag = 0;
uint8_t LED_Mode_Flag = 0;
uint8_t LED_Color_Flag = 0;
uint8_t Random_Change_Flag = 0;

/*--------------------------------------------------------------------------*/
void SYS_Init(void)
{
    /*---------------------------------------------------------------------------------------------------------*/
    /* Init System Clock                                                                                       */
    /*---------------------------------------------------------------------------------------------------------*/
    /* Enable Internal HIRC 48 MHz clock */
    CLK_EnableXtalRC(CLK_PWRCTL_HIRCEN);

    /* Waiting for Internal RC clock ready */
    CLK_WaitClockReady(CLK_STATUS_HIRCSTB_Msk);

    /* Switch HCLK clock source to Internal HIRC and HCLK source divide 1 */
    CLK_SetHCLK(CLK_CLKSEL0_HCLKSEL_HIRC, CLK_CLKDIV0_HCLK(1));

    /* Enable and apply new PLL setting; PLL = 76.2MHz */
    CLK->PLLCTL = CLK_PLLCTL_PLLSRC_HIRC_DIV2 | CLK_PLLCTL_NO_4 | CLK_PLLCTL_NR(10) | CLK_PLLCTL_NF(127);

    /* Wait for PLL clock stable */
    CLK_WaitClockReady(CLK_STATUS_PLLSTB_Msk);
	
    /* Enable module clock */
    CLK_EnableModuleClock(USBD_MODULE);
    CLK_EnableModuleClock(PWM0_MODULE);
		CLK_EnableModuleClock(PWM1_MODULE);
		CLK_EnableModuleClock(BPWM0_MODULE);
    CLK_EnableModuleClock(TMR0_MODULE);
		CLK_EnableModuleClock(TMR1_MODULE);
    CLK_EnableModuleClock(PDMA_MODULE);
		
    /*---------------------------------------------------------------------------------------------------------*/
    /* PWM clock frequency configuration                                                                       */
    /*---------------------------------------------------------------------------------------------------------*/
    /* Select HCLK clock source as PLL and and HCLK clock divider as 2 */
    CLK_SetHCLK(CLK_CLKSEL0_HCLKSEL_PLL, CLK_CLKDIV0_HCLK(2));

    /* Select PWM0, PWM1 and BPWM0 module clock source as PLL */
    CLK_SetModuleClock(PWM0_MODULE, CLK_CLKSEL1_PWM0SEL_PLL, NULL);
		CLK_SetModuleClock(PWM1_MODULE, CLK_CLKSEL1_PWM1SEL_PLL, NULL);
		CLK_SetModuleClock(BPWM0_MODULE, CLK_CLKSEL1_BPWM0SEL_PLL, NULL);

    /* Select module clock source */
    CLK_SetModuleClock(USBD_MODULE, CLK_CLKSEL3_USBDSEL_HIRC, CLK_CLKDIV0_USB(1));
		CLK_SetModuleClock(TMR0_MODULE, CLK_CLKSEL1_TMR0SEL_HIRC_DIV2, NULL);
		CLK_SetModuleClock(TMR1_MODULE, CLK_CLKSEL1_TMR1SEL_HIRC_DIV2, NULL);
		CLK_SetModuleClock(ADC_MODULE, CLK_CLKSEL1_ADCSEL_HIRC, CLK_CLKDIV0_ADC(24));

		/* Reset module */
    SYS_ResetModule(PWM0_RST);
		SYS_ResetModule(TMR0_RST);
		SYS_ResetModule(TMR1_RST);
    SYS_ResetModule(PDMA_RST);
		
		/* Update System Core Clock */
    SystemCoreClockUpdate();

    /*---------------------------------------------------------------------------------------------------------*/
    /* Init I/O Multi-function                                                                                 */
    /*---------------------------------------------------------------------------------------------------------*/
    /* Set multi-function pins for COM0~7 */
		COM0_Init();
		COM1_Init();
		COM2_Init();
		COM3_Init();
		COM4_Init();
		COM5_Init();
		COM6_Init();
		COM7_Init();

    /* Set multi-function pins for LED DEMO */
		DEMO_Mode_Init();
		GPIO_ENABLE_DEBOUNCE(DEMO_Mode_PORT, DEMO_Mode_BIT);
		DEMO_Color_Init();
		GPIO_ENABLE_DEBOUNCE(DEMO_Color_PORT, DEMO_Color_BIT);
		GPIO_SET_DEBOUNCE_TIME(GPIO_DBCTL_DBCLKSRC_LIRC, GPIO_DBCTL_DBCLKSEL_512);
		GPIO_EnableInt(DEMO_Mode_PORT, DEMO_Mode_NUM, GPIO_INT_FALLING);
		GPIO_EnableInt(DEMO_Color_PORT, DEMO_Color_NUM, GPIO_INT_FALLING);
		NVIC_EnableIRQ(GPCDEF_IRQn);
}

void PWM_Init(void)
{
    /*---------------------------------------------------------------------------------------------------------*/
    /* Init PWM & BPWM                                                                                         */
    /*---------------------------------------------------------------------------------------------------------*/
    /* Set prescaler of PWM0 for channel0~2 as PWM_Prescaler for Group1 */
		/* Set prescaler of PWM0 for channel3~5 as PWM_Prescaler for Group2 */
		/* Set prescaler of PWM1 for channel0~2 as PWM_Prescaler for Group3 */
		/* Set prescaler of PWM1 for channel3~5 as PWM_Prescaler for Group4 */
		/* Set prescaler of BPWM0 for channel0~2 as PWM_Prescaler for Group5 */
		/* Set prescaler of BPWM0 for channel3~5 as PWM_Prescaler for Stripline */
		PWM0->CLKPSC0_1 = (PWM_Prescaler - 1);
		PWM0->CLKPSC2_3 = (PWM_Prescaler - 1);
		PWM0->CLKPSC4_5 = (PWM_Prescaler - 1);
		PWM1->CLKPSC0_1 = (PWM_Prescaler - 1);
		PWM1->CLKPSC2_3 = (PWM_Prescaler - 1);
		PWM1->CLKPSC4_5 = (PWM_Prescaler - 1);
		BPWM0->CLKPSC = (PWM_Prescaler - 1);
	
    /* Set period of PWM0 for channel0~2 as (Color_Intensity * LED_Brightness) for Group1 */
		/* Set period of PWM0 for channel3~5 as (Color_Intensity * LED_Brightness) for Group2 */
		/* Set period of PWM1 for channel0~2 as (Color_Intensity * LED_Brightness) for Group3 */
		/* Set period of PWM1 for channel3~5 as (Color_Intensity * LED_Brightness) for Group4 */
		/* Set period of BPWM0 for channel0~2 as (Color_Intensity * LED_Brightness) for Group5 */
		/* Set period of BPWM0 for channel3~5 as (Color_Intensity * LED_Brightness) for Stripline */
		PWM0->PERIOD[0] = (Color_Intensity * LED_Brightness - 1);
		PWM0->PERIOD[2] = (Color_Intensity * LED_Brightness - 1);
		PWM0->PERIOD[4] = (Color_Intensity * LED_Brightness - 1);
		PWM1->PERIOD[0] = (Color_Intensity * LED_Brightness - 1);
		PWM1->PERIOD[2] = (Color_Intensity * LED_Brightness - 1);
		PWM1->PERIOD[4] = (Color_Intensity * LED_Brightness - 1);
		BPWM0->PERIOD = (Color_Intensity * LED_Brightness - 1);

    /* Set compare of PWM0 for channel0~2 as 0 for Group1 */
		/* Set compare of PWM0 for channel3~5 as 0 for Group2 */
		/* Set compare of PWM1 for channel0~2 as 0 for Group3 */
		/* Set compare of PWM1 for channel3~5 as 0 for Group4 */
		/* Set compare of BPWM0 for channel0~2 as 0 for Group5 */
		/* Set compare of BPWM0 for channel3~5 as 0 for Stripline */
		PWM0->CMPDAT[0] = 0;		// Group1_R
		PWM0->CMPDAT[1] = 0;		// Group1_G
		PWM0->CMPDAT[2] = 0;		// Group1_B
		PWM0->CMPDAT[3] = 0;		// Group2_R
		PWM0->CMPDAT[4] = 0;		// Group2_G
		PWM0->CMPDAT[5] = 0;		// Group2_B
		PWM1->CMPDAT[0] = 0;		// Group3_R
		PWM1->CMPDAT[1] = 0;		// Group3_G
		PWM1->CMPDAT[2] = 0;		// Group3_B
		PWM1->CMPDAT[3] = 0;		// Group4_R
		PWM1->CMPDAT[4] = 0;		// Group4_G
		PWM1->CMPDAT[5] = 0;		// Group4_B
		BPWM0->CMPDAT[0] = 0;		// Group5_R
		BPWM0->CMPDAT[1] = 0;		// Group5_G
		BPWM0->CMPDAT[2] = 0;		// Group5_B
		BPWM0->CMPDAT[3] = 0;		// Stripline_R
		BPWM0->CMPDAT[4] = 0;		// Stripline_G
		BPWM0->CMPDAT[5] = 0;		// Stripline_B

		/* Set Counter Type; 0 : Up Count ; 1 : Down Count ; 2 : Up-Down Count */
		PWM0->CTL1 = (0 << PWM_CTL1_CNTTYPE0_Pos) | (0 << PWM_CTL1_CNTTYPE2_Pos) | (0 << PWM_CTL1_CNTTYPE4_Pos);
		PWM1->CTL1 = (0 << PWM_CTL1_CNTTYPE0_Pos) | (0 << PWM_CTL1_CNTTYPE2_Pos) | (0 << PWM_CTL1_CNTTYPE4_Pos);
		BPWM0->CTL1 = (0 << BPWM_CTL1_CNTTYPE0_Pos);
		
		/* Set Zero Point Output High; 0 : Do Nothing ; 1 : Low ; 2 : High ; 3 : Toggle */
		PWM0->WGCTL0 = (2 << PWM_WGCTL0_ZPCTL0_Pos) | (2 << PWM_WGCTL0_ZPCTL1_Pos) | (2 << PWM_WGCTL0_ZPCTL2_Pos) |
									 (2 << PWM_WGCTL0_ZPCTL3_Pos) | (2 << PWM_WGCTL0_ZPCTL4_Pos) | (2 << PWM_WGCTL0_ZPCTL5_Pos);
		PWM1->WGCTL0 = (2 << PWM_WGCTL0_ZPCTL0_Pos) | (2 << PWM_WGCTL0_ZPCTL1_Pos) | (2 << PWM_WGCTL0_ZPCTL2_Pos) |
									 (2 << PWM_WGCTL0_ZPCTL3_Pos) | (2 << PWM_WGCTL0_ZPCTL4_Pos) | (2 << PWM_WGCTL0_ZPCTL5_Pos);
		BPWM0->WGCTL0 = (2 << BPWM_WGCTL0_ZPCTL0_Pos) | (2 << BPWM_WGCTL0_ZPCTL1_Pos) | (2 << BPWM_WGCTL0_ZPCTL2_Pos) |
									  (2 << BPWM_WGCTL0_ZPCTL3_Pos) | (2 << BPWM_WGCTL0_ZPCTL4_Pos) | (2 << BPWM_WGCTL0_ZPCTL5_Pos);									 
		
		/* Set Compare Up Point Output Low; 0 : Do Nothing ; 1 : Low ; 2 : High ; 3 : Toggle */
		PWM0->WGCTL1 = (1 << PWM_WGCTL1_CMPUCTL0_Pos) | (1 << PWM_WGCTL1_CMPUCTL1_Pos) | (1 << PWM_WGCTL1_CMPUCTL2_Pos) |
		               (1 << PWM_WGCTL1_CMPUCTL3_Pos) | (1 << PWM_WGCTL1_CMPUCTL4_Pos) | (1 << PWM_WGCTL1_CMPUCTL5_Pos);
		PWM1->WGCTL1 = (1 << PWM_WGCTL1_CMPUCTL0_Pos) | (1 << PWM_WGCTL1_CMPUCTL1_Pos) | (1 << PWM_WGCTL1_CMPUCTL2_Pos) |
		               (1 << PWM_WGCTL1_CMPUCTL3_Pos) | (1 << PWM_WGCTL1_CMPUCTL4_Pos) | (1 << PWM_WGCTL1_CMPUCTL5_Pos);
		BPWM0->WGCTL1 = (1 << BPWM_WGCTL1_CMPUCTL0_Pos) | (1 << BPWM_WGCTL1_CMPUCTL1_Pos) | (1 << BPWM_WGCTL1_CMPUCTL2_Pos) |
		                (1 << BPWM_WGCTL1_CMPUCTL3_Pos) | (1 << BPWM_WGCTL1_CMPUCTL4_Pos) | (1 << BPWM_WGCTL1_CMPUCTL5_Pos);

    /* Enable PWM0 Output path for channel0~5; PWM1 Output path for channel0~5; BPWM0 Output path for channel0~5 */
		PWM0->POEN = 0x3F;
		PWM1->POEN = 0x3F;
		BPWM0->POEN = 0x3F;

    /* Start PWM0; 0 : Counter Stop Running, 	1 : Counter Start Running */
		PWM0->CNTEN = (1 << PWM_CNTEN_CNTEN0_Pos) | (1 << PWM_CNTEN_CNTEN2_Pos) | (1 << PWM_CNTEN_CNTEN4_Pos);
		PWM1->CNTEN = (1 << PWM_CNTEN_CNTEN0_Pos) | (1 << PWM_CNTEN_CNTEN2_Pos) | (1 << PWM_CNTEN_CNTEN4_Pos);
		BPWM0->CNTEN = (1 << BPWM_CNTEN_CNTEN0_Pos);
		
		/* Set multi-function pins for PWM0 Channel0~5 */
    SYS->GPA_MFPH = (SYS->GPA_MFPH & (~SYS_GPA_MFPH_PA12MFP_Msk));
    SYS->GPA_MFPH |= SYS_GPA_MFPH_PA12MFP_PWM0_CH0;
    SYS->GPA_MFPH = (SYS->GPA_MFPH & (~SYS_GPA_MFPH_PA13MFP_Msk));
    SYS->GPA_MFPH |= SYS_GPA_MFPH_PA13MFP_PWM0_CH1;
    SYS->GPA_MFPH = (SYS->GPA_MFPH & (~SYS_GPA_MFPH_PA14MFP_Msk));
    SYS->GPA_MFPH |= SYS_GPA_MFPH_PA14MFP_PWM0_CH2;
    SYS->GPA_MFPH = (SYS->GPA_MFPH & (~SYS_GPA_MFPH_PA15MFP_Msk));
    SYS->GPA_MFPH |= SYS_GPA_MFPH_PA15MFP_PWM0_CH3;
    SYS->GPC_MFPH = (SYS->GPC_MFPH & (~SYS_GPC_MFPH_PC8MFP_Msk));
    SYS->GPC_MFPH |= SYS_GPC_MFPH_PC8MFP_PWM0_CH4;
    SYS->GPC_MFPH = (SYS->GPC_MFPH & (~SYS_GPC_MFPH_PC9MFP_Msk));
    SYS->GPC_MFPH |= SYS_GPC_MFPH_PC9MFP_PWM0_CH5;
		/* Set multi-function pins for PWM1 Channel0~5 */
    SYS->GPC_MFPL = (SYS->GPC_MFPL & (~SYS_GPC_MFPL_PC0MFP_Msk));
    SYS->GPC_MFPL |= SYS_GPC_MFPL_PC0MFP_PWM1_CH0;
    SYS->GPC_MFPL = (SYS->GPC_MFPL & (~SYS_GPC_MFPL_PC1MFP_Msk));
    SYS->GPC_MFPL |= SYS_GPC_MFPL_PC1MFP_PWM1_CH1;
    SYS->GPC_MFPL = (SYS->GPC_MFPL & (~SYS_GPC_MFPL_PC2MFP_Msk));
    SYS->GPC_MFPL |= SYS_GPC_MFPL_PC2MFP_PWM1_CH2;
    SYS->GPC_MFPL = (SYS->GPC_MFPL & (~SYS_GPC_MFPL_PC3MFP_Msk));
    SYS->GPC_MFPL |= SYS_GPC_MFPL_PC3MFP_PWM1_CH3;
    SYS->GPC_MFPL = (SYS->GPC_MFPL & (~SYS_GPC_MFPL_PC4MFP_Msk));
    SYS->GPC_MFPL |= SYS_GPC_MFPL_PC4MFP_PWM1_CH4;
    SYS->GPC_MFPL = (SYS->GPC_MFPL & (~SYS_GPC_MFPL_PC5MFP_Msk));
    SYS->GPC_MFPL |= SYS_GPC_MFPL_PC5MFP_PWM1_CH5;
		/* Set multi-function pins for BPWM0 Channel0~5 */
    SYS->GPB_MFPL = (SYS->GPB_MFPL & (~SYS_GPB_MFPL_PB7MFP_Msk));
    SYS->GPB_MFPL |= SYS_GPB_MFPL_PB7MFP_BPWM0_CH0;
    SYS->GPB_MFPL = (SYS->GPB_MFPL & (~SYS_GPB_MFPL_PB6MFP_Msk));
    SYS->GPB_MFPL |= SYS_GPB_MFPL_PB6MFP_BPWM0_CH1;
    SYS->GPB_MFPL = (SYS->GPB_MFPL & (~SYS_GPB_MFPL_PB5MFP_Msk));
    SYS->GPB_MFPL |= SYS_GPB_MFPL_PB5MFP_BPWM0_CH2;
    SYS->GPB_MFPL = (SYS->GPB_MFPL & (~SYS_GPB_MFPL_PB4MFP_Msk));
    SYS->GPB_MFPL |= SYS_GPB_MFPL_PB4MFP_BPWM0_CH3;
    SYS->GPD_MFPH = (SYS->GPD_MFPH & (~SYS_GPD_MFPH_PD11MFP_Msk));
    SYS->GPD_MFPH |= SYS_GPD_MFPH_PD11MFP_BPWM0_CH4;
    SYS->GPD_MFPH = (SYS->GPD_MFPH & (~SYS_GPD_MFPH_PD10MFP_Msk));
    SYS->GPD_MFPH |= SYS_GPD_MFPH_PD10MFP_BPWM0_CH5;
}

void PWM0_IRQHandler(void)
{
    /* Clear channel 0 period interrupt flag */
    PWM_ClearPeriodIntFlag(PWM0, 0);
		
		PWMCounter++;
		if(PWMCounter == 10)
		{
				PWMCounter = 0;
				TimeCounter++;
				G12TimeCounter++;
				G34TimeCounter++;
				G5TimeCounter++;
				RGB1TimeCounter++;
				GraphicTimeCounter++;
				BarTimeCounter++;
				StripeTimeCounter++;
				Change_Flag = 1;
			
//				/* Start PWM0; 0 : Counter Stop Running, 	1 : Counter Start Running */
//				PWM0->CNTEN = (0 << PWM_CNTEN_CNTEN0_Pos) | (0 << PWM_CNTEN_CNTEN2_Pos) | (0 << PWM_CNTEN_CNTEN4_Pos);
//				PWM1->CNTEN = (0 << PWM_CNTEN_CNTEN0_Pos) | (0 << PWM_CNTEN_CNTEN2_Pos) | (0 << PWM_CNTEN_CNTEN4_Pos);
//				BPWM0->CNTEN = (0 << BPWM_CNTEN_CNTEN0_Pos);
		}
}

void ReadStoredSetting(void)
{
		uint32_t Temp;

    /* Unlock write-protected registers */
    SYS_UnlockReg();
		
		/* Enable FMC ISP function */
		FMC_Open();

		/* Read Group1 & Group2 setting from Data Flash */
		Temp = FMC_Read(Data_Address);	
		G12LightingMode = Temp & 0xFF;
		G12RGBColor[0][0] = (Temp & 0xFF00) >> 8;
		G12RGBColor[0][1] = (Temp & 0xFF0000) >> 16;
		G12RGBColor[0][2] = (Temp & 0xFF000000) >> 24;
		Temp = FMC_Read(Data_Address + 4);
		G12BreathingSpeed = Temp & 0xFF;
		G12MaxBright = (Temp & 0xFF00) >> 8;
	
		/* Read Group3 & Group4 setting from Data Flash */
		Temp = FMC_Read(Data_Address + 8);	
		G34LightingMode = Temp & 0xFF;
		G34RGBColor[0][0] = (Temp & 0xFF00) >> 8;
		G34RGBColor[0][1] = (Temp & 0xFF0000) >> 16;
		G34RGBColor[0][2] = (Temp & 0xFF000000) >> 24;
		Temp = FMC_Read(Data_Address + 12);
		G34BreathingSpeed = Temp & 0xFF;
		G34MaxBright = (Temp & 0xFF00) >> 8;
		
		/* Read Group5 setting from Data Flash */
		Temp = FMC_Read(Data_Address + 16);	
		G5LightingMode = Temp & 0xFF;
		G5RGBColor[0][0] = (Temp & 0xFF00) >> 8;
		G5RGBColor[0][1] = (Temp & 0xFF0000) >> 16;
		G5RGBColor[0][2] = (Temp & 0xFF000000) >> 24;
		Temp = FMC_Read(Data_Address + 20);
		G5BreathingSpeed = Temp & 0xFF;
		G5MaxBright = (Temp & 0xFF00) >> 8;

		/* Read RGB Stripe setting from Data Flash */
		Temp = FMC_Read(Data_Address + 24);	
		RGB1LightingMode = Temp & 0xFF;
		RGB1RGBColor[0][0] = (Temp & 0xFF00) >> 8;
		RGB1RGBColor[0][1] = (Temp & 0xFF0000) >> 16;
		RGB1RGBColor[0][2] = (Temp & 0xFF000000) >> 24;
		Temp = FMC_Read(Data_Address + 28);
		RGB1BreathingSpeed = Temp & 0xFF;
		RGB1MaxBright = (Temp & 0xFF00) >> 8;

		/* Read Graphic LED setting from Data Flash */
		Temp = FMC_Read(Data_Address + 32);	
		GraphicLightingMode = Temp & 0xFF;
		Graphic_Fn = (Graphic_FUNC)Graphic_ptr[GraphicLightingMode];
		GraphicRGBColor[0][0] = (Temp & 0xFF00) >> 8;
		GraphicRGBColor[0][1] = (Temp & 0xFF0000) >> 16;
		GraphicRGBColor[0][2] = (Temp & 0xFF000000) >> 24;
		Temp = FMC_Read(Data_Address + 36);
		GraphicSpeed = Temp & 0xFF;
		GraphicBrightness = (Temp & 0xFF00) >> 8;

		/* Read Bar LED setting from Data Flash */
		Temp = FMC_Read(Data_Address + 32);	
		BarLightingMode = Temp & 0xFF;
		Bar_Fn = (Bar_FUNC)Bar_ptr[BarLightingMode];
		BarRGBColor[0][0] = (Temp & 0xFF00) >> 8;
		BarRGBColor[0][1] = (Temp & 0xFF0000) >> 16;
		BarRGBColor[0][2] = (Temp & 0xFF000000) >> 24;
		Temp = FMC_Read(Data_Address + 36);
		BarSpeed = Temp & 0xFF;
		BarBrightness = (Temp & 0xFF00) >> 8;
		
		/* Read Stripe LED setting from Data Flash */
		Temp = FMC_Read(Data_Address + 32);	
		StripeLightingMode = Temp & 0xFF;
		Stripe_Fn = (Stripe_FUNC)Stripe_ptr[StripeLightingMode];
		StripeRGBColor[0][0] = (Temp & 0xFF00) >> 8;
		StripeRGBColor[0][1] = (Temp & 0xFF0000) >> 16;
		StripeRGBColor[0][2] = (Temp & 0xFF000000) >> 24;
		Temp = FMC_Read(Data_Address + 36);
		StripeSpeed = Temp & 0xFF;
		StripeBrightness = (Temp & 0xFF00) >> 8;

    /* Lock protected registers */
    SYS_LockReg();
}

void WriteNewSetting(void)
{
		uint32_t Temp;

    /* Unlock write-protected registers */
    SYS_UnlockReg();
		
		/* Enable FMC ISP function */
		FMC_Open();

		FMC_Erase(Data_Address);

		/* Write Group1 & Group2 new setting to Data Flash */
		Temp = (G12RGBColor[0][2] << 24) | (G12RGBColor[0][1] << 16) | (G12RGBColor[0][0] << 8) | G12LightingMode;	
		FMC_Write(Data_Address, Temp);
		Temp = 0xFFFF0000 | (G12MaxBright << 8) | G12BreathingSpeed;
		FMC_Write(Data_Address + 4, Temp);

		/* Write Group3 & Group4 new setting to Data Flash */
		Temp = (G34RGBColor[0][2] << 24) | (G34RGBColor[0][1] << 16) | (G34RGBColor[0][0] << 8) | G34LightingMode;	
		FMC_Write(Data_Address + 8, Temp);
		Temp = 0xFFFF0000 | (G34MaxBright << 8) | G34BreathingSpeed;
		FMC_Write(Data_Address + 12, Temp);
		
		/* Write Group5 new setting to Data Flash */
		Temp = (G5RGBColor[0][2] << 24) | (G5RGBColor[0][1] << 16) | (G5RGBColor[0][0] << 8) | G5LightingMode;	
		FMC_Write(Data_Address + 16, Temp);
		Temp = 0xFFFF0000 | (G5MaxBright << 8) | G5BreathingSpeed;
		FMC_Write(Data_Address + 20, Temp);
		
		/* Write RGB Stripe new setting to Data Flash */
		Temp = (RGB1RGBColor[0][2] << 24) | (RGB1RGBColor[0][1] << 16) | (RGB1RGBColor[0][0] << 8) | RGB1LightingMode;	
		FMC_Write(Data_Address + 24, Temp);
		Temp = 0xFFFF0000 | (RGB1MaxBright << 8) | RGB1BreathingSpeed;
		FMC_Write(Data_Address + 28, Temp);
		
		/* Write Graphiec LED new setting to Data Flash */
		Temp = (GraphicRGBColor[0][2] << 24) | (GraphicRGBColor[0][1] << 16) | (GraphicRGBColor[0][0] << 8) | GraphicLightingMode;	
		FMC_Write(Data_Address + 32, Temp);
		Temp = 0xFFFF0000 | (GraphicBrightness << 8) | GraphicSpeed;
		FMC_Write(Data_Address + 36, Temp);
		
		/* Write Bar LED new setting to Data Flash */
		Temp = (BarRGBColor[0][2] << 24) | (BarRGBColor[0][1] << 16) | (BarRGBColor[0][0] << 8) | BarLightingMode;	
		FMC_Write(Data_Address + 40, Temp);
		Temp = 0xFFFF0000 | (BarBrightness << 8) | BarSpeed;
		FMC_Write(Data_Address + 44, Temp);
		
		/* Write Graphiec LED new setting to Data Flash */
		Temp = (StripeRGBColor[0][2] << 24) | (StripeRGBColor[0][1] << 16) | (StripeRGBColor[0][0] << 8) | StripeLightingMode;	
		FMC_Write(Data_Address + 48, Temp);
		Temp = 0xFFFF0000 | (StripeBrightness << 8) | StripeSpeed;
		FMC_Write(Data_Address + 52, Temp);
		
    /* Lock protected registers */
    SYS_LockReg();
}

void GPCDEF_IRQHandler(void)
{
		if(GPIO_GET_INT_FLAG(DEMO_Mode_PORT, DEMO_Mode_BIT))
		{
				GPIO_CLR_INT_FLAG(DEMO_Mode_PORT, DEMO_Mode_BIT);	
				LED_Mode_Flag = 1;
		}
		else
		{
				GPIO_CLR_INT_FLAG(DEMO_Color_PORT, DEMO_Color_BIT);	
				LED_Color_Flag = 1;
		}
}



/*---------------------------------------------------------------------------------------------------------*/
/*  Main Function                                                                                          */
/*---------------------------------------------------------------------------------------------------------*/
int32_t main(void)
{
		uint32_t Store_Flash;
		uint32_t G12TempCounter, G34TempCounter, G5TempCounter, RGB1TempCounter;
	
    /* Unlock write-protected registers */
    SYS_UnlockReg();
	             			        
    /* Init system and multi-funcition I/O */
    SYS_Init();
	
    /* Lock protected registers */
    SYS_LockReg();
	
		/* Init PWM0 channel0~5 and enable interrupt to add counter */
		PWM_Init();
		PWM_EnablePeriodInt(PWM0, 0, 0);
    NVIC_EnableIRQ(PWM0_IRQn);
	
		/* Init USCI_SPI0 to control WS2812B */
		PDMA_Open(PDMA_CHCTL_CHEN0_Msk | PDMA_CHCTL_CHEN1_Msk);
		USPI_Init();
		SPI_Init();

    /* Enable ADC module clock */
    CLK_EnableModuleClock(ADC_MODULE);
		/* Enable Tempreture Sensor function */
		SYS->IVSCTL |= SYS_IVSCTL_VTEMPEN_Msk;

    /* Open USB controller */
    USBD_Open(&gsInfo, HID_ClassRequest, NULL);
    /*Init Endpoint configuration for HID */
    HID_Init();
    /* Start USB device */
    USBD_Start();
    /* Enable USB device interrupt */
    NVIC_EnableIRQ(USBD_IRQn);
		
		/* Read setting from Data Flash */
		ReadStoredSetting();

//		G12LightingMode = No_Animation;
//		G12RGBColor[0][0] = 255;
//		G12RGBColor[0][1] = 0;
//		G12RGBColor[0][2] = 0;
//		G12BreathingSpeed = 0;
//		G12MaxBright = B100;
//		G34LightingMode = No_Animation;
//		G34RGBColor[0][0] = 255;
//		G34RGBColor[0][1] = 0;
//		G34RGBColor[0][2] = 0;
//		G34BreathingSpeed = 0;
//		G34MaxBright = B100;
//		G5LightingMode = No_Animation;
//		G5RGBColor[0][0] = 255;
//		G5RGBColor[0][1] = 0;
//		G5RGBColor[0][2] = 0;
//		G5BreathingSpeed = 0;
//		G5MaxBright = B100;
//		RGB1LightingMode = No_Animation;
//		RGB1RGBColor[0][0] = 255;
//		RGB1RGBColor[0][1] = 0;
//		RGB1RGBColor[0][2] = 0;
//		RGB1BreathingSpeed = 0;
//		RGB1MaxBright = B100;
//		GraphicLightingMode = 1;
//		Graphic_Fn = (Graphic_FUNC)NoAnimation_Graphic;
//		GraphicRGBColor[0][0] = 255;
//		GraphicRGBColor[0][1] = 0;
//		GraphicRGBColor[0][2] = 0;
//		GraphicSpeed = 0;
//		GraphicBrightness = B40;
//		BarLightingMode = 1;
//		Bar_Fn = (Bar_FUNC)NoAnimation_Bar;
//		BarRGBColor[0][0] = 255;
//		BarRGBColor[0][1] = 0;
//		BarRGBColor[0][2] = 0;
//		BarSpeed = 0;
//		BarBrightness = B40;
//		StripeLightingMode = 1;
//		Stripe_Fn = (Stripe_FUNC)NoAnimation_Stripe;
//		StripeRGBColor[0][0] = 255;
//		StripeRGBColor[0][1] = 0;
//		StripeRGBColor[0][2] = 0;
//		StripeSpeed = 0;
//		StripeBrightness = B40;	
//		Store_Flash = 0;

		G12Mode_Reset();
		G34Mode_Reset();
		G5Mode_Reset();
		RGB1Mode_Reset();
		Reset_GraphicLED();
		while(!fPDMA_GraphicDone);
		Reset_BarLED();
		while(!fPDMA_BarDone);
		Reset_StripeLED();

		/* Use PWM_CNT0 as seed of random function */
		srand(PWM0->CNT[0]);
		
    while(1)
		{
				if((set_report_flag == 1) && (get_set_report_flag == 1))
        {
						/* clear set report flag */
						set_report_flag = 0;
						get_set_report_flag = 0;   

						if(RcvBuffer[0] == 2)
						{
								/* Get Group1 & Group2 Setting */
								G12LightingMode = RcvBuffer[1];
								G12RGBColor[0][0] = RcvBuffer[2];
								G12RGBColor[0][1] = RcvBuffer[3];
								G12RGBColor[0][2] = RcvBuffer[4];
								G12BreathingSpeed = RcvBuffer[5];
								G12MaxBright = RcvBuffer[6];
								/* Get Group3 & Group4 Setting */
								G34LightingMode = RcvBuffer[7];
								G34RGBColor[0][0] = RcvBuffer[8];
								G34RGBColor[0][1] = RcvBuffer[9];
								G34RGBColor[0][2] = RcvBuffer[10];
								G34BreathingSpeed = RcvBuffer[11];
								G34MaxBright = RcvBuffer[12];
								/* Get Group5 Setting */
								G5LightingMode = RcvBuffer[13];
								G5RGBColor[0][0] = RcvBuffer[14];
								G5RGBColor[0][1] = RcvBuffer[15];
								G5RGBColor[0][2] = RcvBuffer[16];
								G5BreathingSpeed = RcvBuffer[17];
								G5MaxBright = RcvBuffer[18];
								/* Get RGB Stripe Setting */
								RGB1LightingMode = RcvBuffer[19];
								RGB1RGBColor[0][0] = RcvBuffer[20];
								RGB1RGBColor[0][1] = RcvBuffer[21];
								RGB1RGBColor[0][2] = RcvBuffer[22];
								RGB1BreathingSpeed = RcvBuffer[23];
								RGB1MaxBright = RcvBuffer[24];
								/* Get Graphic LED Setting */
								GraphicLightingMode = RcvBuffer[25];
								Graphic_Fn = (Graphic_FUNC)Graphic_ptr[GraphicLightingMode];
								GraphicRGBColor[0][0] = RcvBuffer[26];
								GraphicRGBColor[0][1] = RcvBuffer[27];
								GraphicRGBColor[0][2] = RcvBuffer[28];
								GraphicSpeed = RcvBuffer[29];
								GraphicBrightness = RcvBuffer[30];
								/* Get Bar LED Setting */
								BarLightingMode = RcvBuffer[31];
								Bar_Fn = (Graphic_FUNC)Bar_ptr[BarLightingMode];
								BarRGBColor[0][0] = RcvBuffer[32];
								BarRGBColor[0][1] = RcvBuffer[33];
								BarRGBColor[0][2] = RcvBuffer[34];
								BarSpeed = RcvBuffer[35];
								BarBrightness = RcvBuffer[36];
								/* Get Stripe LED Setting */
								StripeLightingMode = RcvBuffer[37];
								Stripe_Fn = (Stripe_FUNC)Stripe_ptr[StripeLightingMode];
								StripeRGBColor[0][0] = RcvBuffer[38];
								StripeRGBColor[0][1] = RcvBuffer[39];
								StripeRGBColor[0][2] = RcvBuffer[40];
								StripeSpeed = RcvBuffer[41];
								StripeBrightness = RcvBuffer[42];
								Store_Flash = RcvBuffer[43];

								G12Mode_Reset();
								G34Mode_Reset();
								G5Mode_Reset();
								RGB1Mode_Reset();
								GraphicTimeCounter = 0;
								BarTimeCounter = 0;
								StripeTimeCounter = 0;
							
								/* Store new setting to Data Flash */
								if(Store_Flash)
										WriteNewSetting();
						}							
				}
		
				if(LED_Mode_Flag == 1)
				{
						G12LightingMode = (G12LightingMode % 8) + 1;
						G34LightingMode = (G34LightingMode % 8) + 1;
						G5LightingMode = (G5LightingMode % 8) + 1;
						RGB1LightingMode = (RGB1LightingMode % 8) + 1;
						GraphicLightingMode = (GraphicLightingMode % 8) + 1;
						BarLightingMode = (BarLightingMode % 8) + 1;
						StripeLightingMode = (StripeLightingMode % 8) + 1;
						
						G12Mode_Reset();
						G34Mode_Reset();
						G5Mode_Reset();
						RGB1Mode_Reset();
						Graphic_Fn = (Graphic_FUNC)Graphic_ptr[GraphicLightingMode];
						Bar_Fn = (Bar_FUNC)Bar_ptr[BarLightingMode];
						Stripe_Fn = (Stripe_FUNC)Stripe_ptr[StripeLightingMode];
						GraphicTimeCounter = 0;
						BarTimeCounter = 0;
						StripeTimeCounter = 0;
						
						LED_Mode_Flag = 0;
				}
				
				if(LED_Color_Flag == 1)
				{
						G12RGBColor[0][0] = RainbowColor[ptrDEMOColor * 2][0];
						G12RGBColor[0][1] = RainbowColor[ptrDEMOColor * 2][1];
						G12RGBColor[0][2] = RainbowColor[ptrDEMOColor * 2][2];
						G34RGBColor[0][0] = RainbowColor[ptrDEMOColor * 2][0];
						G34RGBColor[0][1] = RainbowColor[ptrDEMOColor * 2][1];
						G34RGBColor[0][2] = RainbowColor[ptrDEMOColor * 2][2];
						G5RGBColor[0][0] = RainbowColor[ptrDEMOColor * 2][0];
						G5RGBColor[0][1] = RainbowColor[ptrDEMOColor * 2][1];
						G5RGBColor[0][2] = RainbowColor[ptrDEMOColor * 2][2];
						RGB1RGBColor[0][0] = RainbowColor[ptrDEMOColor * 2][0];
						RGB1RGBColor[0][1] = RainbowColor[ptrDEMOColor * 2][1];
						RGB1RGBColor[0][2] = RainbowColor[ptrDEMOColor * 2][2];
						GraphicRGBColor[0][0] = RainbowColor[ptrDEMOColor * 2][0];
						GraphicRGBColor[0][1] = RainbowColor[ptrDEMOColor * 2][1];
						GraphicRGBColor[0][2] = RainbowColor[ptrDEMOColor * 2][2];
						BarRGBColor[0][0] = RainbowColor[ptrDEMOColor * 2][0];
						BarRGBColor[0][1] = RainbowColor[ptrDEMOColor * 2][1];
						BarRGBColor[0][2] = RainbowColor[ptrDEMOColor * 2][2];
						StripeRGBColor[0][0] = RainbowColor[ptrDEMOColor * 2][0];
						StripeRGBColor[0][1] = RainbowColor[ptrDEMOColor * 2][1];
						StripeRGBColor[0][2] = RainbowColor[ptrDEMOColor * 2][2];
						ptrDEMOColor = (ptrDEMOColor + 1) % 8;
						
						LED_Color_Flag = 0;
				}
								
				if(Change_Flag)
				{
						G12_Change();
						G34_Change();
						G5_Change();
						RGB1_Change();
											
						G12TempCounter = G12TimeCounter / G12TempCal;
						G34TempCounter = G34TimeCounter / G34TempCal;
						G5TempCounter = G5TimeCounter / G5TempCal;
						RGB1TempCounter = RGB1TimeCounter / RGB1TempCal;
						
						switch(TimeCounter % 12)
						{
								/* COM1 ON */
								case 0:
								{
										/* Enable all group LED0 */
										PWM0->CMPDAT[0] = G1_R_CMP;		// Group1_R
										PWM0->CMPDAT[1] = G1_G_CMP;		// Group1_G
										PWM0->CMPDAT[2] = G1_B_CMP;		// Group1_B
										PWM0->CMPDAT[3] = G2_R_CMP;		// Group2_R
										PWM0->CMPDAT[4] = G2_G_CMP;		// Group2_G
										PWM0->CMPDAT[5] = G2_B_CMP;		// Group2_B
										PWM1->CMPDAT[0] = G3_R_CMP;		// Group3_R
										PWM1->CMPDAT[1] = G3_G_CMP;		// Group3_G
										PWM1->CMPDAT[2] = G3_B_CMP;		// Group3_B
										PWM1->CMPDAT[3] = G4_R_CMP;		// Group4_R
										PWM1->CMPDAT[4] = G4_G_CMP;		// Group4_G
										PWM1->CMPDAT[5] = G4_B_CMP;		// Group4_B
										BPWM0->CMPDAT[0] = G5_R_CMP;	// Group5_R
										BPWM0->CMPDAT[1] = G5_G_CMP;	// Group5_G
										BPWM0->CMPDAT[2] = G5_B_CMP;	// Group5_B
										BPWM0->CMPDAT[0] = G5_R_CMP;	// Group5_R
										BPWM0->CMPDAT[1] = G5_G_CMP;	// Group5_G
										BPWM0->CMPDAT[2] = G5_B_CMP;	// Group5_B
										BPWM0->CMPDAT[3] = RGB1_R_CMP;	// RGB1_R
										BPWM0->CMPDAT[4] = RGB1_G_CMP;	// RGB1_G
										BPWM0->CMPDAT[5] = RGB1_B_CMP;	// RGB1_B
										/* Enable LED0 */
										COM0_ON();
										/* Calculate next value */
										G1_R_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[1]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[1]) % G12BrightSize)) / 100;		// Group1_R
										G1_G_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[1]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[1]) % G12BrightSize)) / 100;		// Group1_G
										G1_B_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[1]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[1]) % G12BrightSize)) / 100;		// Group1_B
										G2_R_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[1]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[1]) % G12BrightSize)) / 100;		// Group2_R
										G2_G_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[1]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[1]) % G12BrightSize)) / 100;		// Group2_G
										G2_B_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[1]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[1]) % G12BrightSize)) / 100;		// Group2_B
										G3_R_CMP = *(ptrG3_ColorArray + 3 * ((G12TempCounter + ptrG3Color[1]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[1]) % G34BrightSize)) / 100;		// Group3_R
										G3_G_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[1]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[1]) % G34BrightSize)) / 100;		// Group3_G
										G3_B_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[1]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[1]) % G34BrightSize)) / 100;		// Group3_B
										G4_R_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[1]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[1]) % G34BrightSize)) / 100;		// Group4_R
										G4_G_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[1]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[1]) % G34BrightSize)) / 100;		// Group4_G
										G4_B_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[1]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[1]) % G34BrightSize)) / 100;		// Group4_B
										G5_R_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[1]) % G5ColorSize)     ) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[1]) % G5BrightSize))  / 100;		// Group5_R
										G5_G_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[1]) % G5ColorSize)  + 1) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[1]) % G5BrightSize))  / 100;		// Group5_G
										G5_B_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[1]) % G5ColorSize)  + 2) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[1]) % G5BrightSize))  / 100;		// Group5_B
										RGB1_R_CMP = *(ptrRGB1_ColorArray + 3 * ((RGB1TempCounter  + ptrRGB1Color[1]) % RGB1ColorSize)     ) * RGB1MaxBright  * *(ptrRGB1BrightArray  + ((RGB1TempCounter  + ptrRGB1Bright[1]) % RGB1BrightSize))  / 100;		// RGB1_R
										RGB1_G_CMP = *(ptrRGB1_ColorArray + 3 * ((RGB1TempCounter  + ptrRGB1Color[1]) % RGB1ColorSize)  + 1) * RGB1MaxBright  * *(ptrRGB1BrightArray  + ((RGB1TempCounter  + ptrRGB1Bright[1]) % RGB1BrightSize))  / 100;		// RGB1_G
										RGB1_B_CMP = *(ptrRGB1_ColorArray + 3 * ((RGB1TempCounter  + ptrRGB1Color[1]) % RGB1ColorSize)  + 2) * RGB1MaxBright  * *(ptrRGB1BrightArray  + ((RGB1TempCounter  + ptrRGB1Bright[1]) % RGB1BrightSize))  / 100;		// RGB1_B

										break;
								}
								case 1:
								{
										/* Disable LED0 */
										COM0_OFF();
										/* Enable all group LED1 */
										PWM0->CMPDAT[0] = G1_R_CMP;		// Group1_R
										PWM0->CMPDAT[1] = G1_G_CMP;		// Group1_G
										PWM0->CMPDAT[2] = G1_B_CMP;		// Group1_B
										PWM0->CMPDAT[3] = G2_R_CMP;		// Group2_R
										PWM0->CMPDAT[4] = G2_G_CMP;		// Group2_G
										PWM0->CMPDAT[5] = G2_B_CMP;		// Group2_B
										PWM1->CMPDAT[0] = G3_R_CMP;		// Group3_R
										PWM1->CMPDAT[1] = G3_G_CMP;		// Group3_G
										PWM1->CMPDAT[2] = G3_B_CMP;		// Group3_B
										PWM1->CMPDAT[3] = G4_R_CMP;		// Group4_R
										PWM1->CMPDAT[4] = G4_G_CMP;		// Group4_G
										PWM1->CMPDAT[5] = G4_B_CMP;		// Group4_B
										BPWM0->CMPDAT[0] = G5_R_CMP;	// Group5_R
										BPWM0->CMPDAT[1] = G5_G_CMP;	// Group5_G
										BPWM0->CMPDAT[2] = G5_B_CMP;	// Group5_B
										/* Enable LED1 */
										COM1_ON();
										/* Calculate next value */
										G1_R_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[2]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[2]) % G12BrightSize)) / 100;		// Group1_R
										G1_G_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[2]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[2]) % G12BrightSize)) / 100;		// Group1_G
										G1_B_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[2]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[2]) % G12BrightSize)) / 100;		// Group1_B
										G2_R_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[2]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[2]) % G12BrightSize)) / 100;		// Group2_R
										G2_G_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[2]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[2]) % G12BrightSize)) / 100;		// Group2_G
										G2_B_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[2]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[2]) % G12BrightSize)) / 100;		// Group2_B
										G3_R_CMP = *(ptrG3_ColorArray + 3 * ((G12TempCounter + ptrG3Color[2]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[2]) % G34BrightSize)) / 100;		// Group3_R
										G3_G_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[2]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[2]) % G34BrightSize)) / 100;		// Group3_G
										G3_B_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[2]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[2]) % G34BrightSize)) / 100;		// Group3_B
										G4_R_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[2]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[2]) % G34BrightSize)) / 100;		// Group4_R
										G4_G_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[2]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[2]) % G34BrightSize)) / 100;		// Group4_G
										G4_B_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[2]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[2]) % G34BrightSize)) / 100;		// Group4_B
										G5_R_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[2]) % G5ColorSize)     ) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[2]) % G5BrightSize))  / 100;		// Group5_R
										G5_G_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[2]) % G5ColorSize)  + 1) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[2]) % G5BrightSize))  / 100;		// Group5_G
										G5_B_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[2]) % G5ColorSize)  + 2) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[2]) % G5BrightSize))  / 100;		// Group5_B
									
										break;
								}
								case 2:
								{
										/* Disable LED1 */
										COM1_OFF();
										/* Enable all group LED2 */
										PWM0->CMPDAT[0] = G1_R_CMP;		// Group1_R
										PWM0->CMPDAT[1] = G1_G_CMP;		// Group1_G
										PWM0->CMPDAT[2] = G1_B_CMP;		// Group1_B
										PWM0->CMPDAT[3] = G2_R_CMP;		// Group2_R
										PWM0->CMPDAT[4] = G2_G_CMP;		// Group2_G
										PWM0->CMPDAT[5] = G2_B_CMP;		// Group2_B
										PWM1->CMPDAT[0] = G3_R_CMP;		// Group3_R
										PWM1->CMPDAT[1] = G3_G_CMP;		// Group3_G
										PWM1->CMPDAT[2] = G3_B_CMP;		// Group3_B
										PWM1->CMPDAT[3] = G4_R_CMP;		// Group4_R
										PWM1->CMPDAT[4] = G4_G_CMP;		// Group4_G
										PWM1->CMPDAT[5] = G4_B_CMP;		// Group4_B
										BPWM0->CMPDAT[0] = G5_R_CMP;	// Group5_R
										BPWM0->CMPDAT[1] = G5_G_CMP;	// Group5_G
										BPWM0->CMPDAT[2] = G5_B_CMP;	// Group5_B
										/* Enable LED2 */
										COM2_ON();
										/* Calculate next value */
										G1_R_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[3]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[3]) % G12BrightSize)) / 100;		// Group1_R
										G1_G_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[3]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[3]) % G12BrightSize)) / 100;		// Group1_G
										G1_B_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[3]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[3]) % G12BrightSize)) / 100;		// Group1_B
										G2_R_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[3]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[3]) % G12BrightSize)) / 100;		// Group2_R
										G2_G_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[3]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[3]) % G12BrightSize)) / 100;		// Group2_G
										G2_B_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[3]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[3]) % G12BrightSize)) / 100;		// Group2_B
										G3_R_CMP = *(ptrG3_ColorArray + 3 * ((G12TempCounter + ptrG3Color[3]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[3]) % G34BrightSize)) / 100;		// Group3_R
										G3_G_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[3]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[3]) % G34BrightSize)) / 100;		// Group3_G
										G3_B_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[3]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[3]) % G34BrightSize)) / 100;		// Group3_B
										G4_R_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[3]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[3]) % G34BrightSize)) / 100;		// Group4_R
										G4_G_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[3]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[3]) % G34BrightSize)) / 100;		// Group4_G
										G4_B_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[3]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[3]) % G34BrightSize)) / 100;		// Group4_B
										G5_R_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[3]) % G5ColorSize)     ) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[3]) % G5BrightSize))  / 100;		// Group5_R
										G5_G_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[3]) % G5ColorSize)  + 1) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[3]) % G5BrightSize))  / 100;		// Group5_G
										G5_B_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[3]) % G5ColorSize)  + 2) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[3]) % G5BrightSize))  / 100;		// Group5_B
										
										break;
								}
								case 3:
								{
										/* Disable LED2 */
										COM2_OFF();
										/* Enable all group LED3 */
										PWM0->CMPDAT[0] = G1_R_CMP;		// Group1_R
										PWM0->CMPDAT[1] = G1_G_CMP;		// Group1_G
										PWM0->CMPDAT[2] = G1_B_CMP;		// Group1_B
										PWM0->CMPDAT[3] = G2_R_CMP;		// Group2_R
										PWM0->CMPDAT[4] = G2_G_CMP;		// Group2_G
										PWM0->CMPDAT[5] = G2_B_CMP;		// Group2_B
										PWM1->CMPDAT[0] = G3_R_CMP;		// Group3_R
										PWM1->CMPDAT[1] = G3_G_CMP;		// Group3_G
										PWM1->CMPDAT[2] = G3_B_CMP;		// Group3_B
										PWM1->CMPDAT[3] = G4_R_CMP;		// Group4_R
										PWM1->CMPDAT[4] = G4_G_CMP;		// Group4_G
										PWM1->CMPDAT[5] = G4_B_CMP;		// Group4_B
										BPWM0->CMPDAT[0] = G5_R_CMP;	// Group5_R
										BPWM0->CMPDAT[1] = G5_G_CMP;	// Group5_G
										BPWM0->CMPDAT[2] = G5_B_CMP;	// Group5_B
										/* Enable LED3 */
										COM3_ON();
										/* Calculate next value */
										G1_R_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[4]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[4]) % G12BrightSize)) / 100;		// Group1_R
										G1_G_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[4]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[4]) % G12BrightSize)) / 100;		// Group1_G
										G1_B_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[4]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[4]) % G12BrightSize)) / 100;		// Group1_B
										G2_R_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[4]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[4]) % G12BrightSize)) / 100;		// Group2_R
										G2_G_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[4]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[4]) % G12BrightSize)) / 100;		// Group2_G
										G2_B_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[4]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[4]) % G12BrightSize)) / 100;		// Group2_B
										G3_R_CMP = *(ptrG3_ColorArray + 3 * ((G12TempCounter + ptrG3Color[4]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[4]) % G34BrightSize)) / 100;		// Group3_R
										G3_G_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[4]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[4]) % G34BrightSize)) / 100;		// Group3_G
										G3_B_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[4]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[4]) % G34BrightSize)) / 100;		// Group3_B
										G4_R_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[4]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[4]) % G34BrightSize)) / 100;		// Group4_R
										G4_G_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[4]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[4]) % G34BrightSize)) / 100;		// Group4_G
										G4_B_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[4]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[4]) % G34BrightSize)) / 100;		// Group4_B
										G5_R_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[4]) % G5ColorSize)     ) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[4]) % G5BrightSize))  / 100;		// Group5_R
										G5_G_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[4]) % G5ColorSize)  + 1) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[4]) % G5BrightSize))  / 100;		// Group5_G
										G5_B_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[4]) % G5ColorSize)  + 2) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[4]) % G5BrightSize))  / 100;		// Group5_B

										break;
								}
								case 4:
								{
										/* Disable LED3 */
										COM3_OFF();
										if(fPDMA_GraphicDone & fPDMA_BarDone)
										{
												fPDMA_GraphicDone = 0;
												/* Prepare Graphic data */
												Graphic_Fn(&GraphicTimeCounter);
												/* Set Graphic */
												Set_GraphicLED();
										}
										
										break;
								}
								case 5:
								{
										/* Enable all group LED4 */
										PWM0->CMPDAT[0] = G1_R_CMP;		// Group1_R
										PWM0->CMPDAT[1] = G1_G_CMP;		// Group1_G
										PWM0->CMPDAT[2] = G1_B_CMP;		// Group1_B
										PWM0->CMPDAT[3] = G2_R_CMP;		// Group2_R
										PWM0->CMPDAT[4] = G2_G_CMP;		// Group2_G
										PWM0->CMPDAT[5] = G2_B_CMP;		// Group2_B
										PWM1->CMPDAT[0] = G3_R_CMP;		// Group3_R
										PWM1->CMPDAT[1] = G3_G_CMP;		// Group3_G
										PWM1->CMPDAT[2] = G3_B_CMP;		// Group3_B
										PWM1->CMPDAT[3] = G4_R_CMP;		// Group4_R
										PWM1->CMPDAT[4] = G4_G_CMP;		// Group4_G
										PWM1->CMPDAT[5] = G4_B_CMP;		// Group4_B
										BPWM0->CMPDAT[0] = G5_R_CMP;	// Group5_R
										BPWM0->CMPDAT[1] = G5_G_CMP;	// Group5_G
										BPWM0->CMPDAT[2] = G5_B_CMP;	// Group5_B
										/* Enable LED4 */
										COM4_ON();
										/* Calculate next value */
										G1_R_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[5]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[5]) % G12BrightSize)) / 100;		// Group1_R
										G1_G_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[5]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[5]) % G12BrightSize)) / 100;		// Group1_G
										G1_B_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[5]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[5]) % G12BrightSize)) / 100;		// Group1_B
										G2_R_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[5]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[5]) % G12BrightSize)) / 100;		// Group2_R
										G2_G_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[5]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[5]) % G12BrightSize)) / 100;		// Group2_G
										G2_B_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[5]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[5]) % G12BrightSize)) / 100;		// Group2_B
										G3_R_CMP = *(ptrG3_ColorArray + 3 * ((G12TempCounter + ptrG3Color[5]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[5]) % G34BrightSize)) / 100;		// Group3_R
										G3_G_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[5]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[5]) % G34BrightSize)) / 100;		// Group3_G
										G3_B_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[5]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[5]) % G34BrightSize)) / 100;		// Group3_B
										G4_R_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[5]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[5]) % G34BrightSize)) / 100;		// Group4_R
										G4_G_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[5]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[5]) % G34BrightSize)) / 100;		// Group4_G
										G4_B_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[5]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[5]) % G34BrightSize)) / 100;		// Group4_B
										G5_R_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[5]) % G5ColorSize)     ) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[5]) % G5BrightSize))  / 100;		// Group5_R
										G5_G_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[5]) % G5ColorSize)  + 1) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[5]) % G5BrightSize))  / 100;		// Group5_G
										G5_B_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[5]) % G5ColorSize)  + 2) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[5]) % G5BrightSize))  / 100;		// Group5_B
										
										break;
								}
								case 6:
								{
										/* Disable LED4 */
										COM4_OFF();
										/* Enable all group LED5 */
										PWM0->CMPDAT[0] = G1_R_CMP;		// Group1_R
										PWM0->CMPDAT[1] = G1_G_CMP;		// Group1_G
										PWM0->CMPDAT[2] = G1_B_CMP;		// Group1_B
										PWM0->CMPDAT[3] = G2_R_CMP;		// Group2_R
										PWM0->CMPDAT[4] = G2_G_CMP;		// Group2_G
										PWM0->CMPDAT[5] = G2_B_CMP;		// Group2_B
										PWM1->CMPDAT[0] = G3_R_CMP;		// Group3_R
										PWM1->CMPDAT[1] = G3_G_CMP;		// Group3_G
										PWM1->CMPDAT[2] = G3_B_CMP;		// Group3_B
										PWM1->CMPDAT[3] = G4_R_CMP;		// Group4_R
										PWM1->CMPDAT[4] = G4_G_CMP;		// Group4_G
										PWM1->CMPDAT[5] = G4_B_CMP;		// Group4_B
										BPWM0->CMPDAT[0] = G5_R_CMP;	// Group5_R
										BPWM0->CMPDAT[1] = G5_G_CMP;	// Group5_G
										BPWM0->CMPDAT[2] = G5_B_CMP;	// Group5_B
										/* Enable LED5 */
										COM5_ON();
										/* Calculate next value */
										G1_R_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[6]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[6]) % G12BrightSize)) / 100;		// Group1_R
										G1_G_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[6]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[6]) % G12BrightSize)) / 100;		// Group1_G
										G1_B_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[6]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[6]) % G12BrightSize)) / 100;		// Group1_B
										G2_R_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[6]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[6]) % G12BrightSize)) / 100;		// Group2_R
										G2_G_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[6]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[6]) % G12BrightSize)) / 100;		// Group2_G
										G2_B_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[6]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[6]) % G12BrightSize)) / 100;		// Group2_B
										G3_R_CMP = *(ptrG3_ColorArray + 3 * ((G12TempCounter + ptrG3Color[6]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[6]) % G34BrightSize)) / 100;		// Group3_R
										G3_G_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[6]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[6]) % G34BrightSize)) / 100;		// Group3_G
										G3_B_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[6]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[6]) % G34BrightSize)) / 100;		// Group3_B
										G4_R_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[6]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[6]) % G34BrightSize)) / 100;		// Group4_R
										G4_G_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[6]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[6]) % G34BrightSize)) / 100;		// Group4_G
										G4_B_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[6]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[6]) % G34BrightSize)) / 100;		// Group4_B
										G5_R_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[6]) % G5ColorSize)     ) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[6]) % G5BrightSize))  / 100;		// Group5_R
										G5_G_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[6]) % G5ColorSize)  + 1) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[6]) % G5BrightSize))  / 100;		// Group5_G
										G5_B_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[6]) % G5ColorSize)  + 2) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[6]) % G5BrightSize))  / 100;		// Group5_B
									
										break;
								}
								case 7:
								{
										/* Disable LED5 */
										COM5_OFF();
										/* Enable all group LED6 */
										PWM0->CMPDAT[0] = G1_R_CMP;		// Group1_R
										PWM0->CMPDAT[1] = G1_G_CMP;		// Group1_G
										PWM0->CMPDAT[2] = G1_B_CMP;		// Group1_B
										PWM0->CMPDAT[3] = G2_R_CMP;		// Group2_R
										PWM0->CMPDAT[4] = G2_G_CMP;		// Group2_G
										PWM0->CMPDAT[5] = G2_B_CMP;		// Group2_B
										PWM1->CMPDAT[0] = G3_R_CMP;		// Group3_R
										PWM1->CMPDAT[1] = G3_G_CMP;		// Group3_G
										PWM1->CMPDAT[2] = G3_B_CMP;		// Group3_B
										PWM1->CMPDAT[3] = G4_R_CMP;		// Group4_R
										PWM1->CMPDAT[4] = G4_G_CMP;		// Group4_G
										PWM1->CMPDAT[5] = G4_B_CMP;		// Group4_B
										BPWM0->CMPDAT[0] = G5_R_CMP;	// Group5_R
										BPWM0->CMPDAT[1] = G5_G_CMP;	// Group5_G
										BPWM0->CMPDAT[2] = G5_B_CMP;	// Group5_B
										/* Enable LED6 */
										COM6_ON();
										/* Calculate next value */
										G1_R_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[7]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[7]) % G12BrightSize)) / 100;		// Group1_R
										G1_G_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[7]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[7]) % G12BrightSize)) / 100;		// Group1_G
										G1_B_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[7]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[7]) % G12BrightSize)) / 100;		// Group1_B
										G2_R_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[7]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[7]) % G12BrightSize)) / 100;		// Group2_R
										G2_G_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[7]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[7]) % G12BrightSize)) / 100;		// Group2_G
										G2_B_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[7]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[7]) % G12BrightSize)) / 100;		// Group2_B
										G3_R_CMP = *(ptrG3_ColorArray + 3 * ((G12TempCounter + ptrG3Color[7]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[7]) % G34BrightSize)) / 100;		// Group3_R
										G3_G_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[7]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[7]) % G34BrightSize)) / 100;		// Group3_G
										G3_B_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[7]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[7]) % G34BrightSize)) / 100;		// Group3_B
										G4_R_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[7]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[7]) % G34BrightSize)) / 100;		// Group4_R
										G4_G_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[7]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[7]) % G34BrightSize)) / 100;		// Group4_G
										G4_B_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[7]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[7]) % G34BrightSize)) / 100;		// Group4_B
										G5_R_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[7]) % G5ColorSize)     ) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[7]) % G5BrightSize))  / 100;		// Group5_R
										G5_G_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[7]) % G5ColorSize)  + 1) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[7]) % G5BrightSize))  / 100;		// Group5_G
										G5_B_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[7]) % G5ColorSize)  + 2) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[7]) % G5BrightSize))  / 100;		// Group5_B
										
										break;
								}
								case 8:
								{
										/* Disable LED6 */
										COM6_OFF();
										/* Enable all group LED7 */
										PWM0->CMPDAT[0] = G1_R_CMP;		// Group1_R
										PWM0->CMPDAT[1] = G1_G_CMP;		// Group1_G
										PWM0->CMPDAT[2] = G1_B_CMP;		// Group1_B
										PWM0->CMPDAT[3] = G2_R_CMP;		// Group2_R
										PWM0->CMPDAT[4] = G2_G_CMP;		// Group2_G
										PWM0->CMPDAT[5] = G2_B_CMP;		// Group2_B
										PWM1->CMPDAT[0] = G3_R_CMP;		// Group3_R
										PWM1->CMPDAT[1] = G3_G_CMP;		// Group3_G
										PWM1->CMPDAT[2] = G3_B_CMP;		// Group3_B
										PWM1->CMPDAT[3] = G4_R_CMP;		// Group4_R
										PWM1->CMPDAT[4] = G4_G_CMP;		// Group4_G
										PWM1->CMPDAT[5] = G4_B_CMP;		// Group4_B
										BPWM0->CMPDAT[0] = G5_R_CMP;	// Group5_R
										BPWM0->CMPDAT[1] = G5_G_CMP;	// Group5_G
										BPWM0->CMPDAT[2] = G5_B_CMP;	// Group5_B
										/* Enable LED7 */
										COM7_ON();
										/* Calculate next value */
										G1_R_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[0]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[0]) % G12BrightSize)) / 100;		// Group1_R
										G1_G_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[0]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[0]) % G12BrightSize)) / 100;		// Group1_G
										G1_B_CMP = *(ptrG1_ColorArray + 3 * ((G12TempCounter + ptrG1Color[0]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG1Bright[0]) % G12BrightSize)) / 100;		// Group1_B
										G2_R_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[0]) % G12ColorSize)    ) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[0]) % G12BrightSize)) / 100;		// Group2_R
										G2_G_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[0]) % G12ColorSize) + 1) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[0]) % G12BrightSize)) / 100;		// Group2_G
										G2_B_CMP = *(ptrG2_ColorArray + 3 * ((G12TempCounter + ptrG2Color[0]) % G12ColorSize) + 2) * G12MaxBright * *(ptrG12BrightArray + ((G12TempCounter + ptrG2Bright[0]) % G12BrightSize)) / 100;		// Group2_B
										G3_R_CMP = *(ptrG3_ColorArray + 3 * ((G12TempCounter + ptrG3Color[0]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[0]) % G34BrightSize)) / 100;		// Group3_R
										G3_G_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[0]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[0]) % G34BrightSize)) / 100;		// Group3_G
										G3_B_CMP = *(ptrG3_ColorArray + 3 * ((G34TempCounter + ptrG3Color[0]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG3Bright[0]) % G34BrightSize)) / 100;		// Group3_B
										G4_R_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[0]) % G34ColorSize)    ) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[0]) % G34BrightSize)) / 100;		// Group4_R
										G4_G_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[0]) % G34ColorSize) + 1) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[0]) % G34BrightSize)) / 100;		// Group4_G
										G4_B_CMP = *(ptrG4_ColorArray + 3 * ((G34TempCounter + ptrG4Color[0]) % G34ColorSize) + 2) * G34MaxBright * *(ptrG34BrightArray + ((G34TempCounter + ptrG4Bright[0]) % G34BrightSize)) / 100;		// Group4_B
										G5_R_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[0]) % G5ColorSize)     ) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[0]) % G5BrightSize))  / 100;		// Group5_R
										G5_G_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[0]) % G5ColorSize)  + 1) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[0]) % G5BrightSize))  / 100;		// Group5_G
										G5_B_CMP = *(ptrG5_ColorArray + 3 * ((G5TempCounter  + ptrG5Color[0]) % G5ColorSize)  + 2) * G5MaxBright  * *(ptrG5BrightArray  + ((G5TempCounter  + ptrG5Bright[0]) % G5BrightSize))  / 100;		// Group5_B
								
										break;
								}
								case 9:
								{
										/* Disable LED7 */
										COM7_OFF();
										if(fPDMA_GraphicDone & fPDMA_BarDone)
										{
												fPDMA_BarDone = 0;
												/* Prepare Bar data */
												Bar_Fn(&BarTimeCounter);
												/* Set Bar */
												Set_BarLED();
										}
										
										break;
								}
								case 10:
								{
										if(fPDMA_StripeDone)
										{
												fPDMA_StripeDone = 0;
												/* Prepare Stripe data */
												Stripe_Fn(&StripeTimeCounter);
												/* Set Stripe */
												Set_StripeLED();
										}
										break;
								}
								case 11:
								{
										break;
								}
						}
//						/* Start PWM0; 0 : Counter Stop Running, 	1 : Counter Start Running */
//						PWM0->CNTEN = (1 << PWM_CNTEN_CNTEN0_Pos) | (1 << PWM_CNTEN_CNTEN2_Pos) | (1 << PWM_CNTEN_CNTEN4_Pos);
//						PWM1->CNTEN = (1 << PWM_CNTEN_CNTEN0_Pos) | (1 << PWM_CNTEN_CNTEN2_Pos) | (1 << PWM_CNTEN_CNTEN4_Pos);
//						BPWM0->CNTEN = (1 << BPWM_CNTEN_CNTEN0_Pos);
						Change_Flag = 0;
				}
		}
		
}
				 
/*** (C) COPYRIGHT 2016 Nuvoton Technology Corp. ***/
